# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/executor.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.executor import task_pb2 as eolymp_dot_executor_dot_task__pb2
from eolymp.executor import language_pb2 as eolymp_dot_executor_dot_language__pb2
from eolymp.executor import runtime_pb2 as eolymp_dot_executor_dot_runtime__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/executor/executor.proto',
  package='eolymp.executor',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/executor;executor',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/executor/executor.proto\x12\x0f\x65olymp.executor\x1a!eolymp/wellknown/expression.proto\x1a\x1a\x65olymp/executor/task.proto\x1a\x1e\x65olymp/executor/language.proto\x1a\x1d\x65olymp/executor/runtime.proto\"6\n\x0f\x43reateTaskInput\x12#\n\x04task\x18\x01 \x01(\x0b\x32\x15.eolymp.executor.Task\"\x12\n\x10\x43reateTaskOutput\",\n\x15\x44\x65scribeLanguageInput\x12\x13\n\x0blanguage_id\x18\x01 \x01(\t\"E\n\x16\x44\x65scribeLanguageOutput\x12+\n\x08language\x18\x01 \x01(\x0b\x32\x19.eolymp.executor.Language\"\xf0\x01\n\x12ListLanguagesInput\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.executor.ListLanguagesInput.Filter\x1a\x9c\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x34\n\ndeprecated\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"?\n\x13ListLanguagesOutput\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.executor.Language\"*\n\x14\x44\x65scribeRuntimeInput\x12\x12\n\nruntime_id\x18\x01 \x01(\t\"B\n\x15\x44\x65scribeRuntimeOutput\x12)\n\x07runtime\x18\x01 \x01(\x0b\x32\x18.eolymp.executor.Runtime\"\xcb\x02\n\x10ListRuntimeInput\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.executor.ListRuntimeInput.Filter\x1a\xfb\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12,\n\x04lang\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07version\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x34\n\ndeprecated\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"<\n\x11ListRuntimeOutput\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.executor.Runtime\"/\n\x19\x44\x65scribeCodeTemplateInput\x12\x12\n\nruntime_id\x18\x01 \x01(\t\".\n\x1a\x44\x65scribeCodeTemplateOutput\x12\x10\n\x08template\x18\x01 \x01(\t2\xfe\x03\n\x08\x45xecutor\x12\x65\n\x10\x44\x65scribeLanguage\x12&.eolymp.executor.DescribeLanguageInput\x1a\'.eolymp.executor.DescribeLanguageOutput\"\x00\x12\\\n\rListLanguages\x12#.eolymp.executor.ListLanguagesInput\x1a$.eolymp.executor.ListLanguagesOutput\"\x00\x12\x62\n\x0f\x44\x65scribeRuntime\x12%.eolymp.executor.DescribeRuntimeInput\x1a&.eolymp.executor.DescribeRuntimeOutput\"\x00\x12V\n\x0bListRuntime\x12!.eolymp.executor.ListRuntimeInput\x1a\".eolymp.executor.ListRuntimeOutput\"\x00\x12q\n\x14\x44\x65scribeCodeTemplate\x12*.eolymp.executor.DescribeCodeTemplateInput\x1a+.eolymp.executor.DescribeCodeTemplateOutput\"\x00\x42\x39Z7github.com/eolymp/contracts/go/eolymp/executor;executorb\x06proto3'
  ,
  dependencies=[eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_executor_dot_task__pb2.DESCRIPTOR,eolymp_dot_executor_dot_language__pb2.DESCRIPTOR,eolymp_dot_executor_dot_runtime__pb2.DESCRIPTOR,])




_CREATETASKINPUT = _descriptor.Descriptor(
  name='CreateTaskInput',
  full_name='eolymp.executor.CreateTaskInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task', full_name='eolymp.executor.CreateTaskInput.task', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=231,
)


_CREATETASKOUTPUT = _descriptor.Descriptor(
  name='CreateTaskOutput',
  full_name='eolymp.executor.CreateTaskOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=251,
)


_DESCRIBELANGUAGEINPUT = _descriptor.Descriptor(
  name='DescribeLanguageInput',
  full_name='eolymp.executor.DescribeLanguageInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language_id', full_name='eolymp.executor.DescribeLanguageInput.language_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=297,
)


_DESCRIBELANGUAGEOUTPUT = _descriptor.Descriptor(
  name='DescribeLanguageOutput',
  full_name='eolymp.executor.DescribeLanguageOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='eolymp.executor.DescribeLanguageOutput.language', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=368,
)


_LISTLANGUAGESINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.executor.ListLanguagesInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.executor.ListLanguagesInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.executor.ListLanguagesInput.Filter.name', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='eolymp.executor.ListLanguagesInput.Filter.deprecated', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=611,
)

_LISTLANGUAGESINPUT = _descriptor.Descriptor(
  name='ListLanguagesInput',
  full_name='eolymp.executor.ListLanguagesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.executor.ListLanguagesInput.filters', index=0,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTLANGUAGESINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=611,
)


_LISTLANGUAGESOUTPUT = _descriptor.Descriptor(
  name='ListLanguagesOutput',
  full_name='eolymp.executor.ListLanguagesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.executor.ListLanguagesOutput.items', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=613,
  serialized_end=676,
)


_DESCRIBERUNTIMEINPUT = _descriptor.Descriptor(
  name='DescribeRuntimeInput',
  full_name='eolymp.executor.DescribeRuntimeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='runtime_id', full_name='eolymp.executor.DescribeRuntimeInput.runtime_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=678,
  serialized_end=720,
)


_DESCRIBERUNTIMEOUTPUT = _descriptor.Descriptor(
  name='DescribeRuntimeOutput',
  full_name='eolymp.executor.DescribeRuntimeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='runtime', full_name='eolymp.executor.DescribeRuntimeOutput.runtime', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=722,
  serialized_end=788,
)


_LISTRUNTIMEINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.executor.ListRuntimeInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.executor.ListRuntimeInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.executor.ListRuntimeInput.Filter.lang', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='eolymp.executor.ListRuntimeInput.Filter.version', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.executor.ListRuntimeInput.Filter.name', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='eolymp.executor.ListRuntimeInput.Filter.deprecated', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=871,
  serialized_end=1122,
)

_LISTRUNTIMEINPUT = _descriptor.Descriptor(
  name='ListRuntimeInput',
  full_name='eolymp.executor.ListRuntimeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.executor.ListRuntimeInput.filters', index=0,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTRUNTIMEINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=791,
  serialized_end=1122,
)


_LISTRUNTIMEOUTPUT = _descriptor.Descriptor(
  name='ListRuntimeOutput',
  full_name='eolymp.executor.ListRuntimeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.executor.ListRuntimeOutput.items', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1124,
  serialized_end=1184,
)


_DESCRIBECODETEMPLATEINPUT = _descriptor.Descriptor(
  name='DescribeCodeTemplateInput',
  full_name='eolymp.executor.DescribeCodeTemplateInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='runtime_id', full_name='eolymp.executor.DescribeCodeTemplateInput.runtime_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1186,
  serialized_end=1233,
)


_DESCRIBECODETEMPLATEOUTPUT = _descriptor.Descriptor(
  name='DescribeCodeTemplateOutput',
  full_name='eolymp.executor.DescribeCodeTemplateOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='eolymp.executor.DescribeCodeTemplateOutput.template', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1235,
  serialized_end=1281,
)

_CREATETASKINPUT.fields_by_name['task'].message_type = eolymp_dot_executor_dot_task__pb2._TASK
_DESCRIBELANGUAGEOUTPUT.fields_by_name['language'].message_type = eolymp_dot_executor_dot_language__pb2._LANGUAGE
_LISTLANGUAGESINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTLANGUAGESINPUT_FILTER.fields_by_name['name'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTLANGUAGESINPUT_FILTER.fields_by_name['deprecated'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTLANGUAGESINPUT_FILTER.containing_type = _LISTLANGUAGESINPUT
_LISTLANGUAGESINPUT.fields_by_name['filters'].message_type = _LISTLANGUAGESINPUT_FILTER
_LISTLANGUAGESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_executor_dot_language__pb2._LANGUAGE
_DESCRIBERUNTIMEOUTPUT.fields_by_name['runtime'].message_type = eolymp_dot_executor_dot_runtime__pb2._RUNTIME
_LISTRUNTIMEINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTRUNTIMEINPUT_FILTER.fields_by_name['lang'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTRUNTIMEINPUT_FILTER.fields_by_name['version'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTRUNTIMEINPUT_FILTER.fields_by_name['name'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTRUNTIMEINPUT_FILTER.fields_by_name['deprecated'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTRUNTIMEINPUT_FILTER.containing_type = _LISTRUNTIMEINPUT
_LISTRUNTIMEINPUT.fields_by_name['filters'].message_type = _LISTRUNTIMEINPUT_FILTER
_LISTRUNTIMEOUTPUT.fields_by_name['items'].message_type = eolymp_dot_executor_dot_runtime__pb2._RUNTIME
DESCRIPTOR.message_types_by_name['CreateTaskInput'] = _CREATETASKINPUT
DESCRIPTOR.message_types_by_name['CreateTaskOutput'] = _CREATETASKOUTPUT
DESCRIPTOR.message_types_by_name['DescribeLanguageInput'] = _DESCRIBELANGUAGEINPUT
DESCRIPTOR.message_types_by_name['DescribeLanguageOutput'] = _DESCRIBELANGUAGEOUTPUT
DESCRIPTOR.message_types_by_name['ListLanguagesInput'] = _LISTLANGUAGESINPUT
DESCRIPTOR.message_types_by_name['ListLanguagesOutput'] = _LISTLANGUAGESOUTPUT
DESCRIPTOR.message_types_by_name['DescribeRuntimeInput'] = _DESCRIBERUNTIMEINPUT
DESCRIPTOR.message_types_by_name['DescribeRuntimeOutput'] = _DESCRIBERUNTIMEOUTPUT
DESCRIPTOR.message_types_by_name['ListRuntimeInput'] = _LISTRUNTIMEINPUT
DESCRIPTOR.message_types_by_name['ListRuntimeOutput'] = _LISTRUNTIMEOUTPUT
DESCRIPTOR.message_types_by_name['DescribeCodeTemplateInput'] = _DESCRIBECODETEMPLATEINPUT
DESCRIPTOR.message_types_by_name['DescribeCodeTemplateOutput'] = _DESCRIBECODETEMPLATEOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateTaskInput = _reflection.GeneratedProtocolMessageType('CreateTaskInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETASKINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.CreateTaskInput)
  })
_sym_db.RegisterMessage(CreateTaskInput)

CreateTaskOutput = _reflection.GeneratedProtocolMessageType('CreateTaskOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETASKOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.CreateTaskOutput)
  })
_sym_db.RegisterMessage(CreateTaskOutput)

DescribeLanguageInput = _reflection.GeneratedProtocolMessageType('DescribeLanguageInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBELANGUAGEINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.DescribeLanguageInput)
  })
_sym_db.RegisterMessage(DescribeLanguageInput)

DescribeLanguageOutput = _reflection.GeneratedProtocolMessageType('DescribeLanguageOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBELANGUAGEOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.DescribeLanguageOutput)
  })
_sym_db.RegisterMessage(DescribeLanguageOutput)

ListLanguagesInput = _reflection.GeneratedProtocolMessageType('ListLanguagesInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTLANGUAGESINPUT_FILTER,
    '__module__' : 'eolymp.executor.executor_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.executor.ListLanguagesInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTLANGUAGESINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.ListLanguagesInput)
  })
_sym_db.RegisterMessage(ListLanguagesInput)
_sym_db.RegisterMessage(ListLanguagesInput.Filter)

ListLanguagesOutput = _reflection.GeneratedProtocolMessageType('ListLanguagesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTLANGUAGESOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.ListLanguagesOutput)
  })
_sym_db.RegisterMessage(ListLanguagesOutput)

DescribeRuntimeInput = _reflection.GeneratedProtocolMessageType('DescribeRuntimeInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERUNTIMEINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.DescribeRuntimeInput)
  })
_sym_db.RegisterMessage(DescribeRuntimeInput)

DescribeRuntimeOutput = _reflection.GeneratedProtocolMessageType('DescribeRuntimeOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERUNTIMEOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.DescribeRuntimeOutput)
  })
_sym_db.RegisterMessage(DescribeRuntimeOutput)

ListRuntimeInput = _reflection.GeneratedProtocolMessageType('ListRuntimeInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTRUNTIMEINPUT_FILTER,
    '__module__' : 'eolymp.executor.executor_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.executor.ListRuntimeInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTRUNTIMEINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.ListRuntimeInput)
  })
_sym_db.RegisterMessage(ListRuntimeInput)
_sym_db.RegisterMessage(ListRuntimeInput.Filter)

ListRuntimeOutput = _reflection.GeneratedProtocolMessageType('ListRuntimeOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNTIMEOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.ListRuntimeOutput)
  })
_sym_db.RegisterMessage(ListRuntimeOutput)

DescribeCodeTemplateInput = _reflection.GeneratedProtocolMessageType('DescribeCodeTemplateInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECODETEMPLATEINPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.DescribeCodeTemplateInput)
  })
_sym_db.RegisterMessage(DescribeCodeTemplateInput)

DescribeCodeTemplateOutput = _reflection.GeneratedProtocolMessageType('DescribeCodeTemplateOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECODETEMPLATEOUTPUT,
  '__module__' : 'eolymp.executor.executor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.DescribeCodeTemplateOutput)
  })
_sym_db.RegisterMessage(DescribeCodeTemplateOutput)


DESCRIPTOR._options = None

_EXECUTOR = _descriptor.ServiceDescriptor(
  name='Executor',
  full_name='eolymp.executor.Executor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1284,
  serialized_end=1794,
  methods=[
  _descriptor.MethodDescriptor(
    name='DescribeLanguage',
    full_name='eolymp.executor.Executor.DescribeLanguage',
    index=0,
    containing_service=None,
    input_type=_DESCRIBELANGUAGEINPUT,
    output_type=_DESCRIBELANGUAGEOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLanguages',
    full_name='eolymp.executor.Executor.ListLanguages',
    index=1,
    containing_service=None,
    input_type=_LISTLANGUAGESINPUT,
    output_type=_LISTLANGUAGESOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeRuntime',
    full_name='eolymp.executor.Executor.DescribeRuntime',
    index=2,
    containing_service=None,
    input_type=_DESCRIBERUNTIMEINPUT,
    output_type=_DESCRIBERUNTIMEOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRuntime',
    full_name='eolymp.executor.Executor.ListRuntime',
    index=3,
    containing_service=None,
    input_type=_LISTRUNTIMEINPUT,
    output_type=_LISTRUNTIMEOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeCodeTemplate',
    full_name='eolymp.executor.Executor.DescribeCodeTemplate',
    index=4,
    containing_service=None,
    input_type=_DESCRIBECODETEMPLATEINPUT,
    output_type=_DESCRIBECODETEMPLATEOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXECUTOR)

DESCRIPTOR.services_by_name['Executor'] = _EXECUTOR

# @@protoc_insertion_point(module_scope)
