# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/apollo/events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/apollo/events.proto',
  package='eolymp.apollo',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/apollo;apollo',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/apollo/events.proto\x12\reolymp.apollo\"5\n\x0eStarAddedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"7\n\x10StarRemovedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\tB5Z3github.com/eolymp/contracts/go/eolymp/apollo;apollob\x06proto3'
)




_STARADDEDEVENT = _descriptor.Descriptor(
  name='StarAddedEvent',
  full_name='eolymp.apollo.StarAddedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.apollo.StarAddedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.apollo.StarAddedEvent.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=98,
)


_STARREMOVEDEVENT = _descriptor.Descriptor(
  name='StarRemovedEvent',
  full_name='eolymp.apollo.StarRemovedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.apollo.StarRemovedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.apollo.StarRemovedEvent.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=155,
)

DESCRIPTOR.message_types_by_name['StarAddedEvent'] = _STARADDEDEVENT
DESCRIPTOR.message_types_by_name['StarRemovedEvent'] = _STARREMOVEDEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StarAddedEvent = _reflection.GeneratedProtocolMessageType('StarAddedEvent', (_message.Message,), {
  'DESCRIPTOR' : _STARADDEDEVENT,
  '__module__' : 'eolymp.apollo.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.StarAddedEvent)
  })
_sym_db.RegisterMessage(StarAddedEvent)

StarRemovedEvent = _reflection.GeneratedProtocolMessageType('StarRemovedEvent', (_message.Message,), {
  'DESCRIPTOR' : _STARREMOVEDEVENT,
  '__module__' : 'eolymp.apollo.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.StarRemovedEvent)
  })
_sym_db.RegisterMessage(StarRemovedEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
