# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/verifier.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/executor/verifier.proto',
  package='eolymp.executor',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/executor;executor',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/executor/verifier.proto\x12\x0f\x65olymp.executor\"\xcb\x01\n\x08Verifier\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x1e.eolymp.executor.Verifier.Type\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x11\n\tprecision\x18\x04 \x01(\x05\x12\x16\n\x0e\x63\x61se_sensitive\x18\x05 \x01(\x08\"H\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06TOKENS\x10\x01\x12\t\n\x05LINES\x10\x02\x12\x0b\n\x07PROGRAM\x10\x03\x12\x12\n\x0eLEGACY_PROGRAM\x10\x04\x42\x39Z7github.com/eolymp/contracts/go/eolymp/executor;executorb\x06proto3'
)



_VERIFIER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.executor.Verifier.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOKENS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRAM', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEGACY_PROGRAM', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=183,
  serialized_end=255,
)
_sym_db.RegisterEnumDescriptor(_VERIFIER_TYPE)


_VERIFIER = _descriptor.Descriptor(
  name='Verifier',
  full_name='eolymp.executor.Verifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.executor.Verifier.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.executor.Verifier.lang', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.executor.Verifier.source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='precision', full_name='eolymp.executor.Verifier.precision', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_sensitive', full_name='eolymp.executor.Verifier.case_sensitive', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VERIFIER_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=255,
)

_VERIFIER.fields_by_name['type'].enum_type = _VERIFIER_TYPE
_VERIFIER_TYPE.containing_type = _VERIFIER
DESCRIPTOR.message_types_by_name['Verifier'] = _VERIFIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Verifier = _reflection.GeneratedProtocolMessageType('Verifier', (_message.Message,), {
  'DESCRIPTOR' : _VERIFIER,
  '__module__' : 'eolymp.executor.verifier_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.Verifier)
  })
_sym_db.RegisterMessage(Verifier)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
