# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/testset.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import feedback_pb2 as eolymp_dot_atlas_dot_feedback__pb2
from eolymp.atlas import scoring_pb2 as eolymp_dot_atlas_dot_scoring__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/testset.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/atlas/testset.proto\x12\x0c\x65olymp.atlas\x1a\x1b\x65olymp/atlas/feedback.proto\x1a\x1a\x65olymp/atlas/scoring.proto\"\xf9\x01\n\x07Testset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\r\x12\x12\n\ntime_limit\x18\n \x01(\r\x12\x14\n\x0cmemory_limit\x18\x0b \x01(\x04\x12\x17\n\x0f\x66ile_size_limit\x18\x0c \x01(\x04\x12\x14\n\x0c\x64\x65pendencies\x18\x14 \x03(\r\x12/\n\x0cscoring_mode\x18\x1e \x01(\x0e\x32\x19.eolymp.atlas.ScoringMode\x12\x35\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18( \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicyB3Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
  ,
  dependencies=[eolymp_dot_atlas_dot_feedback__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_scoring__pb2.DESCRIPTOR,])




_TESTSET = _descriptor.Descriptor(
  name='Testset',
  full_name='eolymp.atlas.Testset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.atlas.Testset.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.Testset.problem_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.atlas.Testset.index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_limit', full_name='eolymp.atlas.Testset.time_limit', index=3,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_limit', full_name='eolymp.atlas.Testset.memory_limit', index=4,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size_limit', full_name='eolymp.atlas.Testset.file_size_limit', index=5,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dependencies', full_name='eolymp.atlas.Testset.dependencies', index=6,
      number=20, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoring_mode', full_name='eolymp.atlas.Testset.scoring_mode', index=7,
      number=30, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedback_policy', full_name='eolymp.atlas.Testset.feedback_policy', index=8,
      number=40, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=351,
)

_TESTSET.fields_by_name['scoring_mode'].enum_type = eolymp_dot_atlas_dot_scoring__pb2._SCORINGMODE
_TESTSET.fields_by_name['feedback_policy'].enum_type = eolymp_dot_atlas_dot_feedback__pb2._FEEDBACKPOLICY
DESCRIPTOR.message_types_by_name['Testset'] = _TESTSET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Testset = _reflection.GeneratedProtocolMessageType('Testset', (_message.Message,), {
  'DESCRIPTOR' : _TESTSET,
  '__module__' : 'eolymp.atlas.testset_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.Testset)
  })
_sym_db.RegisterMessage(Testset)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
