# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import problem_pb2 as eolymp_dot_atlas_dot_problem__pb2
from eolymp.atlas import permission_pb2 as eolymp_dot_atlas_dot_permission__pb2
from eolymp.atlas import submission_pb2 as eolymp_dot_atlas_dot_submission__pb2
from eolymp.atlas import score_pb2 as eolymp_dot_atlas_dot_score__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/events.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x65olymp/atlas/events.proto\x12\x0c\x65olymp.atlas\x1a\x1a\x65olymp/atlas/problem.proto\x1a\x1d\x65olymp/atlas/permission.proto\x1a\x1d\x65olymp/atlas/submission.proto\x1a\x18\x65olymp/atlas/score.proto\"=\n\x13ProblemUpdatedEvent\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\")\n\x13ProblemDeletedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"[\n\x17PermissionsUpdatedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12,\n\npermission\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Permission\">\n\x17PermissionsDeletedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"W\n\x17SubmissionCompleteEvent\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Submission\x12\x0e\n\x06update\x18\x02 \x01(\x08\"7\n\x11ScoreUpdatedEvent\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.atlas.ScoreB3Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
  ,
  dependencies=[eolymp_dot_atlas_dot_problem__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_permission__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_submission__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_score__pb2.DESCRIPTOR,])




_PROBLEMUPDATEDEVENT = _descriptor.Descriptor(
  name='ProblemUpdatedEvent',
  full_name='eolymp.atlas.ProblemUpdatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem', full_name='eolymp.atlas.ProblemUpdatedEvent.problem', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=220,
)


_PROBLEMDELETEDEVENT = _descriptor.Descriptor(
  name='ProblemDeletedEvent',
  full_name='eolymp.atlas.ProblemDeletedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.ProblemDeletedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=263,
)


_PERMISSIONSUPDATEDEVENT = _descriptor.Descriptor(
  name='PermissionsUpdatedEvent',
  full_name='eolymp.atlas.PermissionsUpdatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.PermissionsUpdatedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='eolymp.atlas.PermissionsUpdatedEvent.permission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=265,
  serialized_end=356,
)


_PERMISSIONSDELETEDEVENT = _descriptor.Descriptor(
  name='PermissionsDeletedEvent',
  full_name='eolymp.atlas.PermissionsDeletedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.PermissionsDeletedEvent.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.atlas.PermissionsDeletedEvent.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=420,
)


_SUBMISSIONCOMPLETEEVENT = _descriptor.Descriptor(
  name='SubmissionCompleteEvent',
  full_name='eolymp.atlas.SubmissionCompleteEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission', full_name='eolymp.atlas.SubmissionCompleteEvent.submission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='eolymp.atlas.SubmissionCompleteEvent.update', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=422,
  serialized_end=509,
)


_SCOREUPDATEDEVENT = _descriptor.Descriptor(
  name='ScoreUpdatedEvent',
  full_name='eolymp.atlas.ScoreUpdatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.atlas.ScoreUpdatedEvent.score', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=511,
  serialized_end=566,
)

_PROBLEMUPDATEDEVENT.fields_by_name['problem'].message_type = eolymp_dot_atlas_dot_problem__pb2._PROBLEM
_PERMISSIONSUPDATEDEVENT.fields_by_name['permission'].message_type = eolymp_dot_atlas_dot_permission__pb2._PERMISSION
_SUBMISSIONCOMPLETEEVENT.fields_by_name['submission'].message_type = eolymp_dot_atlas_dot_submission__pb2._SUBMISSION
_SCOREUPDATEDEVENT.fields_by_name['score'].message_type = eolymp_dot_atlas_dot_score__pb2._SCORE
DESCRIPTOR.message_types_by_name['ProblemUpdatedEvent'] = _PROBLEMUPDATEDEVENT
DESCRIPTOR.message_types_by_name['ProblemDeletedEvent'] = _PROBLEMDELETEDEVENT
DESCRIPTOR.message_types_by_name['PermissionsUpdatedEvent'] = _PERMISSIONSUPDATEDEVENT
DESCRIPTOR.message_types_by_name['PermissionsDeletedEvent'] = _PERMISSIONSDELETEDEVENT
DESCRIPTOR.message_types_by_name['SubmissionCompleteEvent'] = _SUBMISSIONCOMPLETEEVENT
DESCRIPTOR.message_types_by_name['ScoreUpdatedEvent'] = _SCOREUPDATEDEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProblemUpdatedEvent = _reflection.GeneratedProtocolMessageType('ProblemUpdatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _PROBLEMUPDATEDEVENT,
  '__module__' : 'eolymp.atlas.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ProblemUpdatedEvent)
  })
_sym_db.RegisterMessage(ProblemUpdatedEvent)

ProblemDeletedEvent = _reflection.GeneratedProtocolMessageType('ProblemDeletedEvent', (_message.Message,), {
  'DESCRIPTOR' : _PROBLEMDELETEDEVENT,
  '__module__' : 'eolymp.atlas.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ProblemDeletedEvent)
  })
_sym_db.RegisterMessage(ProblemDeletedEvent)

PermissionsUpdatedEvent = _reflection.GeneratedProtocolMessageType('PermissionsUpdatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSIONSUPDATEDEVENT,
  '__module__' : 'eolymp.atlas.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.PermissionsUpdatedEvent)
  })
_sym_db.RegisterMessage(PermissionsUpdatedEvent)

PermissionsDeletedEvent = _reflection.GeneratedProtocolMessageType('PermissionsDeletedEvent', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSIONSDELETEDEVENT,
  '__module__' : 'eolymp.atlas.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.PermissionsDeletedEvent)
  })
_sym_db.RegisterMessage(PermissionsDeletedEvent)

SubmissionCompleteEvent = _reflection.GeneratedProtocolMessageType('SubmissionCompleteEvent', (_message.Message,), {
  'DESCRIPTOR' : _SUBMISSIONCOMPLETEEVENT,
  '__module__' : 'eolymp.atlas.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.SubmissionCompleteEvent)
  })
_sym_db.RegisterMessage(SubmissionCompleteEvent)

ScoreUpdatedEvent = _reflection.GeneratedProtocolMessageType('ScoreUpdatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _SCOREUPDATEDEVENT,
  '__module__' : 'eolymp.atlas.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.ScoreUpdatedEvent)
  })
_sym_db.RegisterMessage(ScoreUpdatedEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
