# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/typewriter/typewriter.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/typewriter/typewriter.proto',
  package='eolymp.typewriter',
  syntax='proto3',
  serialized_options=b'Z;github.com/eolymp/contracts/go/eolymp/typewriter;typewriter',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"eolymp/typewriter/typewriter.proto\x12\x11\x65olymp.typewriter\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\"2\n\x10UploadAssetInput\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"!\n\x11UploadAssetOutput\x12\x0c\n\x04link\x18\x01 \x01(\t2\x96\x01\n\nTypewriter\x12\x87\x01\n\x0bUploadAsset\x12#.eolymp.typewriter.UploadAssetInput\x1a$.eolymp.typewriter.UploadAssetOutput\"-\x82\xe3\n\x1a\x8a\xe3\n\x16typewriter:asset:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\ndB=Z;github.com/eolymp/contracts/go/eolymp/typewriter;typewriterb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,])




_UPLOADASSETINPUT = _descriptor.Descriptor(
  name='UploadAssetInput',
  full_name='eolymp.typewriter.UploadAssetInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='eolymp.typewriter.UploadAssetInput.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='eolymp.typewriter.UploadAssetInput.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=175,
)


_UPLOADASSETOUTPUT = _descriptor.Descriptor(
  name='UploadAssetOutput',
  full_name='eolymp.typewriter.UploadAssetOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='eolymp.typewriter.UploadAssetOutput.link', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=210,
)

DESCRIPTOR.message_types_by_name['UploadAssetInput'] = _UPLOADASSETINPUT
DESCRIPTOR.message_types_by_name['UploadAssetOutput'] = _UPLOADASSETOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UploadAssetInput = _reflection.GeneratedProtocolMessageType('UploadAssetInput', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADASSETINPUT,
  '__module__' : 'eolymp.typewriter.typewriter_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.typewriter.UploadAssetInput)
  })
_sym_db.RegisterMessage(UploadAssetInput)

UploadAssetOutput = _reflection.GeneratedProtocolMessageType('UploadAssetOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADASSETOUTPUT,
  '__module__' : 'eolymp.typewriter.typewriter_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.typewriter.UploadAssetOutput)
  })
_sym_db.RegisterMessage(UploadAssetOutput)


DESCRIPTOR._options = None

_TYPEWRITER = _descriptor.ServiceDescriptor(
  name='Typewriter',
  full_name='eolymp.typewriter.Typewriter',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=213,
  serialized_end=363,
  methods=[
  _descriptor.MethodDescriptor(
    name='UploadAsset',
    full_name='eolymp.typewriter.Typewriter.UploadAsset',
    index=0,
    containing_service=None,
    input_type=_UPLOADASSETINPUT,
    output_type=_UPLOADASSETOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026typewriter:asset:write\352\342\n\013\365\342\n\000\000\000@\370\342\nd',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TYPEWRITER)

DESCRIPTOR.services_by_name['Typewriter'] = _TYPEWRITER

# @@protoc_insertion_point(module_scope)
