# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/universe/universe.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.universe import space_pb2 as eolymp_dot_universe_dot_space__pb2
from eolymp.universe import member_pb2 as eolymp_dot_universe_dot_member__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/universe/universe.proto',
  package='eolymp.universe',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/universe;universe',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/universe/universe.proto\x12\x0f\x65olymp.universe\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1b\x65olymp/universe/space.proto\x1a\x1c\x65olymp/universe/member.proto\"9\n\x10\x43reateSpaceInput\x12%\n\x05space\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Space\"%\n\x11\x43reateSpaceOutput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"K\n\x10UpdateSpaceInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12%\n\x05space\x18\x02 \x01(\x0b\x32\x16.eolymp.universe.Space\"\x13\n\x11UpdateSpaceOutput\"$\n\x10\x44\x65leteSpaceInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteSpaceOutput\"\x1f\n\x10LookupSpaceInput\x12\x0b\n\x03key\x18\x01 \x01(\t\":\n\x11LookupSpaceOutput\x12%\n\x05space\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Space\"&\n\x12\x44\x65scribeSpaceInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"<\n\x13\x44\x65scribeSpaceOutput\x12%\n\x05space\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Space\"\xff\x01\n\x0fListSpacesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.universe.ListSpacesInput.Filter\x1a\x93\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12+\n\x03key\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"H\n\x10ListSpacesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.universe.Space\"A\n\x0e\x41\x64\x64MemberInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\"$\n\x0f\x41\x64\x64MemberOutput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"4\n\x11UpdateMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"\x14\n\x12UpdateMemberOutput\"&\n\x11RemoveMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\x14\n\x12RemoveMemberOutput\"(\n\x13\x44\x65scribeMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"?\n\x14\x44\x65scribeMemberOutput\x12\'\n\x06member\x18\x01 \x01(\x0b\x32\x17.eolymp.universe.Member\")\n\x15IntrospectMemberInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"A\n\x16IntrospectMemberOutput\x12\'\n\x06member\x18\x01 \x01(\x0b\x32\x17.eolymp.universe.Member\"\xcb\x02\n\x10ListMembersInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.universe.ListMembersInput.Filter\x1a\xcb\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04role\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x34\n\x08username\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"J\n\x11ListMembersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.universe.Member2\x9e\x10\n\x08Universe\x12\x9c\x01\n\x0b\x43reateSpace\x12!.eolymp.universe.CreateSpaceInput\x1a\".eolymp.universe.CreateSpaceOutput\"F\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x15\"\x10/universe/spacesb\x01*\x12\xa4\x01\n\x0bUpdateSpace\x12!.eolymp.universe.UpdateSpaceInput\x1a\".eolymp.universe.UpdateSpaceOutput\"N\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1d\x1a\x1b/universe/spaces/{space_id}\x12\xa4\x01\n\x0b\x44\x65leteSpace\x12!.eolymp.universe.DeleteSpaceInput\x1a\".eolymp.universe.DeleteSpaceOutput\"N\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1d*\x1b/universe/spaces/{space_id}\x12\x90\x01\n\x0bLookupSpace\x12!.eolymp.universe.LookupSpaceInput\x1a\".eolymp.universe.LookupSpaceOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02%\x12\x1c/universe/space-lookup/{key}b\x05space\x12\xb0\x01\n\rDescribeSpace\x12#.eolymp.universe.DescribeSpaceInput\x1a$.eolymp.universe.DescribeSpaceOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02$\x12\x1b/universe/spaces/{space_id}b\x05space\x12\x98\x01\n\nListSpaces\x12 .eolymp.universe.ListSpacesInput\x1a!.eolymp.universe.ListSpacesOutput\"E\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x15\x12\x10/universe/spacesb\x01*\x12\xb3\x01\n\tAddMember\x12\x1f.eolymp.universe.AddMemberInput\x1a .eolymp.universe.AddMemberOutput\"c\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x32\x1a-/universe/spaces/{space_id}/members/{user_id}b\x01*\x12\xac\x01\n\x0cUpdateMember\x12\".eolymp.universe.UpdateMemberInput\x1a#.eolymp.universe.UpdateMemberOutput\"S\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\"\x1a\x1d/universe/members/{member_id}b\x01*\x12\xac\x01\n\x0cRemoveMember\x12\".eolymp.universe.RemoveMemberInput\x1a#.eolymp.universe.RemoveMemberOutput\"S\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\"*\x1d/universe/members/{member_id}b\x01*\x12\xb6\x01\n\x0e\x44\x65scribeMember\x12$.eolymp.universe.DescribeMemberInput\x1a%.eolymp.universe.DescribeMemberOutput\"W\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\'\x12\x1d/universe/members/{member_id}b\x06member\x12\xc5\x01\n\x10IntrospectMember\x12&.eolymp.universe.IntrospectMemberInput\x1a\'.eolymp.universe.IntrospectMemberOutput\"`\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x30\x12&/universe/spaces/{space_id}/introspectb\x06member\x12\xae\x01\n\x0bListMembers\x12!.eolymp.universe.ListMembersInput\x1a\".eolymp.universe.ListMembersOutput\"X\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02(\x12#/universe/spaces/{space_id}/membersb\x01*B9Z7github.com/eolymp/contracts/go/eolymp/universe;universeb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_universe_dot_space__pb2.DESCRIPTOR,eolymp_dot_universe_dot_member__pb2.DESCRIPTOR,])




_CREATESPACEINPUT = _descriptor.Descriptor(
  name='CreateSpaceInput',
  full_name='eolymp.universe.CreateSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='eolymp.universe.CreateSpaceInput.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=301,
)


_CREATESPACEOUTPUT = _descriptor.Descriptor(
  name='CreateSpaceOutput',
  full_name='eolymp.universe.CreateSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.CreateSpaceOutput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=340,
)


_UPDATESPACEINPUT = _descriptor.Descriptor(
  name='UpdateSpaceInput',
  full_name='eolymp.universe.UpdateSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.UpdateSpaceInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='space', full_name='eolymp.universe.UpdateSpaceInput.space', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=417,
)


_UPDATESPACEOUTPUT = _descriptor.Descriptor(
  name='UpdateSpaceOutput',
  full_name='eolymp.universe.UpdateSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=438,
)


_DELETESPACEINPUT = _descriptor.Descriptor(
  name='DeleteSpaceInput',
  full_name='eolymp.universe.DeleteSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.DeleteSpaceInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=476,
)


_DELETESPACEOUTPUT = _descriptor.Descriptor(
  name='DeleteSpaceOutput',
  full_name='eolymp.universe.DeleteSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=497,
)


_LOOKUPSPACEINPUT = _descriptor.Descriptor(
  name='LookupSpaceInput',
  full_name='eolymp.universe.LookupSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.universe.LookupSpaceInput.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=530,
)


_LOOKUPSPACEOUTPUT = _descriptor.Descriptor(
  name='LookupSpaceOutput',
  full_name='eolymp.universe.LookupSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='eolymp.universe.LookupSpaceOutput.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=590,
)


_DESCRIBESPACEINPUT = _descriptor.Descriptor(
  name='DescribeSpaceInput',
  full_name='eolymp.universe.DescribeSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.DescribeSpaceInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=630,
)


_DESCRIBESPACEOUTPUT = _descriptor.Descriptor(
  name='DescribeSpaceOutput',
  full_name='eolymp.universe.DescribeSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='eolymp.universe.DescribeSpaceOutput.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=632,
  serialized_end=692,
)


_LISTSPACESINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.universe.ListSpacesInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.universe.ListSpacesInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.universe.ListSpacesInput.Filter.key', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.universe.ListSpacesInput.Filter.name', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=803,
  serialized_end=950,
)

_LISTSPACESINPUT = _descriptor.Descriptor(
  name='ListSpacesInput',
  full_name='eolymp.universe.ListSpacesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.universe.ListSpacesInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.universe.ListSpacesInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.universe.ListSpacesInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSPACESINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=695,
  serialized_end=950,
)


_LISTSPACESOUTPUT = _descriptor.Descriptor(
  name='ListSpacesOutput',
  full_name='eolymp.universe.ListSpacesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.universe.ListSpacesOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.universe.ListSpacesOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=952,
  serialized_end=1024,
)


_ADDMEMBERINPUT = _descriptor.Descriptor(
  name='AddMemberInput',
  full_name='eolymp.universe.AddMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.AddMemberInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.universe.AddMemberInput.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='eolymp.universe.AddMemberInput.role', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1026,
  serialized_end=1091,
)


_ADDMEMBEROUTPUT = _descriptor.Descriptor(
  name='AddMemberOutput',
  full_name='eolymp.universe.AddMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.universe.AddMemberOutput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1093,
  serialized_end=1129,
)


_UPDATEMEMBERINPUT = _descriptor.Descriptor(
  name='UpdateMemberInput',
  full_name='eolymp.universe.UpdateMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.universe.UpdateMemberInput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='eolymp.universe.UpdateMemberInput.role', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1131,
  serialized_end=1183,
)


_UPDATEMEMBEROUTPUT = _descriptor.Descriptor(
  name='UpdateMemberOutput',
  full_name='eolymp.universe.UpdateMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=1205,
)


_REMOVEMEMBERINPUT = _descriptor.Descriptor(
  name='RemoveMemberInput',
  full_name='eolymp.universe.RemoveMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.universe.RemoveMemberInput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1207,
  serialized_end=1245,
)


_REMOVEMEMBEROUTPUT = _descriptor.Descriptor(
  name='RemoveMemberOutput',
  full_name='eolymp.universe.RemoveMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1247,
  serialized_end=1267,
)


_DESCRIBEMEMBERINPUT = _descriptor.Descriptor(
  name='DescribeMemberInput',
  full_name='eolymp.universe.DescribeMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.universe.DescribeMemberInput.member_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1269,
  serialized_end=1309,
)


_DESCRIBEMEMBEROUTPUT = _descriptor.Descriptor(
  name='DescribeMemberOutput',
  full_name='eolymp.universe.DescribeMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.universe.DescribeMemberOutput.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1311,
  serialized_end=1374,
)


_INTROSPECTMEMBERINPUT = _descriptor.Descriptor(
  name='IntrospectMemberInput',
  full_name='eolymp.universe.IntrospectMemberInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.IntrospectMemberInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1376,
  serialized_end=1417,
)


_INTROSPECTMEMBEROUTPUT = _descriptor.Descriptor(
  name='IntrospectMemberOutput',
  full_name='eolymp.universe.IntrospectMemberOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.universe.IntrospectMemberOutput.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1419,
  serialized_end=1484,
)


_LISTMEMBERSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.universe.ListMembersInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.universe.ListMembersInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.universe.ListMembersInput.Filter.user_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='eolymp.universe.ListMembersInput.Filter.role', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='eolymp.universe.ListMembersInput.Filter.username', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1615,
  serialized_end=1818,
)

_LISTMEMBERSINPUT = _descriptor.Descriptor(
  name='ListMembersInput',
  full_name='eolymp.universe.ListMembersInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.ListMembersInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.universe.ListMembersInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.universe.ListMembersInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.universe.ListMembersInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMEMBERSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1487,
  serialized_end=1818,
)


_LISTMEMBERSOUTPUT = _descriptor.Descriptor(
  name='ListMembersOutput',
  full_name='eolymp.universe.ListMembersOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.universe.ListMembersOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.universe.ListMembersOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1820,
  serialized_end=1894,
)

_CREATESPACEINPUT.fields_by_name['space'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_UPDATESPACEINPUT.fields_by_name['space'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_LOOKUPSPACEOUTPUT.fields_by_name['space'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_DESCRIBESPACEOUTPUT.fields_by_name['space'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_LISTSPACESINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSPACESINPUT_FILTER.fields_by_name['key'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSPACESINPUT_FILTER.fields_by_name['name'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTSPACESINPUT_FILTER.containing_type = _LISTSPACESINPUT
_LISTSPACESINPUT.fields_by_name['filters'].message_type = _LISTSPACESINPUT_FILTER
_LISTSPACESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_DESCRIBEMEMBEROUTPUT.fields_by_name['member'].message_type = eolymp_dot_universe_dot_member__pb2._MEMBER
_INTROSPECTMEMBEROUTPUT.fields_by_name['member'].message_type = eolymp_dot_universe_dot_member__pb2._MEMBER
_LISTMEMBERSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTMEMBERSINPUT_FILTER.fields_by_name['user_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTMEMBERSINPUT_FILTER.fields_by_name['role'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTMEMBERSINPUT_FILTER.fields_by_name['username'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTMEMBERSINPUT_FILTER.containing_type = _LISTMEMBERSINPUT
_LISTMEMBERSINPUT.fields_by_name['filters'].message_type = _LISTMEMBERSINPUT_FILTER
_LISTMEMBERSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_universe_dot_member__pb2._MEMBER
DESCRIPTOR.message_types_by_name['CreateSpaceInput'] = _CREATESPACEINPUT
DESCRIPTOR.message_types_by_name['CreateSpaceOutput'] = _CREATESPACEOUTPUT
DESCRIPTOR.message_types_by_name['UpdateSpaceInput'] = _UPDATESPACEINPUT
DESCRIPTOR.message_types_by_name['UpdateSpaceOutput'] = _UPDATESPACEOUTPUT
DESCRIPTOR.message_types_by_name['DeleteSpaceInput'] = _DELETESPACEINPUT
DESCRIPTOR.message_types_by_name['DeleteSpaceOutput'] = _DELETESPACEOUTPUT
DESCRIPTOR.message_types_by_name['LookupSpaceInput'] = _LOOKUPSPACEINPUT
DESCRIPTOR.message_types_by_name['LookupSpaceOutput'] = _LOOKUPSPACEOUTPUT
DESCRIPTOR.message_types_by_name['DescribeSpaceInput'] = _DESCRIBESPACEINPUT
DESCRIPTOR.message_types_by_name['DescribeSpaceOutput'] = _DESCRIBESPACEOUTPUT
DESCRIPTOR.message_types_by_name['ListSpacesInput'] = _LISTSPACESINPUT
DESCRIPTOR.message_types_by_name['ListSpacesOutput'] = _LISTSPACESOUTPUT
DESCRIPTOR.message_types_by_name['AddMemberInput'] = _ADDMEMBERINPUT
DESCRIPTOR.message_types_by_name['AddMemberOutput'] = _ADDMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['UpdateMemberInput'] = _UPDATEMEMBERINPUT
DESCRIPTOR.message_types_by_name['UpdateMemberOutput'] = _UPDATEMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['RemoveMemberInput'] = _REMOVEMEMBERINPUT
DESCRIPTOR.message_types_by_name['RemoveMemberOutput'] = _REMOVEMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['DescribeMemberInput'] = _DESCRIBEMEMBERINPUT
DESCRIPTOR.message_types_by_name['DescribeMemberOutput'] = _DESCRIBEMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['IntrospectMemberInput'] = _INTROSPECTMEMBERINPUT
DESCRIPTOR.message_types_by_name['IntrospectMemberOutput'] = _INTROSPECTMEMBEROUTPUT
DESCRIPTOR.message_types_by_name['ListMembersInput'] = _LISTMEMBERSINPUT
DESCRIPTOR.message_types_by_name['ListMembersOutput'] = _LISTMEMBERSOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSpaceInput = _reflection.GeneratedProtocolMessageType('CreateSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.CreateSpaceInput)
  })
_sym_db.RegisterMessage(CreateSpaceInput)

CreateSpaceOutput = _reflection.GeneratedProtocolMessageType('CreateSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.CreateSpaceOutput)
  })
_sym_db.RegisterMessage(CreateSpaceOutput)

UpdateSpaceInput = _reflection.GeneratedProtocolMessageType('UpdateSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.UpdateSpaceInput)
  })
_sym_db.RegisterMessage(UpdateSpaceInput)

UpdateSpaceOutput = _reflection.GeneratedProtocolMessageType('UpdateSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.UpdateSpaceOutput)
  })
_sym_db.RegisterMessage(UpdateSpaceOutput)

DeleteSpaceInput = _reflection.GeneratedProtocolMessageType('DeleteSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DeleteSpaceInput)
  })
_sym_db.RegisterMessage(DeleteSpaceInput)

DeleteSpaceOutput = _reflection.GeneratedProtocolMessageType('DeleteSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DeleteSpaceOutput)
  })
_sym_db.RegisterMessage(DeleteSpaceOutput)

LookupSpaceInput = _reflection.GeneratedProtocolMessageType('LookupSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPSPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.LookupSpaceInput)
  })
_sym_db.RegisterMessage(LookupSpaceInput)

LookupSpaceOutput = _reflection.GeneratedProtocolMessageType('LookupSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPSPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.LookupSpaceOutput)
  })
_sym_db.RegisterMessage(LookupSpaceOutput)

DescribeSpaceInput = _reflection.GeneratedProtocolMessageType('DescribeSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribeSpaceInput)
  })
_sym_db.RegisterMessage(DescribeSpaceInput)

DescribeSpaceOutput = _reflection.GeneratedProtocolMessageType('DescribeSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribeSpaceOutput)
  })
_sym_db.RegisterMessage(DescribeSpaceOutput)

ListSpacesInput = _reflection.GeneratedProtocolMessageType('ListSpacesInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTSPACESINPUT_FILTER,
    '__module__' : 'eolymp.universe.universe_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.universe.ListSpacesInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTSPACESINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.ListSpacesInput)
  })
_sym_db.RegisterMessage(ListSpacesInput)
_sym_db.RegisterMessage(ListSpacesInput.Filter)

ListSpacesOutput = _reflection.GeneratedProtocolMessageType('ListSpacesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSPACESOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.ListSpacesOutput)
  })
_sym_db.RegisterMessage(ListSpacesOutput)

AddMemberInput = _reflection.GeneratedProtocolMessageType('AddMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _ADDMEMBERINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.AddMemberInput)
  })
_sym_db.RegisterMessage(AddMemberInput)

AddMemberOutput = _reflection.GeneratedProtocolMessageType('AddMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _ADDMEMBEROUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.AddMemberOutput)
  })
_sym_db.RegisterMessage(AddMemberOutput)

UpdateMemberInput = _reflection.GeneratedProtocolMessageType('UpdateMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEMBERINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.UpdateMemberInput)
  })
_sym_db.RegisterMessage(UpdateMemberInput)

UpdateMemberOutput = _reflection.GeneratedProtocolMessageType('UpdateMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEMBEROUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.UpdateMemberOutput)
  })
_sym_db.RegisterMessage(UpdateMemberOutput)

RemoveMemberInput = _reflection.GeneratedProtocolMessageType('RemoveMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEMEMBERINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.RemoveMemberInput)
  })
_sym_db.RegisterMessage(RemoveMemberInput)

RemoveMemberOutput = _reflection.GeneratedProtocolMessageType('RemoveMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEMEMBEROUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.RemoveMemberOutput)
  })
_sym_db.RegisterMessage(RemoveMemberOutput)

DescribeMemberInput = _reflection.GeneratedProtocolMessageType('DescribeMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEMEMBERINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribeMemberInput)
  })
_sym_db.RegisterMessage(DescribeMemberInput)

DescribeMemberOutput = _reflection.GeneratedProtocolMessageType('DescribeMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEMEMBEROUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribeMemberOutput)
  })
_sym_db.RegisterMessage(DescribeMemberOutput)

IntrospectMemberInput = _reflection.GeneratedProtocolMessageType('IntrospectMemberInput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTMEMBERINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.IntrospectMemberInput)
  })
_sym_db.RegisterMessage(IntrospectMemberInput)

IntrospectMemberOutput = _reflection.GeneratedProtocolMessageType('IntrospectMemberOutput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTMEMBEROUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.IntrospectMemberOutput)
  })
_sym_db.RegisterMessage(IntrospectMemberOutput)

ListMembersInput = _reflection.GeneratedProtocolMessageType('ListMembersInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTMEMBERSINPUT_FILTER,
    '__module__' : 'eolymp.universe.universe_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.universe.ListMembersInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTMEMBERSINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.ListMembersInput)
  })
_sym_db.RegisterMessage(ListMembersInput)
_sym_db.RegisterMessage(ListMembersInput.Filter)

ListMembersOutput = _reflection.GeneratedProtocolMessageType('ListMembersOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEMBERSOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.ListMembersOutput)
  })
_sym_db.RegisterMessage(ListMembersOutput)


DESCRIPTOR._options = None

_UNIVERSE = _descriptor.ServiceDescriptor(
  name='Universe',
  full_name='eolymp.universe.Universe',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1897,
  serialized_end=3975,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateSpace',
    full_name='eolymp.universe.Universe.CreateSpace',
    index=0,
    containing_service=None,
    input_type=_CREATESPACEINPUT,
    output_type=_CREATESPACEOUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\025\"\020/universe/spacesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSpace',
    full_name='eolymp.universe.Universe.UpdateSpace',
    index=1,
    containing_service=None,
    input_type=_UPDATESPACEINPUT,
    output_type=_UPDATESPACEOUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\035\032\033/universe/spaces/{space_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSpace',
    full_name='eolymp.universe.Universe.DeleteSpace',
    index=2,
    containing_service=None,
    input_type=_DELETESPACEINPUT,
    output_type=_DELETESPACEOUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\035*\033/universe/spaces/{space_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LookupSpace',
    full_name='eolymp.universe.Universe.LookupSpace',
    index=3,
    containing_service=None,
    input_type=_LOOKUPSPACEINPUT,
    output_type=_LOOKUPSPACEOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002%\022\034/universe/space-lookup/{key}b\005space',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeSpace',
    full_name='eolymp.universe.Universe.DescribeSpace',
    index=4,
    containing_service=None,
    input_type=_DESCRIBESPACEINPUT,
    output_type=_DESCRIBESPACEOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002$\022\033/universe/spaces/{space_id}b\005space',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListSpaces',
    full_name='eolymp.universe.Universe.ListSpaces',
    index=5,
    containing_service=None,
    input_type=_LISTSPACESINPUT,
    output_type=_LISTSPACESOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\025\022\020/universe/spacesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddMember',
    full_name='eolymp.universe.Universe.AddMember',
    index=6,
    containing_service=None,
    input_type=_ADDMEMBERINPUT,
    output_type=_ADDMEMBEROUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0022\032-/universe/spaces/{space_id}/members/{user_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMember',
    full_name='eolymp.universe.Universe.UpdateMember',
    index=7,
    containing_service=None,
    input_type=_UPDATEMEMBERINPUT,
    output_type=_UPDATEMEMBEROUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\"\032\035/universe/members/{member_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveMember',
    full_name='eolymp.universe.Universe.RemoveMember',
    index=8,
    containing_service=None,
    input_type=_REMOVEMEMBERINPUT,
    output_type=_REMOVEMEMBEROUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\"*\035/universe/members/{member_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeMember',
    full_name='eolymp.universe.Universe.DescribeMember',
    index=9,
    containing_service=None,
    input_type=_DESCRIBEMEMBERINPUT,
    output_type=_DESCRIBEMEMBEROUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\'\022\035/universe/members/{member_id}b\006member',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IntrospectMember',
    full_name='eolymp.universe.Universe.IntrospectMember',
    index=10,
    containing_service=None,
    input_type=_INTROSPECTMEMBERINPUT,
    output_type=_INTROSPECTMEMBEROUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0020\022&/universe/spaces/{space_id}/introspectb\006member',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMembers',
    full_name='eolymp.universe.Universe.ListMembers',
    index=11,
    containing_service=None,
    input_type=_LISTMEMBERSINPUT,
    output_type=_LISTMEMBERSOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002(\022#/universe/spaces/{space_id}/membersb\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_UNIVERSE)

DESCRIPTOR.services_by_name['Universe'] = _UNIVERSE

# @@protoc_insertion_point(module_scope)
