# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/interactor.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/executor/interactor.proto',
  package='eolymp.executor',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/executor;executor',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n eolymp/executor/interactor.proto\x12\x0f\x65olymp.executor\"y\n\nInteractor\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .eolymp.executor.Interactor.Type\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"\x1d\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PROGRAM\x10\x01\x42\x39Z7github.com/eolymp/contracts/go/eolymp/executor;executorb\x06proto3'
)



_INTERACTOR_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.executor.Interactor.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROGRAM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=145,
  serialized_end=174,
)
_sym_db.RegisterEnumDescriptor(_INTERACTOR_TYPE)


_INTERACTOR = _descriptor.Descriptor(
  name='Interactor',
  full_name='eolymp.executor.Interactor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.executor.Interactor.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.executor.Interactor.lang', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.executor.Interactor.source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INTERACTOR_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=174,
)

_INTERACTOR.fields_by_name['type'].enum_type = _INTERACTOR_TYPE
_INTERACTOR_TYPE.containing_type = _INTERACTOR
DESCRIPTOR.message_types_by_name['Interactor'] = _INTERACTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Interactor = _reflection.GeneratedProtocolMessageType('Interactor', (_message.Message,), {
  'DESCRIPTOR' : _INTERACTOR,
  '__module__' : 'eolymp.executor.interactor_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.Interactor)
  })
_sym_db.RegisterMessage(Interactor)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
