# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/task.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import interactor_pb2 as eolymp_dot_executor_dot_interactor__pb2
from eolymp.executor import verifier_pb2 as eolymp_dot_executor_dot_verifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/executor/task.proto',
  package='eolymp.executor',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/executor;executor',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/executor/task.proto\x12\x0f\x65olymp.executor\x1a eolymp/executor/interactor.proto\x1a\x1e\x65olymp/executor/verifier.proto\"\xdb\x06\n\x04Task\x12\x11\n\treference\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\r\x12\r\n\x04lang\x18\xe8\x07 \x01(\t\x12\x0f\n\x07runtime\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x13\n\x0buse_file_io\x18\x0c \x01(\x08\x12!\n\x19redirect_stderr_to_stdout\x18\r \x01(\x08\x12\x39\n\rpreconditions\x18( \x03(\x0b\x32\".eolymp.executor.Task.Precondition\x12\x35\n\x0b\x63onstraints\x18\x14 \x03(\x0b\x32 .eolymp.executor.Task.Constraint\x12+\n\x08verifier\x18\x18 \x01(\x0b\x32\x19.eolymp.executor.Verifier\x12/\n\ninteractor\x18\x19 \x01(\x0b\x32\x1b.eolymp.executor.Interactor\x12\'\n\x04runs\x18\x1e \x03(\x0b\x32\x19.eolymp.executor.Task.Run\x1a\xd1\x01\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\x12\r\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\x12\x0c\n\x04\x63ost\x18\x04 \x01(\x02\x12\x0e\n\x06labels\x18\x1e \x03(\t\x12\x19\n\x0finput_object_id\x18\n \x01(\tH\x00\x12\x17\n\rinput_content\x18\x0b \x01(\tH\x00\x12\x1a\n\x10\x61nswer_object_id\x18\x14 \x01(\tH\x01\x12\x18\n\x0e\x61nswer_content\x18\x15 \x01(\tH\x01\x42\x07\n\x05inputB\x08\n\x06\x61nswer\x1ai\n\x0cPrecondition\x12\x10\n\x08selector\x18\x01 \x03(\t\x12\x12\n\ndepends_on\x18\n \x03(\t\x12\x17\n\x0fstop_on_failure\x18\x0b \x01(\x08\x12\x1a\n\x12max_execution_time\x18\x0c \x01(\r\x1a~\n\nConstraint\x12\x10\n\x08selector\x18\x01 \x03(\t\x12\x17\n\x0fwall_time_limit\x18\n \x01(\r\x12\x16\n\x0e\x63pu_time_limit\x18\x0b \x01(\r\x12\x14\n\x0cmemory_limit\x18\x0c \x01(\x04\x12\x17\n\x0f\x66ile_size_limit\x18\r \x01(\x04\x42\x39Z7github.com/eolymp/contracts/go/eolymp/executor;executorb\x06proto3'
  ,
  dependencies=[eolymp_dot_executor_dot_interactor__pb2.DESCRIPTOR,eolymp_dot_executor_dot_verifier__pb2.DESCRIPTOR,])




_TASK_RUN = _descriptor.Descriptor(
  name='Run',
  full_name='eolymp.executor.Task.Run',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='eolymp.executor.Task.Run.reference', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.executor.Task.Run.index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug', full_name='eolymp.executor.Task.Run.debug', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='eolymp.executor.Task.Run.cost', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='eolymp.executor.Task.Run.labels', index=4,
      number=30, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_object_id', full_name='eolymp.executor.Task.Run.input_object_id', index=5,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_content', full_name='eolymp.executor.Task.Run.input_content', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer_object_id', full_name='eolymp.executor.Task.Run.answer_object_id', index=7,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer_content', full_name='eolymp.executor.Task.Run.answer_content', index=8,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='input', full_name='eolymp.executor.Task.Run.input',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='answer', full_name='eolymp.executor.Task.Run.answer',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=529,
  serialized_end=738,
)

_TASK_PRECONDITION = _descriptor.Descriptor(
  name='Precondition',
  full_name='eolymp.executor.Task.Precondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='eolymp.executor.Task.Precondition.selector', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depends_on', full_name='eolymp.executor.Task.Precondition.depends_on', index=1,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_on_failure', full_name='eolymp.executor.Task.Precondition.stop_on_failure', index=2,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_execution_time', full_name='eolymp.executor.Task.Precondition.max_execution_time', index=3,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=740,
  serialized_end=845,
)

_TASK_CONSTRAINT = _descriptor.Descriptor(
  name='Constraint',
  full_name='eolymp.executor.Task.Constraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='eolymp.executor.Task.Constraint.selector', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wall_time_limit', full_name='eolymp.executor.Task.Constraint.wall_time_limit', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_time_limit', full_name='eolymp.executor.Task.Constraint.cpu_time_limit', index=2,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_limit', full_name='eolymp.executor.Task.Constraint.memory_limit', index=3,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size_limit', full_name='eolymp.executor.Task.Constraint.file_size_limit', index=4,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=847,
  serialized_end=973,
)

_TASK = _descriptor.Descriptor(
  name='Task',
  full_name='eolymp.executor.Task',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='eolymp.executor.Task.reference', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin', full_name='eolymp.executor.Task.origin', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='eolymp.executor.Task.priority', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.executor.Task.lang', index=3,
      number=1000, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime', full_name='eolymp.executor.Task.runtime', index=4,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.executor.Task.source', index=5,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_file_io', full_name='eolymp.executor.Task.use_file_io', index=6,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_stderr_to_stdout', full_name='eolymp.executor.Task.redirect_stderr_to_stdout', index=7,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preconditions', full_name='eolymp.executor.Task.preconditions', index=8,
      number=40, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='eolymp.executor.Task.constraints', index=9,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verifier', full_name='eolymp.executor.Task.verifier', index=10,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interactor', full_name='eolymp.executor.Task.interactor', index=11,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runs', full_name='eolymp.executor.Task.runs', index=12,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TASK_RUN, _TASK_PRECONDITION, _TASK_CONSTRAINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=973,
)

_TASK_RUN.containing_type = _TASK
_TASK_RUN.oneofs_by_name['input'].fields.append(
  _TASK_RUN.fields_by_name['input_object_id'])
_TASK_RUN.fields_by_name['input_object_id'].containing_oneof = _TASK_RUN.oneofs_by_name['input']
_TASK_RUN.oneofs_by_name['input'].fields.append(
  _TASK_RUN.fields_by_name['input_content'])
_TASK_RUN.fields_by_name['input_content'].containing_oneof = _TASK_RUN.oneofs_by_name['input']
_TASK_RUN.oneofs_by_name['answer'].fields.append(
  _TASK_RUN.fields_by_name['answer_object_id'])
_TASK_RUN.fields_by_name['answer_object_id'].containing_oneof = _TASK_RUN.oneofs_by_name['answer']
_TASK_RUN.oneofs_by_name['answer'].fields.append(
  _TASK_RUN.fields_by_name['answer_content'])
_TASK_RUN.fields_by_name['answer_content'].containing_oneof = _TASK_RUN.oneofs_by_name['answer']
_TASK_PRECONDITION.containing_type = _TASK
_TASK_CONSTRAINT.containing_type = _TASK
_TASK.fields_by_name['preconditions'].message_type = _TASK_PRECONDITION
_TASK.fields_by_name['constraints'].message_type = _TASK_CONSTRAINT
_TASK.fields_by_name['verifier'].message_type = eolymp_dot_executor_dot_verifier__pb2._VERIFIER
_TASK.fields_by_name['interactor'].message_type = eolymp_dot_executor_dot_interactor__pb2._INTERACTOR
_TASK.fields_by_name['runs'].message_type = _TASK_RUN
DESCRIPTOR.message_types_by_name['Task'] = _TASK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Task = _reflection.GeneratedProtocolMessageType('Task', (_message.Message,), {

  'Run' : _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
    'DESCRIPTOR' : _TASK_RUN,
    '__module__' : 'eolymp.executor.task_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.executor.Task.Run)
    })
  ,

  'Precondition' : _reflection.GeneratedProtocolMessageType('Precondition', (_message.Message,), {
    'DESCRIPTOR' : _TASK_PRECONDITION,
    '__module__' : 'eolymp.executor.task_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.executor.Task.Precondition)
    })
  ,

  'Constraint' : _reflection.GeneratedProtocolMessageType('Constraint', (_message.Message,), {
    'DESCRIPTOR' : _TASK_CONSTRAINT,
    '__module__' : 'eolymp.executor.task_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.executor.Task.Constraint)
    })
  ,
  'DESCRIPTOR' : _TASK,
  '__module__' : 'eolymp.executor.task_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.Task)
  })
_sym_db.RegisterMessage(Task)
_sym_db.RegisterMessage(Task.Run)
_sym_db.RegisterMessage(Task.Precondition)
_sym_db.RegisterMessage(Task.Constraint)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
