# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/scoring.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/scoring.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/atlas/scoring.proto\x12\x0c\x65olymp.atlas*.\n\x0bScoringMode\x12\x0c\n\x08NO_SCORE\x10\x00\x12\x08\n\x04\x45\x41\x43H\x10\x01\x12\x07\n\x03\x41LL\x10\x02\x42\x33Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
)

_SCORINGMODE = _descriptor.EnumDescriptor(
  name='ScoringMode',
  full_name='eolymp.atlas.ScoringMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_SCORE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EACH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=44,
  serialized_end=90,
)
_sym_db.RegisterEnumDescriptor(_SCORINGMODE)

ScoringMode = enum_type_wrapper.EnumTypeWrapper(_SCORINGMODE)
NO_SCORE = 0
EACH = 1
ALL = 2


DESCRIPTOR.enum_types_by_name['ScoringMode'] = _SCORINGMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
