# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/entitlement.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/cognito/entitlement.proto',
  package='eolymp.cognito',
  syntax='proto3',
  serialized_options=b'Z5github.com/eolymp/contracts/go/eolymp/cognito;cognito',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n eolymp/cognito/entitlement.proto\x12\x0e\x65olymp.cognito*z\n\x0b\x45ntitlement\x12\x17\n\x13VIEW_PUBLIC_PROFILE\x10\x00\x12\x18\n\x14VIEW_BLOCKED_PROFILE\x10\x01\x12\x15\n\x11VIEW_PRIVATE_DATA\x10\x02\x12\x10\n\x0cMANAGE_ROLES\x10\x03\x12\x0f\n\x0b\x42LOCK_USERS\x10\x04\x42\x37Z5github.com/eolymp/contracts/go/eolymp/cognito;cognitob\x06proto3'
)

_ENTITLEMENT = _descriptor.EnumDescriptor(
  name='Entitlement',
  full_name='eolymp.cognito.Entitlement',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VIEW_PUBLIC_PROFILE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_BLOCKED_PROFILE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_PRIVATE_DATA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_ROLES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCK_USERS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=52,
  serialized_end=174,
)
_sym_db.RegisterEnumDescriptor(_ENTITLEMENT)

Entitlement = enum_type_wrapper.EnumTypeWrapper(_ENTITLEMENT)
VIEW_PUBLIC_PROFILE = 0
VIEW_BLOCKED_PROFILE = 1
VIEW_PRIVATE_DATA = 2
MANAGE_ROLES = 3
BLOCK_USERS = 4


DESCRIPTOR.enum_types_by_name['Entitlement'] = _ENTITLEMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
