# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ranker/ranker.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.ranker import scoreboard_pb2 as eolymp_dot_ranker_dot_scoreboard__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/ranker/ranker.proto',
  package='eolymp.ranker',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/ranker;ranker',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/ranker/ranker.proto\x12\reolymp.ranker\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1e\x65olymp/ranker/scoreboard.proto\"F\n\x15\x43reateScoreboardInput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"/\n\x16\x43reateScoreboardOutput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"]\n\x15UpdateScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12-\n\nscoreboard\x18\x02 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\x18\n\x16UpdateScoreboardOutput\"/\n\x16RebuildScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x19\n\x17RebuildScoreboardOutput\"_\n\x12\x41ssignContestInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x32\n\x07\x63ontest\x18\x02 \x01(\x0b\x32!.eolymp.ranker.Scoreboard.Contest\"\x15\n\x13\x41ssignContestOutput\"A\n\x14UnassignContestInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x12\n\ncontest_id\x18\x02 \x01(\t\"\x17\n\x15UnassignContestOutput\".\n\x15\x44\x65leteScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteScoreboardOutput\"$\n\x15LookupScoreboardInput\x12\x0b\n\x03key\x18\x01 \x01(\t\"G\n\x16LookupScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"0\n\x17\x44\x65scribeScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"I\n\x18\x44\x65scribeScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\xa7\x01\n\x14ListScoreboardsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.ranker.ListScoreboardsInput.Filter\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"P\n\x15ListScoreboardsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.ranker.Scoreboard\"0\n\x17ListScoreboardRowsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"W\n\x18ListScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row2\xe0\x0e\n\x06Ranker\x12\xad\x01\n\x10\x43reateScoreboard\x12$.eolymp.ranker.CreateScoreboardInput\x1a%.eolymp.ranker.CreateScoreboardOutput\"L\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18\"\x13/ranker/scoreboardsb\x01*\x12\xba\x01\n\x10UpdateScoreboard\x12$.eolymp.ranker.UpdateScoreboardInput\x1a%.eolymp.ranker.UpdateScoreboardOutput\"Y\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02%\x1a#/ranker/scoreboards/{scoreboard_id}\x12\xc5\x01\n\x11RebuildScoreboard\x12%.eolymp.ranker.RebuildScoreboardInput\x1a&.eolymp.ranker.RebuildScoreboardOutput\"a\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02-\"+/ranker/scoreboards/{scoreboard_id}/rebuild\x12\xba\x01\n\x10\x44\x65leteScoreboard\x12$.eolymp.ranker.DeleteScoreboardInput\x1a%.eolymp.ranker.DeleteScoreboardOutput\"Y\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02%*#/ranker/scoreboards/{scoreboard_id}\x12\xa3\x01\n\x10LookupScoreboard\x12$.eolymp.ranker.LookupScoreboardInput\x1a%.eolymp.ranker.LookupScoreboardOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02-\x12\x1f/ranker/scoreboard-lookup/{key}b\nscoreboard\x12\xcb\x01\n\x12\x44\x65scribeScoreboard\x12&.eolymp.ranker.DescribeScoreboardInput\x1a\'.eolymp.ranker.DescribeScoreboardOutput\"d\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x31\x12#/ranker/scoreboards/{scoreboard_id}b\nscoreboard\x12\xa9\x01\n\x0fListScoreboards\x12#.eolymp.ranker.ListScoreboardsInput\x1a$.eolymp.ranker.ListScoreboardsOutput\"K\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x18\x12\x13/ranker/scoreboardsb\x01*\x12\xa9\x01\n\x12ListScoreboardRows\x12&.eolymp.ranker.ListScoreboardRowsInput\x1a\'.eolymp.ranker.ListScoreboardRowsOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02-\x12(/ranker/scoreboards/{scoreboard_id}/rowsb\x01*\x12\xc7\x01\n\rAssignContest\x12!.eolymp.ranker.AssignContestInput\x1a\".eolymp.ranker.AssignContestOutput\"o\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02;\x1a\x39/ranker/scoreboards/{scoreboard_id}/contests/{contest_id}\x12\xcd\x01\n\x0fUnassignContest\x12#.eolymp.ranker.UnassignContestInput\x1a$.eolymp.ranker.UnassignContestOutput\"o\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02;*9/ranker/scoreboards/{scoreboard_id}/contests/{contest_id}B5Z3github.com/eolymp/contracts/go/eolymp/ranker;rankerb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_ranker_dot_scoreboard__pb2.DESCRIPTOR,])




_CREATESCOREBOARDINPUT = _descriptor.Descriptor(
  name='CreateScoreboardInput',
  full_name='eolymp.ranker.CreateScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.ranker.CreateScoreboardInput.scoreboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=281,
)


_CREATESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='CreateScoreboardOutput',
  full_name='eolymp.ranker.CreateScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.CreateScoreboardOutput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=330,
)


_UPDATESCOREBOARDINPUT = _descriptor.Descriptor(
  name='UpdateScoreboardInput',
  full_name='eolymp.ranker.UpdateScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.UpdateScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.ranker.UpdateScoreboardInput.scoreboard', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=425,
)


_UPDATESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='UpdateScoreboardOutput',
  full_name='eolymp.ranker.UpdateScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=451,
)


_REBUILDSCOREBOARDINPUT = _descriptor.Descriptor(
  name='RebuildScoreboardInput',
  full_name='eolymp.ranker.RebuildScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.RebuildScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=500,
)


_REBUILDSCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='RebuildScoreboardOutput',
  full_name='eolymp.ranker.RebuildScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=527,
)


_ASSIGNCONTESTINPUT = _descriptor.Descriptor(
  name='AssignContestInput',
  full_name='eolymp.ranker.AssignContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.AssignContestInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest', full_name='eolymp.ranker.AssignContestInput.contest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=624,
)


_ASSIGNCONTESTOUTPUT = _descriptor.Descriptor(
  name='AssignContestOutput',
  full_name='eolymp.ranker.AssignContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=647,
)


_UNASSIGNCONTESTINPUT = _descriptor.Descriptor(
  name='UnassignContestInput',
  full_name='eolymp.ranker.UnassignContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.UnassignContestInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.ranker.UnassignContestInput.contest_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=714,
)


_UNASSIGNCONTESTOUTPUT = _descriptor.Descriptor(
  name='UnassignContestOutput',
  full_name='eolymp.ranker.UnassignContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=716,
  serialized_end=739,
)


_DELETESCOREBOARDINPUT = _descriptor.Descriptor(
  name='DeleteScoreboardInput',
  full_name='eolymp.ranker.DeleteScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.DeleteScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=787,
)


_DELETESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='DeleteScoreboardOutput',
  full_name='eolymp.ranker.DeleteScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=789,
  serialized_end=813,
)


_LOOKUPSCOREBOARDINPUT = _descriptor.Descriptor(
  name='LookupScoreboardInput',
  full_name='eolymp.ranker.LookupScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.ranker.LookupScoreboardInput.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=815,
  serialized_end=851,
)


_LOOKUPSCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='LookupScoreboardOutput',
  full_name='eolymp.ranker.LookupScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.ranker.LookupScoreboardOutput.scoreboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=924,
)


_DESCRIBESCOREBOARDINPUT = _descriptor.Descriptor(
  name='DescribeScoreboardInput',
  full_name='eolymp.ranker.DescribeScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.DescribeScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=926,
  serialized_end=974,
)


_DESCRIBESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='DescribeScoreboardOutput',
  full_name='eolymp.ranker.DescribeScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.ranker.DescribeScoreboardOutput.scoreboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=976,
  serialized_end=1049,
)


_LISTSCOREBOARDSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.ranker.ListScoreboardsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.ranker.ListScoreboardsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1167,
  serialized_end=1219,
)

_LISTSCOREBOARDSINPUT = _descriptor.Descriptor(
  name='ListScoreboardsInput',
  full_name='eolymp.ranker.ListScoreboardsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.ranker.ListScoreboardsInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.ranker.ListScoreboardsInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.ranker.ListScoreboardsInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSCOREBOARDSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1052,
  serialized_end=1219,
)


_LISTSCOREBOARDSOUTPUT = _descriptor.Descriptor(
  name='ListScoreboardsOutput',
  full_name='eolymp.ranker.ListScoreboardsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.ranker.ListScoreboardsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.ranker.ListScoreboardsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1221,
  serialized_end=1301,
)


_LISTSCOREBOARDROWSINPUT = _descriptor.Descriptor(
  name='ListScoreboardRowsInput',
  full_name='eolymp.ranker.ListScoreboardRowsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.ListScoreboardRowsInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1303,
  serialized_end=1351,
)


_LISTSCOREBOARDROWSOUTPUT = _descriptor.Descriptor(
  name='ListScoreboardRowsOutput',
  full_name='eolymp.ranker.ListScoreboardRowsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.ranker.ListScoreboardRowsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.ranker.ListScoreboardRowsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1353,
  serialized_end=1440,
)

_CREATESCOREBOARDINPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_UPDATESCOREBOARDINPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_ASSIGNCONTESTINPUT.fields_by_name['contest'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD_CONTEST
_LOOKUPSCOREBOARDOUTPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_DESCRIBESCOREBOARDOUTPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_LISTSCOREBOARDSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSCOREBOARDSINPUT_FILTER.containing_type = _LISTSCOREBOARDSINPUT
_LISTSCOREBOARDSINPUT.fields_by_name['filters'].message_type = _LISTSCOREBOARDSINPUT_FILTER
_LISTSCOREBOARDSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_LISTSCOREBOARDROWSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD_ROW
DESCRIPTOR.message_types_by_name['CreateScoreboardInput'] = _CREATESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['CreateScoreboardOutput'] = _CREATESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['UpdateScoreboardInput'] = _UPDATESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['UpdateScoreboardOutput'] = _UPDATESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['RebuildScoreboardInput'] = _REBUILDSCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['RebuildScoreboardOutput'] = _REBUILDSCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['AssignContestInput'] = _ASSIGNCONTESTINPUT
DESCRIPTOR.message_types_by_name['AssignContestOutput'] = _ASSIGNCONTESTOUTPUT
DESCRIPTOR.message_types_by_name['UnassignContestInput'] = _UNASSIGNCONTESTINPUT
DESCRIPTOR.message_types_by_name['UnassignContestOutput'] = _UNASSIGNCONTESTOUTPUT
DESCRIPTOR.message_types_by_name['DeleteScoreboardInput'] = _DELETESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['DeleteScoreboardOutput'] = _DELETESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['LookupScoreboardInput'] = _LOOKUPSCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['LookupScoreboardOutput'] = _LOOKUPSCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardInput'] = _DESCRIBESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardOutput'] = _DESCRIBESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['ListScoreboardsInput'] = _LISTSCOREBOARDSINPUT
DESCRIPTOR.message_types_by_name['ListScoreboardsOutput'] = _LISTSCOREBOARDSOUTPUT
DESCRIPTOR.message_types_by_name['ListScoreboardRowsInput'] = _LISTSCOREBOARDROWSINPUT
DESCRIPTOR.message_types_by_name['ListScoreboardRowsOutput'] = _LISTSCOREBOARDROWSOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateScoreboardInput = _reflection.GeneratedProtocolMessageType('CreateScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.CreateScoreboardInput)
  })
_sym_db.RegisterMessage(CreateScoreboardInput)

CreateScoreboardOutput = _reflection.GeneratedProtocolMessageType('CreateScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.CreateScoreboardOutput)
  })
_sym_db.RegisterMessage(CreateScoreboardOutput)

UpdateScoreboardInput = _reflection.GeneratedProtocolMessageType('UpdateScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.UpdateScoreboardInput)
  })
_sym_db.RegisterMessage(UpdateScoreboardInput)

UpdateScoreboardOutput = _reflection.GeneratedProtocolMessageType('UpdateScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.UpdateScoreboardOutput)
  })
_sym_db.RegisterMessage(UpdateScoreboardOutput)

RebuildScoreboardInput = _reflection.GeneratedProtocolMessageType('RebuildScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDSCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.RebuildScoreboardInput)
  })
_sym_db.RegisterMessage(RebuildScoreboardInput)

RebuildScoreboardOutput = _reflection.GeneratedProtocolMessageType('RebuildScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDSCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.RebuildScoreboardOutput)
  })
_sym_db.RegisterMessage(RebuildScoreboardOutput)

AssignContestInput = _reflection.GeneratedProtocolMessageType('AssignContestInput', (_message.Message,), {
  'DESCRIPTOR' : _ASSIGNCONTESTINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.AssignContestInput)
  })
_sym_db.RegisterMessage(AssignContestInput)

AssignContestOutput = _reflection.GeneratedProtocolMessageType('AssignContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _ASSIGNCONTESTOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.AssignContestOutput)
  })
_sym_db.RegisterMessage(AssignContestOutput)

UnassignContestInput = _reflection.GeneratedProtocolMessageType('UnassignContestInput', (_message.Message,), {
  'DESCRIPTOR' : _UNASSIGNCONTESTINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.UnassignContestInput)
  })
_sym_db.RegisterMessage(UnassignContestInput)

UnassignContestOutput = _reflection.GeneratedProtocolMessageType('UnassignContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _UNASSIGNCONTESTOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.UnassignContestOutput)
  })
_sym_db.RegisterMessage(UnassignContestOutput)

DeleteScoreboardInput = _reflection.GeneratedProtocolMessageType('DeleteScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DeleteScoreboardInput)
  })
_sym_db.RegisterMessage(DeleteScoreboardInput)

DeleteScoreboardOutput = _reflection.GeneratedProtocolMessageType('DeleteScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DeleteScoreboardOutput)
  })
_sym_db.RegisterMessage(DeleteScoreboardOutput)

LookupScoreboardInput = _reflection.GeneratedProtocolMessageType('LookupScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPSCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.LookupScoreboardInput)
  })
_sym_db.RegisterMessage(LookupScoreboardInput)

LookupScoreboardOutput = _reflection.GeneratedProtocolMessageType('LookupScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPSCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.LookupScoreboardOutput)
  })
_sym_db.RegisterMessage(LookupScoreboardOutput)

DescribeScoreboardInput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DescribeScoreboardInput)
  })
_sym_db.RegisterMessage(DescribeScoreboardInput)

DescribeScoreboardOutput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DescribeScoreboardOutput)
  })
_sym_db.RegisterMessage(DescribeScoreboardOutput)

ListScoreboardsInput = _reflection.GeneratedProtocolMessageType('ListScoreboardsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTSCOREBOARDSINPUT_FILTER,
    '__module__' : 'eolymp.ranker.ranker_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTSCOREBOARDSINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardsInput)
  })
_sym_db.RegisterMessage(ListScoreboardsInput)
_sym_db.RegisterMessage(ListScoreboardsInput.Filter)

ListScoreboardsOutput = _reflection.GeneratedProtocolMessageType('ListScoreboardsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCOREBOARDSOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardsOutput)
  })
_sym_db.RegisterMessage(ListScoreboardsOutput)

ListScoreboardRowsInput = _reflection.GeneratedProtocolMessageType('ListScoreboardRowsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCOREBOARDROWSINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardRowsInput)
  })
_sym_db.RegisterMessage(ListScoreboardRowsInput)

ListScoreboardRowsOutput = _reflection.GeneratedProtocolMessageType('ListScoreboardRowsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCOREBOARDROWSOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardRowsOutput)
  })
_sym_db.RegisterMessage(ListScoreboardRowsOutput)


DESCRIPTOR._options = None

_RANKER = _descriptor.ServiceDescriptor(
  name='Ranker',
  full_name='eolymp.ranker.Ranker',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1443,
  serialized_end=3331,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateScoreboard',
    full_name='eolymp.ranker.Ranker.CreateScoreboard',
    index=0,
    containing_service=None,
    input_type=_CREATESCOREBOARDINPUT,
    output_type=_CREATESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\030\"\023/ranker/scoreboardsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateScoreboard',
    full_name='eolymp.ranker.Ranker.UpdateScoreboard',
    index=1,
    containing_service=None,
    input_type=_UPDATESCOREBOARDINPUT,
    output_type=_UPDATESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002%\032#/ranker/scoreboards/{scoreboard_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RebuildScoreboard',
    full_name='eolymp.ranker.Ranker.RebuildScoreboard',
    index=2,
    containing_service=None,
    input_type=_REBUILDSCOREBOARDINPUT,
    output_type=_REBUILDSCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002-\"+/ranker/scoreboards/{scoreboard_id}/rebuild',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteScoreboard',
    full_name='eolymp.ranker.Ranker.DeleteScoreboard',
    index=3,
    containing_service=None,
    input_type=_DELETESCOREBOARDINPUT,
    output_type=_DELETESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002%*#/ranker/scoreboards/{scoreboard_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LookupScoreboard',
    full_name='eolymp.ranker.Ranker.LookupScoreboard',
    index=4,
    containing_service=None,
    input_type=_LOOKUPSCOREBOARDINPUT,
    output_type=_LOOKUPSCOREBOARDOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002-\022\037/ranker/scoreboard-lookup/{key}b\nscoreboard',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeScoreboard',
    full_name='eolymp.ranker.Ranker.DescribeScoreboard',
    index=5,
    containing_service=None,
    input_type=_DESCRIBESCOREBOARDINPUT,
    output_type=_DESCRIBESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0021\022#/ranker/scoreboards/{scoreboard_id}b\nscoreboard',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListScoreboards',
    full_name='eolymp.ranker.Ranker.ListScoreboards',
    index=6,
    containing_service=None,
    input_type=_LISTSCOREBOARDSINPUT,
    output_type=_LISTSCOREBOARDSOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\030\022\023/ranker/scoreboardsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListScoreboardRows',
    full_name='eolymp.ranker.Ranker.ListScoreboardRows',
    index=7,
    containing_service=None,
    input_type=_LISTSCOREBOARDROWSINPUT,
    output_type=_LISTSCOREBOARDROWSOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002-\022(/ranker/scoreboards/{scoreboard_id}/rowsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AssignContest',
    full_name='eolymp.ranker.Ranker.AssignContest',
    index=8,
    containing_service=None,
    input_type=_ASSIGNCONTESTINPUT,
    output_type=_ASSIGNCONTESTOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002;\0329/ranker/scoreboards/{scoreboard_id}/contests/{contest_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnassignContest',
    full_name='eolymp.ranker.Ranker.UnassignContest',
    index=9,
    containing_service=None,
    input_type=_UNASSIGNCONTESTINPUT,
    output_type=_UNASSIGNCONTESTOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002;*9/ranker/scoreboards/{scoreboard_id}/contests/{contest_id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RANKER)

DESCRIPTOR.services_by_name['Ranker'] = _RANKER

# @@protoc_insertion_point(module_scope)
