# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/feedback.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/feedback.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x65olymp/judge/feedback.proto\x12\x0c\x65olymp.judge*;\n\x0e\x46\x65\x65\x64\x62\x61\x63kPolicy\x12\x0c\n\x08\x43OMPLETE\x10\x00\x12\x08\n\x04ICPC\x10\x01\x12\x11\n\rICPC_EXPANDED\x10\x02\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
)

_FEEDBACKPOLICY = _descriptor.EnumDescriptor(
  name='FeedbackPolicy',
  full_name='eolymp.judge.FeedbackPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ICPC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ICPC_EXPANDED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45,
  serialized_end=104,
)
_sym_db.RegisterEnumDescriptor(_FEEDBACKPOLICY)

FeedbackPolicy = enum_type_wrapper.EnumTypeWrapper(_FEEDBACKPOLICY)
COMPLETE = 0
ICPC = 1
ICPC_EXPANDED = 2


DESCRIPTOR.enum_types_by_name['FeedbackPolicy'] = _FEEDBACKPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
