# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/wellknown/errors.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/wellknown/errors.proto',
  package='eolymp.wellknown',
  syntax='proto3',
  serialized_options=b'Z9github.com/eolymp/contracts/go/eolymp/wellknown;wellknown',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x65olymp/wellknown/errors.proto\x12\x10\x65olymp.wellknown\" \n\x0b\x45rrorReport\x12\x11\n\treport_id\x18\x01 \x01(\t\"Z\n\x0fInvalidArgument\x12\x15\n\rargument_path\x18\x01 \x01(\t\x12\x30\n\nvalidation\x18\x02 \x03(\x0b\x32\x1c.eolymp.wellknown.Validation\"u\n\nValidation\x12\x15\n\rargument_path\x18\x01 \x03(\t\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x39\n\x0clocalization\x18\x03 \x01(\x0b\x32#.eolymp.wellknown.ErrorLocalization\"-\n\rQuotaExceeded\x12\r\n\x05quota\x18\x01 \x01(\x05\x12\r\n\x05usage\x18\x02 \x01(\x05\"\xaa\x01\n\x11\x45rrorLocalization\x12\x12\n\nphrase_key\x18\x01 \x01(\t\x12L\n\rphrase_params\x18\x02 \x03(\x0b\x32\x35.eolymp.wellknown.ErrorLocalization.PhraseParamsEntry\x1a\x33\n\x11PhraseParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42;Z9github.com/eolymp/contracts/go/eolymp/wellknown;wellknownb\x06proto3'
)




_ERRORREPORT = _descriptor.Descriptor(
  name='ErrorReport',
  full_name='eolymp.wellknown.ErrorReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='report_id', full_name='eolymp.wellknown.ErrorReport.report_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=83,
)


_INVALIDARGUMENT = _descriptor.Descriptor(
  name='InvalidArgument',
  full_name='eolymp.wellknown.InvalidArgument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='argument_path', full_name='eolymp.wellknown.InvalidArgument.argument_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation', full_name='eolymp.wellknown.InvalidArgument.validation', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=175,
)


_VALIDATION = _descriptor.Descriptor(
  name='Validation',
  full_name='eolymp.wellknown.Validation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='argument_path', full_name='eolymp.wellknown.Validation.argument_path', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='eolymp.wellknown.Validation.error_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization', full_name='eolymp.wellknown.Validation.localization', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=294,
)


_QUOTAEXCEEDED = _descriptor.Descriptor(
  name='QuotaExceeded',
  full_name='eolymp.wellknown.QuotaExceeded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='quota', full_name='eolymp.wellknown.QuotaExceeded.quota', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='eolymp.wellknown.QuotaExceeded.usage', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=341,
)


_ERRORLOCALIZATION_PHRASEPARAMSENTRY = _descriptor.Descriptor(
  name='PhraseParamsEntry',
  full_name='eolymp.wellknown.ErrorLocalization.PhraseParamsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.wellknown.ErrorLocalization.PhraseParamsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ErrorLocalization.PhraseParamsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=514,
)

_ERRORLOCALIZATION = _descriptor.Descriptor(
  name='ErrorLocalization',
  full_name='eolymp.wellknown.ErrorLocalization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phrase_key', full_name='eolymp.wellknown.ErrorLocalization.phrase_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phrase_params', full_name='eolymp.wellknown.ErrorLocalization.phrase_params', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ERRORLOCALIZATION_PHRASEPARAMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=514,
)

_INVALIDARGUMENT.fields_by_name['validation'].message_type = _VALIDATION
_VALIDATION.fields_by_name['localization'].message_type = _ERRORLOCALIZATION
_ERRORLOCALIZATION_PHRASEPARAMSENTRY.containing_type = _ERRORLOCALIZATION
_ERRORLOCALIZATION.fields_by_name['phrase_params'].message_type = _ERRORLOCALIZATION_PHRASEPARAMSENTRY
DESCRIPTOR.message_types_by_name['ErrorReport'] = _ERRORREPORT
DESCRIPTOR.message_types_by_name['InvalidArgument'] = _INVALIDARGUMENT
DESCRIPTOR.message_types_by_name['Validation'] = _VALIDATION
DESCRIPTOR.message_types_by_name['QuotaExceeded'] = _QUOTAEXCEEDED
DESCRIPTOR.message_types_by_name['ErrorLocalization'] = _ERRORLOCALIZATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ErrorReport = _reflection.GeneratedProtocolMessageType('ErrorReport', (_message.Message,), {
  'DESCRIPTOR' : _ERRORREPORT,
  '__module__' : 'eolymp.wellknown.errors_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ErrorReport)
  })
_sym_db.RegisterMessage(ErrorReport)

InvalidArgument = _reflection.GeneratedProtocolMessageType('InvalidArgument', (_message.Message,), {
  'DESCRIPTOR' : _INVALIDARGUMENT,
  '__module__' : 'eolymp.wellknown.errors_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.InvalidArgument)
  })
_sym_db.RegisterMessage(InvalidArgument)

Validation = _reflection.GeneratedProtocolMessageType('Validation', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATION,
  '__module__' : 'eolymp.wellknown.errors_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.Validation)
  })
_sym_db.RegisterMessage(Validation)

QuotaExceeded = _reflection.GeneratedProtocolMessageType('QuotaExceeded', (_message.Message,), {
  'DESCRIPTOR' : _QUOTAEXCEEDED,
  '__module__' : 'eolymp.wellknown.errors_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.QuotaExceeded)
  })
_sym_db.RegisterMessage(QuotaExceeded)

ErrorLocalization = _reflection.GeneratedProtocolMessageType('ErrorLocalization', (_message.Message,), {

  'PhraseParamsEntry' : _reflection.GeneratedProtocolMessageType('PhraseParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ERRORLOCALIZATION_PHRASEPARAMSENTRY,
    '__module__' : 'eolymp.wellknown.errors_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.wellknown.ErrorLocalization.PhraseParamsEntry)
    })
  ,
  'DESCRIPTOR' : _ERRORLOCALIZATION,
  '__module__' : 'eolymp.wellknown.errors_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ErrorLocalization)
  })
_sym_db.RegisterMessage(ErrorLocalization)
_sym_db.RegisterMessage(ErrorLocalization.PhraseParamsEntry)


DESCRIPTOR._options = None
_ERRORLOCALIZATION_PHRASEPARAMSENTRY._options = None
# @@protoc_insertion_point(module_scope)
