# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class RankerClient:
    def __init__(self, transport):
        self.transport = transport

    def CreateScoreboard(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/CreateScoreboard",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.CreateScoreboardOutput"),
            **kwargs,
        )

    def UpdateScoreboard(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/UpdateScoreboard",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.UpdateScoreboardOutput"),
            **kwargs,
        )

    def RebuildScoreboard(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/RebuildScoreboard",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.RebuildScoreboardOutput"),
            **kwargs,
        )

    def DeleteScoreboard(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/DeleteScoreboard",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.DeleteScoreboardOutput"),
            **kwargs,
        )

    def LookupScoreboard(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/LookupScoreboard",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.LookupScoreboardOutput"),
            **kwargs,
        )

    def DescribeScoreboard(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/DescribeScoreboard",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.DescribeScoreboardOutput"),
            **kwargs,
        )

    def ListScoreboards(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/ListScoreboards",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.ListScoreboardsOutput"),
            **kwargs,
        )

    def ListScoreboardRows(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/ListScoreboardRows",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.ListScoreboardRowsOutput"),
            **kwargs,
        )

    def AssignContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/AssignContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.AssignContestOutput"),
            **kwargs,
        )

    def UnassignContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/UnassignContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.UnassignContestOutput"),
            **kwargs,
        )

