# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/entitlement.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/entitlement.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/judge/entitlement.proto\x12\x0c\x65olymp.judge*\xff\x02\n\x0b\x45ntitlement\x12\x08\n\x04NONE\x10\x00\x12\x12\n\x0e\x43REATE_CONTEST\x10\x01\x12\x12\n\x0eLOOKUP_CONTEST\x10\x02\x12\x12\n\x0eMANAGE_CONTEST\x10\x03\x12\x10\n\x0cVIEW_RUNTIME\x10\x04\x12\x1a\n\x16VIEW_REGISTRATION_FORM\x10\x05\x12\x14\n\x10VIEW_PARTICIPANT\x10\x06\x12\x16\n\x12MANAGE_PARTICIPANT\x10\x07\x12\x10\n\x0cVIEW_PROBLEM\x10\x08\x12\x12\n\x0eMANAGE_PROBLEM\x10\t\x12\x15\n\x11\x43REATE_SUBMISSION\x10\n\x12\x13\n\x0fVIEW_SUBMISSION\x10\x0b\x12\x15\n\x11MANAGE_SUBMISSION\x10\x0c\x12\x15\n\x11VIEW_ANNOUNCEMENT\x10\r\x12\x17\n\x13MANAGE_ANNOUNCEMENT\x10\x0e\x12\x11\n\rCREATE_TICKET\x10\x0f\x12\x0f\n\x0bVIEW_TICKET\x10\x10\x12\x11\n\rMANAGE_TICKET\x10\x11\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
)

_ENTITLEMENT = _descriptor.EnumDescriptor(
  name='Entitlement',
  full_name='eolymp.judge.Entitlement',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATE_CONTEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOOKUP_CONTEST', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_CONTEST', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_RUNTIME', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_REGISTRATION_FORM', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_PARTICIPANT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_PARTICIPANT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_PROBLEM', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_PROBLEM', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATE_SUBMISSION', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_SUBMISSION', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_SUBMISSION', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_ANNOUNCEMENT', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_ANNOUNCEMENT', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATE_TICKET', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_TICKET', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_TICKET', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=49,
  serialized_end=432,
)
_sym_db.RegisterEnumDescriptor(_ENTITLEMENT)

Entitlement = enum_type_wrapper.EnumTypeWrapper(_ENTITLEMENT)
NONE = 0
CREATE_CONTEST = 1
LOOKUP_CONTEST = 2
MANAGE_CONTEST = 3
VIEW_RUNTIME = 4
VIEW_REGISTRATION_FORM = 5
VIEW_PARTICIPANT = 6
MANAGE_PARTICIPANT = 7
VIEW_PROBLEM = 8
MANAGE_PROBLEM = 9
CREATE_SUBMISSION = 10
VIEW_SUBMISSION = 11
MANAGE_SUBMISSION = 12
VIEW_ANNOUNCEMENT = 13
MANAGE_ANNOUNCEMENT = 14
CREATE_TICKET = 15
VIEW_TICKET = 16
MANAGE_TICKET = 17


DESCRIPTOR.enum_types_by_name['Entitlement'] = _ENTITLEMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
