# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ranker/scoreboard.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/ranker/scoreboard.proto',
  package='eolymp.ranker',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/ranker;ranker',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/ranker/scoreboard.proto\x12\reolymp.ranker\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbf\x05\n\nScoreboard\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12;\n\x0cscoring_mode\x18\n \x01(\x0e\x32%.eolymp.ranker.Scoreboard.ScoringMode\x12\x33\n\x08\x63ontests\x18\x64 \x03(\x0b\x32!.eolymp.ranker.Scoreboard.Contest\x1a\xb3\x02\n\x03Row\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\r\n\x05score\x18\n \x01(\x02\x12\x0f\n\x07penalty\x18\x0b \x01(\x02\x12\x33\n\x06scores\x18\x14 \x03(\x0b\x32#.eolymp.ranker.Scoreboard.Row.Score\x1a\xb7\x01\n\x05Score\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x10\n\x08\x61ttempts\x18\n \x01(\r\x12\x11\n\tsolved_in\x18\x0b \x01(\r\x12-\n\tsolved_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05score\x18\x14 \x01(\x02\x12\x0f\n\x07penalty\x18\x15 \x01(\x02\x12\x12\n\npercentage\x18\x16 \x01(\x02\x1a\xb5\x01\n\x07\x43ontest\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\r\x12\x0f\n\x07visible\x18\x04 \x01(\x08\x12;\n\x08problems\x18\n \x03(\x0b\x32).eolymp.ranker.Scoreboard.Contest.Problem\x1a+\n\x07Problem\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"*\n\x0bScoringMode\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03IOI\x10\x01\x12\x08\n\x04ICPC\x10\x02\x42\x35Z3github.com/eolymp/contracts/go/eolymp/ranker;rankerb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_SCOREBOARD_SCORINGMODE = _descriptor.EnumDescriptor(
  name='ScoringMode',
  full_name='eolymp.ranker.Scoreboard.ScoringMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IOI', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ICPC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=744,
  serialized_end=786,
)
_sym_db.RegisterEnumDescriptor(_SCOREBOARD_SCORINGMODE)


_SCOREBOARD_ROW_SCORE = _descriptor.Descriptor(
  name='Score',
  full_name='eolymp.ranker.Scoreboard.Row.Score',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.ranker.Scoreboard.Row.Score.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.ranker.Scoreboard.Row.Score.problem_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attempts', full_name='eolymp.ranker.Scoreboard.Row.Score.attempts', index=2,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='solved_in', full_name='eolymp.ranker.Scoreboard.Row.Score.solved_in', index=3,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='solved_at', full_name='eolymp.ranker.Scoreboard.Row.Score.solved_at', index=4,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.ranker.Scoreboard.Row.Score.score', index=5,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty', full_name='eolymp.ranker.Scoreboard.Row.Score.penalty', index=6,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='eolymp.ranker.Scoreboard.Row.Score.percentage', index=7,
      number=22, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=558,
)

_SCOREBOARD_ROW = _descriptor.Descriptor(
  name='Row',
  full_name='eolymp.ranker.Scoreboard.Row',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.ranker.Scoreboard.Row.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.ranker.Scoreboard.Row.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.ranker.Scoreboard.Row.score', index=2,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty', full_name='eolymp.ranker.Scoreboard.Row.penalty', index=3,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scores', full_name='eolymp.ranker.Scoreboard.Row.scores', index=4,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOREBOARD_ROW_SCORE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=558,
)

_SCOREBOARD_CONTEST_PROBLEM = _descriptor.Descriptor(
  name='Problem',
  full_name='eolymp.ranker.Scoreboard.Contest.Problem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.ranker.Scoreboard.Contest.Problem.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.ranker.Scoreboard.Contest.Problem.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=699,
  serialized_end=742,
)

_SCOREBOARD_CONTEST = _descriptor.Descriptor(
  name='Contest',
  full_name='eolymp.ranker.Scoreboard.Contest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.ranker.Scoreboard.Contest.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.ranker.Scoreboard.Contest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.ranker.Scoreboard.Contest.index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visible', full_name='eolymp.ranker.Scoreboard.Contest.visible', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problems', full_name='eolymp.ranker.Scoreboard.Contest.problems', index=4,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOREBOARD_CONTEST_PROBLEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=742,
)

_SCOREBOARD = _descriptor.Descriptor(
  name='Scoreboard',
  full_name='eolymp.ranker.Scoreboard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.ranker.Scoreboard.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.ranker.Scoreboard.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.ranker.Scoreboard.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoring_mode', full_name='eolymp.ranker.Scoreboard.scoring_mode', index=3,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contests', full_name='eolymp.ranker.Scoreboard.contests', index=4,
      number=100, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCOREBOARD_ROW, _SCOREBOARD_CONTEST, ],
  enum_types=[
    _SCOREBOARD_SCORINGMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=786,
)

_SCOREBOARD_ROW_SCORE.fields_by_name['solved_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCOREBOARD_ROW_SCORE.containing_type = _SCOREBOARD_ROW
_SCOREBOARD_ROW.fields_by_name['scores'].message_type = _SCOREBOARD_ROW_SCORE
_SCOREBOARD_ROW.containing_type = _SCOREBOARD
_SCOREBOARD_CONTEST_PROBLEM.containing_type = _SCOREBOARD_CONTEST
_SCOREBOARD_CONTEST.fields_by_name['problems'].message_type = _SCOREBOARD_CONTEST_PROBLEM
_SCOREBOARD_CONTEST.containing_type = _SCOREBOARD
_SCOREBOARD.fields_by_name['scoring_mode'].enum_type = _SCOREBOARD_SCORINGMODE
_SCOREBOARD.fields_by_name['contests'].message_type = _SCOREBOARD_CONTEST
_SCOREBOARD_SCORINGMODE.containing_type = _SCOREBOARD
DESCRIPTOR.message_types_by_name['Scoreboard'] = _SCOREBOARD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Scoreboard = _reflection.GeneratedProtocolMessageType('Scoreboard', (_message.Message,), {

  'Row' : _reflection.GeneratedProtocolMessageType('Row', (_message.Message,), {

    'Score' : _reflection.GeneratedProtocolMessageType('Score', (_message.Message,), {
      'DESCRIPTOR' : _SCOREBOARD_ROW_SCORE,
      '__module__' : 'eolymp.ranker.scoreboard_pb2'
      # @@protoc_insertion_point(class_scope:eolymp.ranker.Scoreboard.Row.Score)
      })
    ,
    'DESCRIPTOR' : _SCOREBOARD_ROW,
    '__module__' : 'eolymp.ranker.scoreboard_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.ranker.Scoreboard.Row)
    })
  ,

  'Contest' : _reflection.GeneratedProtocolMessageType('Contest', (_message.Message,), {

    'Problem' : _reflection.GeneratedProtocolMessageType('Problem', (_message.Message,), {
      'DESCRIPTOR' : _SCOREBOARD_CONTEST_PROBLEM,
      '__module__' : 'eolymp.ranker.scoreboard_pb2'
      # @@protoc_insertion_point(class_scope:eolymp.ranker.Scoreboard.Contest.Problem)
      })
    ,
    'DESCRIPTOR' : _SCOREBOARD_CONTEST,
    '__module__' : 'eolymp.ranker.scoreboard_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.ranker.Scoreboard.Contest)
    })
  ,
  'DESCRIPTOR' : _SCOREBOARD,
  '__module__' : 'eolymp.ranker.scoreboard_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.Scoreboard)
  })
_sym_db.RegisterMessage(Scoreboard)
_sym_db.RegisterMessage(Scoreboard.Row)
_sym_db.RegisterMessage(Scoreboard.Row.Score)
_sym_db.RegisterMessage(Scoreboard.Contest)
_sym_db.RegisterMessage(Scoreboard.Contest.Problem)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
