# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.judge import submission_pb2 as eolymp_dot_judge_dot_submission__pb2
from eolymp.judge import ticket_pb2 as eolymp_dot_judge_dot_ticket__pb2
from eolymp.judge import reply_pb2 as eolymp_dot_judge_dot_reply__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/events.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x65olymp/judge/events.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/judge/submission.proto\x1a\x19\x65olymp/judge/ticket.proto\x1a\x18\x65olymp/judge/reply.proto\"H\n\x18SubmissionCompletedEvent\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Submission\"D\n\x16RebuildScoreboardEvent\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tivity_id\x18\x02 \x01(\t\":\n\x12TicketCreatedEvent\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"^\n\x12TicketUpdatedEvent\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\x12\"\n\x05reply\x18\x02 \x01(\x0b\x32\x13.eolymp.judge.ReplyB3Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
  ,
  dependencies=[eolymp_dot_judge_dot_submission__pb2.DESCRIPTOR,eolymp_dot_judge_dot_ticket__pb2.DESCRIPTOR,eolymp_dot_judge_dot_reply__pb2.DESCRIPTOR,])




_SUBMISSIONCOMPLETEDEVENT = _descriptor.Descriptor(
  name='SubmissionCompletedEvent',
  full_name='eolymp.judge.SubmissionCompletedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission', full_name='eolymp.judge.SubmissionCompletedEvent.submission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=199,
)


_REBUILDSCOREBOARDEVENT = _descriptor.Descriptor(
  name='RebuildScoreboardEvent',
  full_name='eolymp.judge.RebuildScoreboardEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.judge.RebuildScoreboardEvent.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activity_id', full_name='eolymp.judge.RebuildScoreboardEvent.activity_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=269,
)


_TICKETCREATEDEVENT = _descriptor.Descriptor(
  name='TicketCreatedEvent',
  full_name='eolymp.judge.TicketCreatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket', full_name='eolymp.judge.TicketCreatedEvent.ticket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=329,
)


_TICKETUPDATEDEVENT = _descriptor.Descriptor(
  name='TicketUpdatedEvent',
  full_name='eolymp.judge.TicketUpdatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket', full_name='eolymp.judge.TicketUpdatedEvent.ticket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply', full_name='eolymp.judge.TicketUpdatedEvent.reply', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=425,
)

_SUBMISSIONCOMPLETEDEVENT.fields_by_name['submission'].message_type = eolymp_dot_judge_dot_submission__pb2._SUBMISSION
_TICKETCREATEDEVENT.fields_by_name['ticket'].message_type = eolymp_dot_judge_dot_ticket__pb2._TICKET
_TICKETUPDATEDEVENT.fields_by_name['ticket'].message_type = eolymp_dot_judge_dot_ticket__pb2._TICKET
_TICKETUPDATEDEVENT.fields_by_name['reply'].message_type = eolymp_dot_judge_dot_reply__pb2._REPLY
DESCRIPTOR.message_types_by_name['SubmissionCompletedEvent'] = _SUBMISSIONCOMPLETEDEVENT
DESCRIPTOR.message_types_by_name['RebuildScoreboardEvent'] = _REBUILDSCOREBOARDEVENT
DESCRIPTOR.message_types_by_name['TicketCreatedEvent'] = _TICKETCREATEDEVENT
DESCRIPTOR.message_types_by_name['TicketUpdatedEvent'] = _TICKETUPDATEDEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubmissionCompletedEvent = _reflection.GeneratedProtocolMessageType('SubmissionCompletedEvent', (_message.Message,), {
  'DESCRIPTOR' : _SUBMISSIONCOMPLETEDEVENT,
  '__module__' : 'eolymp.judge.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.SubmissionCompletedEvent)
  })
_sym_db.RegisterMessage(SubmissionCompletedEvent)

RebuildScoreboardEvent = _reflection.GeneratedProtocolMessageType('RebuildScoreboardEvent', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDSCOREBOARDEVENT,
  '__module__' : 'eolymp.judge.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RebuildScoreboardEvent)
  })
_sym_db.RegisterMessage(RebuildScoreboardEvent)

TicketCreatedEvent = _reflection.GeneratedProtocolMessageType('TicketCreatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _TICKETCREATEDEVENT,
  '__module__' : 'eolymp.judge.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.TicketCreatedEvent)
  })
_sym_db.RegisterMessage(TicketCreatedEvent)

TicketUpdatedEvent = _reflection.GeneratedProtocolMessageType('TicketUpdatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _TICKETUPDATEDEVENT,
  '__module__' : 'eolymp.judge.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.TicketUpdatedEvent)
  })
_sym_db.RegisterMessage(TicketUpdatedEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
