# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/change.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from eolymp.executor import verifier_pb2 as eolymp_dot_executor_dot_verifier__pb2
from eolymp.executor import interactor_pb2 as eolymp_dot_executor_dot_interactor__pb2
from eolymp.atlas import permission_pb2 as eolymp_dot_atlas_dot_permission__pb2
from eolymp.atlas import problem_pb2 as eolymp_dot_atlas_dot_problem__pb2
from eolymp.atlas import statement_pb2 as eolymp_dot_atlas_dot_statement__pb2
from eolymp.atlas import template_pb2 as eolymp_dot_atlas_dot_template__pb2
from eolymp.atlas import test_pb2 as eolymp_dot_atlas_dot_test__pb2
from eolymp.atlas import testset_pb2 as eolymp_dot_atlas_dot_testset__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/change.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x65olymp/atlas/change.proto\x12\x0c\x65olymp.atlas\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x65olymp/executor/verifier.proto\x1a eolymp/executor/interactor.proto\x1a\x1d\x65olymp/atlas/permission.proto\x1a\x1a\x65olymp/atlas/problem.proto\x1a\x1c\x65olymp/atlas/statement.proto\x1a\x1b\x65olymp/atlas/template.proto\x1a\x17\x65olymp/atlas/test.proto\x1a\x1a\x65olymp/atlas/testset.proto\"\x8a\x15\n\x06\x43hange\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nip_address\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x12\n\nproblem_id\x18\x05 \x01(\t\x12<\n\x0e\x63reate_problem\x18\x64 \x01(\x0b\x32\".eolymp.atlas.Change.CreateProblemH\x00\x12<\n\x0eupdate_problem\x18\x65 \x01(\x0b\x32\".eolymp.atlas.Change.UpdateProblemH\x00\x12>\n\x0fupdate_verifier\x18\x66 \x01(\x0b\x32#.eolymp.atlas.Change.UpdateVerifierH\x00\x12\x42\n\x11update_interactor\x18h \x01(\x0b\x32%.eolymp.atlas.Change.UpdateInteractorH\x00\x12<\n\x0e\x64\x65lete_problem\x18i \x01(\x0b\x32\".eolymp.atlas.Change.DeleteProblemH\x00\x12@\n\x10\x63reate_statement\x18n \x01(\x0b\x32$.eolymp.atlas.Change.CreateStatementH\x00\x12@\n\x10update_statement\x18o \x01(\x0b\x32$.eolymp.atlas.Change.UpdateStatementH\x00\x12@\n\x10\x64\x65lete_statement\x18p \x01(\x0b\x32$.eolymp.atlas.Change.DeleteStatementH\x00\x12<\n\x0e\x63reate_testset\x18x \x01(\x0b\x32\".eolymp.atlas.Change.CreateTestsetH\x00\x12<\n\x0eupdate_testset\x18y \x01(\x0b\x32\".eolymp.atlas.Change.UpdateTestsetH\x00\x12<\n\x0e\x64\x65lete_testset\x18z \x01(\x0b\x32\".eolymp.atlas.Change.DeleteTestsetH\x00\x12\x37\n\x0b\x63reate_test\x18\x82\x01 \x01(\x0b\x32\x1f.eolymp.atlas.Change.CreateTestH\x00\x12\x37\n\x0bupdate_test\x18\x83\x01 \x01(\x0b\x32\x1f.eolymp.atlas.Change.UpdateTestH\x00\x12\x37\n\x0b\x64\x65lete_test\x18\x84\x01 \x01(\x0b\x32\x1f.eolymp.atlas.Change.DeleteTestH\x00\x12?\n\x0f\x63reate_template\x18\x8c\x01 \x01(\x0b\x32#.eolymp.atlas.Change.CreateTemplateH\x00\x12?\n\x0fupdate_template\x18\x8d\x01 \x01(\x0b\x32#.eolymp.atlas.Change.UpdateTemplateH\x00\x12?\n\x0f\x64\x65lete_template\x18\x8e\x01 \x01(\x0b\x32#.eolymp.atlas.Change.DeleteTemplateH\x00\x12\x41\n\x10grant_permission\x18\x96\x01 \x01(\x0b\x32$.eolymp.atlas.Change.GrantPermissionH\x00\x12\x43\n\x11revoke_permission\x18\x97\x01 \x01(\x0b\x32%.eolymp.atlas.Change.RevokePermissionH\x00\x1a\x35\n\rCreateProblem\x12$\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Problem\x1a\\\n\rUpdateProblem\x12%\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\x12$\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Problem\x1a\x65\n\x0eUpdateVerifier\x12)\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x19.eolymp.executor.Verifier\x12(\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x19.eolymp.executor.Verifier\x1ak\n\x10UpdateInteractor\x12+\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x1b.eolymp.executor.Interactor\x12*\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x1b.eolymp.executor.Interactor\x1a\x36\n\rDeleteProblem\x12%\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\x1a\x39\n\x0f\x43reateStatement\x12&\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\x1a\x62\n\x0fUpdateStatement\x12\'\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Statement\x12&\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\x1a:\n\x0f\x44\x65leteStatement\x12\'\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Statement\x1a\x35\n\rCreateTestset\x12$\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Testset\x1a\\\n\rUpdateTestset\x12%\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Testset\x12$\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Testset\x1a\x36\n\rDeleteTestset\x12%\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Testset\x1a/\n\nCreateTest\x12!\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x12.eolymp.atlas.Test\x1aS\n\nUpdateTest\x12\"\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x12.eolymp.atlas.Test\x12!\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x12.eolymp.atlas.Test\x1a\x30\n\nDeleteTest\x12\"\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x12.eolymp.atlas.Test\x1a\x37\n\x0e\x43reateTemplate\x12%\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x16.eolymp.atlas.Template\x1a_\n\x0eUpdateTemplate\x12&\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template\x12%\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x16.eolymp.atlas.Template\x1a\x38\n\x0e\x44\x65leteTemplate\x12&\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template\x1a:\n\x0fGrantPermission\x12\'\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Permission\x1a<\n\x10RevokePermission\x12(\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.PermissionB\t\n\x07payloadB3Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,eolymp_dot_executor_dot_verifier__pb2.DESCRIPTOR,eolymp_dot_executor_dot_interactor__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_permission__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_problem__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_statement__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_template__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_test__pb2.DESCRIPTOR,eolymp_dot_atlas_dot_testset__pb2.DESCRIPTOR,])




_CHANGE_CREATEPROBLEM = _descriptor.Descriptor(
  name='CreateProblem',
  full_name='eolymp.atlas.Change.CreateProblem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.CreateProblem.after', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1644,
  serialized_end=1697,
)

_CHANGE_UPDATEPROBLEM = _descriptor.Descriptor(
  name='UpdateProblem',
  full_name='eolymp.atlas.Change.UpdateProblem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.UpdateProblem.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.UpdateProblem.after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1699,
  serialized_end=1791,
)

_CHANGE_UPDATEVERIFIER = _descriptor.Descriptor(
  name='UpdateVerifier',
  full_name='eolymp.atlas.Change.UpdateVerifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.UpdateVerifier.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.UpdateVerifier.after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1793,
  serialized_end=1894,
)

_CHANGE_UPDATEINTERACTOR = _descriptor.Descriptor(
  name='UpdateInteractor',
  full_name='eolymp.atlas.Change.UpdateInteractor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.UpdateInteractor.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.UpdateInteractor.after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1896,
  serialized_end=2003,
)

_CHANGE_DELETEPROBLEM = _descriptor.Descriptor(
  name='DeleteProblem',
  full_name='eolymp.atlas.Change.DeleteProblem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.DeleteProblem.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2005,
  serialized_end=2059,
)

_CHANGE_CREATESTATEMENT = _descriptor.Descriptor(
  name='CreateStatement',
  full_name='eolymp.atlas.Change.CreateStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.CreateStatement.after', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2061,
  serialized_end=2118,
)

_CHANGE_UPDATESTATEMENT = _descriptor.Descriptor(
  name='UpdateStatement',
  full_name='eolymp.atlas.Change.UpdateStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.UpdateStatement.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.UpdateStatement.after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2120,
  serialized_end=2218,
)

_CHANGE_DELETESTATEMENT = _descriptor.Descriptor(
  name='DeleteStatement',
  full_name='eolymp.atlas.Change.DeleteStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.DeleteStatement.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2220,
  serialized_end=2278,
)

_CHANGE_CREATETESTSET = _descriptor.Descriptor(
  name='CreateTestset',
  full_name='eolymp.atlas.Change.CreateTestset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.CreateTestset.after', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2280,
  serialized_end=2333,
)

_CHANGE_UPDATETESTSET = _descriptor.Descriptor(
  name='UpdateTestset',
  full_name='eolymp.atlas.Change.UpdateTestset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.UpdateTestset.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.UpdateTestset.after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2335,
  serialized_end=2427,
)

_CHANGE_DELETETESTSET = _descriptor.Descriptor(
  name='DeleteTestset',
  full_name='eolymp.atlas.Change.DeleteTestset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.DeleteTestset.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2429,
  serialized_end=2483,
)

_CHANGE_CREATETEST = _descriptor.Descriptor(
  name='CreateTest',
  full_name='eolymp.atlas.Change.CreateTest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.CreateTest.after', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2485,
  serialized_end=2532,
)

_CHANGE_UPDATETEST = _descriptor.Descriptor(
  name='UpdateTest',
  full_name='eolymp.atlas.Change.UpdateTest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.UpdateTest.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.UpdateTest.after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2534,
  serialized_end=2617,
)

_CHANGE_DELETETEST = _descriptor.Descriptor(
  name='DeleteTest',
  full_name='eolymp.atlas.Change.DeleteTest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.DeleteTest.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2619,
  serialized_end=2667,
)

_CHANGE_CREATETEMPLATE = _descriptor.Descriptor(
  name='CreateTemplate',
  full_name='eolymp.atlas.Change.CreateTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.CreateTemplate.after', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2669,
  serialized_end=2724,
)

_CHANGE_UPDATETEMPLATE = _descriptor.Descriptor(
  name='UpdateTemplate',
  full_name='eolymp.atlas.Change.UpdateTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.UpdateTemplate.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.UpdateTemplate.after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2821,
)

_CHANGE_DELETETEMPLATE = _descriptor.Descriptor(
  name='DeleteTemplate',
  full_name='eolymp.atlas.Change.DeleteTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.DeleteTemplate.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2823,
  serialized_end=2879,
)

_CHANGE_GRANTPERMISSION = _descriptor.Descriptor(
  name='GrantPermission',
  full_name='eolymp.atlas.Change.GrantPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='after', full_name='eolymp.atlas.Change.GrantPermission.after', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2881,
  serialized_end=2939,
)

_CHANGE_REVOKEPERMISSION = _descriptor.Descriptor(
  name='RevokePermission',
  full_name='eolymp.atlas.Change.RevokePermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='before', full_name='eolymp.atlas.Change.RevokePermission.before', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2941,
  serialized_end=3001,
)

_CHANGE = _descriptor.Descriptor(
  name='Change',
  full_name='eolymp.atlas.Change',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.atlas.Change.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='eolymp.atlas.Change.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='eolymp.atlas.Change.ip_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.atlas.Change.user_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.Change.problem_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_problem', full_name='eolymp.atlas.Change.create_problem', index=5,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_problem', full_name='eolymp.atlas.Change.update_problem', index=6,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_verifier', full_name='eolymp.atlas.Change.update_verifier', index=7,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_interactor', full_name='eolymp.atlas.Change.update_interactor', index=8,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_problem', full_name='eolymp.atlas.Change.delete_problem', index=9,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_statement', full_name='eolymp.atlas.Change.create_statement', index=10,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_statement', full_name='eolymp.atlas.Change.update_statement', index=11,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_statement', full_name='eolymp.atlas.Change.delete_statement', index=12,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_testset', full_name='eolymp.atlas.Change.create_testset', index=13,
      number=120, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_testset', full_name='eolymp.atlas.Change.update_testset', index=14,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_testset', full_name='eolymp.atlas.Change.delete_testset', index=15,
      number=122, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_test', full_name='eolymp.atlas.Change.create_test', index=16,
      number=130, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_test', full_name='eolymp.atlas.Change.update_test', index=17,
      number=131, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_test', full_name='eolymp.atlas.Change.delete_test', index=18,
      number=132, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_template', full_name='eolymp.atlas.Change.create_template', index=19,
      number=140, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_template', full_name='eolymp.atlas.Change.update_template', index=20,
      number=141, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_template', full_name='eolymp.atlas.Change.delete_template', index=21,
      number=142, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grant_permission', full_name='eolymp.atlas.Change.grant_permission', index=22,
      number=150, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revoke_permission', full_name='eolymp.atlas.Change.revoke_permission', index=23,
      number=151, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHANGE_CREATEPROBLEM, _CHANGE_UPDATEPROBLEM, _CHANGE_UPDATEVERIFIER, _CHANGE_UPDATEINTERACTOR, _CHANGE_DELETEPROBLEM, _CHANGE_CREATESTATEMENT, _CHANGE_UPDATESTATEMENT, _CHANGE_DELETESTATEMENT, _CHANGE_CREATETESTSET, _CHANGE_UPDATETESTSET, _CHANGE_DELETETESTSET, _CHANGE_CREATETEST, _CHANGE_UPDATETEST, _CHANGE_DELETETEST, _CHANGE_CREATETEMPLATE, _CHANGE_UPDATETEMPLATE, _CHANGE_DELETETEMPLATE, _CHANGE_GRANTPERMISSION, _CHANGE_REVOKEPERMISSION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='eolymp.atlas.Change.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=314,
  serialized_end=3012,
)

_CHANGE_CREATEPROBLEM.fields_by_name['after'].message_type = eolymp_dot_atlas_dot_problem__pb2._PROBLEM
_CHANGE_CREATEPROBLEM.containing_type = _CHANGE
_CHANGE_UPDATEPROBLEM.fields_by_name['before'].message_type = eolymp_dot_atlas_dot_problem__pb2._PROBLEM
_CHANGE_UPDATEPROBLEM.fields_by_name['after'].message_type = eolymp_dot_atlas_dot_problem__pb2._PROBLEM
_CHANGE_UPDATEPROBLEM.containing_type = _CHANGE
_CHANGE_UPDATEVERIFIER.fields_by_name['before'].message_type = eolymp_dot_executor_dot_verifier__pb2._VERIFIER
_CHANGE_UPDATEVERIFIER.fields_by_name['after'].message_type = eolymp_dot_executor_dot_verifier__pb2._VERIFIER
_CHANGE_UPDATEVERIFIER.containing_type = _CHANGE
_CHANGE_UPDATEINTERACTOR.fields_by_name['before'].message_type = eolymp_dot_executor_dot_interactor__pb2._INTERACTOR
_CHANGE_UPDATEINTERACTOR.fields_by_name['after'].message_type = eolymp_dot_executor_dot_interactor__pb2._INTERACTOR
_CHANGE_UPDATEINTERACTOR.containing_type = _CHANGE
_CHANGE_DELETEPROBLEM.fields_by_name['before'].message_type = eolymp_dot_atlas_dot_problem__pb2._PROBLEM
_CHANGE_DELETEPROBLEM.containing_type = _CHANGE
_CHANGE_CREATESTATEMENT.fields_by_name['after'].message_type = eolymp_dot_atlas_dot_statement__pb2._STATEMENT
_CHANGE_CREATESTATEMENT.containing_type = _CHANGE
_CHANGE_UPDATESTATEMENT.fields_by_name['before'].message_type = eolymp_dot_atlas_dot_statement__pb2._STATEMENT
_CHANGE_UPDATESTATEMENT.fields_by_name['after'].message_type = eolymp_dot_atlas_dot_statement__pb2._STATEMENT
_CHANGE_UPDATESTATEMENT.containing_type = _CHANGE
_CHANGE_DELETESTATEMENT.fields_by_name['before'].message_type = eolymp_dot_atlas_dot_statement__pb2._STATEMENT
_CHANGE_DELETESTATEMENT.containing_type = _CHANGE
_CHANGE_CREATETESTSET.fields_by_name['after'].message_type = eolymp_dot_atlas_dot_testset__pb2._TESTSET
_CHANGE_CREATETESTSET.containing_type = _CHANGE
_CHANGE_UPDATETESTSET.fields_by_name['before'].message_type = eolymp_dot_atlas_dot_testset__pb2._TESTSET
_CHANGE_UPDATETESTSET.fields_by_name['after'].message_type = eolymp_dot_atlas_dot_testset__pb2._TESTSET
_CHANGE_UPDATETESTSET.containing_type = _CHANGE
_CHANGE_DELETETESTSET.fields_by_name['before'].message_type = eolymp_dot_atlas_dot_testset__pb2._TESTSET
_CHANGE_DELETETESTSET.containing_type = _CHANGE
_CHANGE_CREATETEST.fields_by_name['after'].message_type = eolymp_dot_atlas_dot_test__pb2._TEST
_CHANGE_CREATETEST.containing_type = _CHANGE
_CHANGE_UPDATETEST.fields_by_name['before'].message_type = eolymp_dot_atlas_dot_test__pb2._TEST
_CHANGE_UPDATETEST.fields_by_name['after'].message_type = eolymp_dot_atlas_dot_test__pb2._TEST
_CHANGE_UPDATETEST.containing_type = _CHANGE
_CHANGE_DELETETEST.fields_by_name['before'].message_type = eolymp_dot_atlas_dot_test__pb2._TEST
_CHANGE_DELETETEST.containing_type = _CHANGE
_CHANGE_CREATETEMPLATE.fields_by_name['after'].message_type = eolymp_dot_atlas_dot_template__pb2._TEMPLATE
_CHANGE_CREATETEMPLATE.containing_type = _CHANGE
_CHANGE_UPDATETEMPLATE.fields_by_name['before'].message_type = eolymp_dot_atlas_dot_template__pb2._TEMPLATE
_CHANGE_UPDATETEMPLATE.fields_by_name['after'].message_type = eolymp_dot_atlas_dot_template__pb2._TEMPLATE
_CHANGE_UPDATETEMPLATE.containing_type = _CHANGE
_CHANGE_DELETETEMPLATE.fields_by_name['before'].message_type = eolymp_dot_atlas_dot_template__pb2._TEMPLATE
_CHANGE_DELETETEMPLATE.containing_type = _CHANGE
_CHANGE_GRANTPERMISSION.fields_by_name['after'].message_type = eolymp_dot_atlas_dot_permission__pb2._PERMISSION
_CHANGE_GRANTPERMISSION.containing_type = _CHANGE
_CHANGE_REVOKEPERMISSION.fields_by_name['before'].message_type = eolymp_dot_atlas_dot_permission__pb2._PERMISSION
_CHANGE_REVOKEPERMISSION.containing_type = _CHANGE
_CHANGE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHANGE.fields_by_name['create_problem'].message_type = _CHANGE_CREATEPROBLEM
_CHANGE.fields_by_name['update_problem'].message_type = _CHANGE_UPDATEPROBLEM
_CHANGE.fields_by_name['update_verifier'].message_type = _CHANGE_UPDATEVERIFIER
_CHANGE.fields_by_name['update_interactor'].message_type = _CHANGE_UPDATEINTERACTOR
_CHANGE.fields_by_name['delete_problem'].message_type = _CHANGE_DELETEPROBLEM
_CHANGE.fields_by_name['create_statement'].message_type = _CHANGE_CREATESTATEMENT
_CHANGE.fields_by_name['update_statement'].message_type = _CHANGE_UPDATESTATEMENT
_CHANGE.fields_by_name['delete_statement'].message_type = _CHANGE_DELETESTATEMENT
_CHANGE.fields_by_name['create_testset'].message_type = _CHANGE_CREATETESTSET
_CHANGE.fields_by_name['update_testset'].message_type = _CHANGE_UPDATETESTSET
_CHANGE.fields_by_name['delete_testset'].message_type = _CHANGE_DELETETESTSET
_CHANGE.fields_by_name['create_test'].message_type = _CHANGE_CREATETEST
_CHANGE.fields_by_name['update_test'].message_type = _CHANGE_UPDATETEST
_CHANGE.fields_by_name['delete_test'].message_type = _CHANGE_DELETETEST
_CHANGE.fields_by_name['create_template'].message_type = _CHANGE_CREATETEMPLATE
_CHANGE.fields_by_name['update_template'].message_type = _CHANGE_UPDATETEMPLATE
_CHANGE.fields_by_name['delete_template'].message_type = _CHANGE_DELETETEMPLATE
_CHANGE.fields_by_name['grant_permission'].message_type = _CHANGE_GRANTPERMISSION
_CHANGE.fields_by_name['revoke_permission'].message_type = _CHANGE_REVOKEPERMISSION
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['create_problem'])
_CHANGE.fields_by_name['create_problem'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['update_problem'])
_CHANGE.fields_by_name['update_problem'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['update_verifier'])
_CHANGE.fields_by_name['update_verifier'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['update_interactor'])
_CHANGE.fields_by_name['update_interactor'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['delete_problem'])
_CHANGE.fields_by_name['delete_problem'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['create_statement'])
_CHANGE.fields_by_name['create_statement'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['update_statement'])
_CHANGE.fields_by_name['update_statement'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['delete_statement'])
_CHANGE.fields_by_name['delete_statement'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['create_testset'])
_CHANGE.fields_by_name['create_testset'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['update_testset'])
_CHANGE.fields_by_name['update_testset'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['delete_testset'])
_CHANGE.fields_by_name['delete_testset'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['create_test'])
_CHANGE.fields_by_name['create_test'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['update_test'])
_CHANGE.fields_by_name['update_test'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['delete_test'])
_CHANGE.fields_by_name['delete_test'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['create_template'])
_CHANGE.fields_by_name['create_template'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['update_template'])
_CHANGE.fields_by_name['update_template'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['delete_template'])
_CHANGE.fields_by_name['delete_template'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['grant_permission'])
_CHANGE.fields_by_name['grant_permission'].containing_oneof = _CHANGE.oneofs_by_name['payload']
_CHANGE.oneofs_by_name['payload'].fields.append(
  _CHANGE.fields_by_name['revoke_permission'])
_CHANGE.fields_by_name['revoke_permission'].containing_oneof = _CHANGE.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['Change'] = _CHANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Change = _reflection.GeneratedProtocolMessageType('Change', (_message.Message,), {

  'CreateProblem' : _reflection.GeneratedProtocolMessageType('CreateProblem', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_CREATEPROBLEM,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.CreateProblem)
    })
  ,

  'UpdateProblem' : _reflection.GeneratedProtocolMessageType('UpdateProblem', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_UPDATEPROBLEM,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.UpdateProblem)
    })
  ,

  'UpdateVerifier' : _reflection.GeneratedProtocolMessageType('UpdateVerifier', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_UPDATEVERIFIER,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.UpdateVerifier)
    })
  ,

  'UpdateInteractor' : _reflection.GeneratedProtocolMessageType('UpdateInteractor', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_UPDATEINTERACTOR,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.UpdateInteractor)
    })
  ,

  'DeleteProblem' : _reflection.GeneratedProtocolMessageType('DeleteProblem', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_DELETEPROBLEM,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.DeleteProblem)
    })
  ,

  'CreateStatement' : _reflection.GeneratedProtocolMessageType('CreateStatement', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_CREATESTATEMENT,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.CreateStatement)
    })
  ,

  'UpdateStatement' : _reflection.GeneratedProtocolMessageType('UpdateStatement', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_UPDATESTATEMENT,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.UpdateStatement)
    })
  ,

  'DeleteStatement' : _reflection.GeneratedProtocolMessageType('DeleteStatement', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_DELETESTATEMENT,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.DeleteStatement)
    })
  ,

  'CreateTestset' : _reflection.GeneratedProtocolMessageType('CreateTestset', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_CREATETESTSET,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.CreateTestset)
    })
  ,

  'UpdateTestset' : _reflection.GeneratedProtocolMessageType('UpdateTestset', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_UPDATETESTSET,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.UpdateTestset)
    })
  ,

  'DeleteTestset' : _reflection.GeneratedProtocolMessageType('DeleteTestset', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_DELETETESTSET,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.DeleteTestset)
    })
  ,

  'CreateTest' : _reflection.GeneratedProtocolMessageType('CreateTest', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_CREATETEST,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.CreateTest)
    })
  ,

  'UpdateTest' : _reflection.GeneratedProtocolMessageType('UpdateTest', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_UPDATETEST,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.UpdateTest)
    })
  ,

  'DeleteTest' : _reflection.GeneratedProtocolMessageType('DeleteTest', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_DELETETEST,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.DeleteTest)
    })
  ,

  'CreateTemplate' : _reflection.GeneratedProtocolMessageType('CreateTemplate', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_CREATETEMPLATE,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.CreateTemplate)
    })
  ,

  'UpdateTemplate' : _reflection.GeneratedProtocolMessageType('UpdateTemplate', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_UPDATETEMPLATE,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.UpdateTemplate)
    })
  ,

  'DeleteTemplate' : _reflection.GeneratedProtocolMessageType('DeleteTemplate', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_DELETETEMPLATE,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.DeleteTemplate)
    })
  ,

  'GrantPermission' : _reflection.GeneratedProtocolMessageType('GrantPermission', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_GRANTPERMISSION,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.GrantPermission)
    })
  ,

  'RevokePermission' : _reflection.GeneratedProtocolMessageType('RevokePermission', (_message.Message,), {
    'DESCRIPTOR' : _CHANGE_REVOKEPERMISSION,
    '__module__' : 'eolymp.atlas.change_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Change.RevokePermission)
    })
  ,
  'DESCRIPTOR' : _CHANGE,
  '__module__' : 'eolymp.atlas.change_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.Change)
  })
_sym_db.RegisterMessage(Change)
_sym_db.RegisterMessage(Change.CreateProblem)
_sym_db.RegisterMessage(Change.UpdateProblem)
_sym_db.RegisterMessage(Change.UpdateVerifier)
_sym_db.RegisterMessage(Change.UpdateInteractor)
_sym_db.RegisterMessage(Change.DeleteProblem)
_sym_db.RegisterMessage(Change.CreateStatement)
_sym_db.RegisterMessage(Change.UpdateStatement)
_sym_db.RegisterMessage(Change.DeleteStatement)
_sym_db.RegisterMessage(Change.CreateTestset)
_sym_db.RegisterMessage(Change.UpdateTestset)
_sym_db.RegisterMessage(Change.DeleteTestset)
_sym_db.RegisterMessage(Change.CreateTest)
_sym_db.RegisterMessage(Change.UpdateTest)
_sym_db.RegisterMessage(Change.DeleteTest)
_sym_db.RegisterMessage(Change.CreateTemplate)
_sym_db.RegisterMessage(Change.UpdateTemplate)
_sym_db.RegisterMessage(Change.DeleteTemplate)
_sym_db.RegisterMessage(Change.GrantPermission)
_sym_db.RegisterMessage(Change.RevokePermission)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
