# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/playground/playground.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.playground import run_pb2 as eolymp_dot_playground_dot_run__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/playground/playground.proto',
  package='eolymp.playground',
  syntax='proto3',
  serialized_options=b'Z;github.com/eolymp/contracts/go/eolymp/playground;playground',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"eolymp/playground/playground.proto\x12\x11\x65olymp.playground\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1b\x65olymp/playground/run.proto\"=\n\x0e\x43reateRunInput\x12\x0c\n\x04lang\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\r\n\x05input\x18\x03 \x01(\t\"!\n\x0f\x43reateRunOutput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"\"\n\x10\x44\x65scribeRunInput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"8\n\x11\x44\x65scribeRunOutput\x12#\n\x03run\x18\x01 \x01(\x0b\x32\x16.eolymp.playground.Run2\xd3\x02\n\nPlayground\x12\x97\x01\n\tCreateRun\x12!.eolymp.playground.CreateRunInput\x1a\".eolymp.playground.CreateRunOutput\"C\x82\xe3\n\x18\x8a\xe3\n\x14playground:run:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x12\"\x10/playground/runs\x12\xaa\x01\n\x0b\x44\x65scribeRun\x12#.eolymp.playground.DescribeRunInput\x1a$.eolymp.playground.DescribeRunOutput\"P\x82\xe3\n\x17\x8a\xe3\n\x13playground:run:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02 \x12\x19/playground/runs/{run_id}b\x03runB=Z;github.com/eolymp/contracts/go/eolymp/playground;playgroundb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_playground_dot_run__pb2.DESCRIPTOR,])




_CREATERUNINPUT = _descriptor.Descriptor(
  name='CreateRunInput',
  full_name='eolymp.playground.CreateRunInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.playground.CreateRunInput.lang', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.playground.CreateRunInput.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input', full_name='eolymp.playground.CreateRunInput.input', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=246,
)


_CREATERUNOUTPUT = _descriptor.Descriptor(
  name='CreateRunOutput',
  full_name='eolymp.playground.CreateRunOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_id', full_name='eolymp.playground.CreateRunOutput.run_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=281,
)


_DESCRIBERUNINPUT = _descriptor.Descriptor(
  name='DescribeRunInput',
  full_name='eolymp.playground.DescribeRunInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_id', full_name='eolymp.playground.DescribeRunInput.run_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=317,
)


_DESCRIBERUNOUTPUT = _descriptor.Descriptor(
  name='DescribeRunOutput',
  full_name='eolymp.playground.DescribeRunOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='eolymp.playground.DescribeRunOutput.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=375,
)

_DESCRIBERUNOUTPUT.fields_by_name['run'].message_type = eolymp_dot_playground_dot_run__pb2._RUN
DESCRIPTOR.message_types_by_name['CreateRunInput'] = _CREATERUNINPUT
DESCRIPTOR.message_types_by_name['CreateRunOutput'] = _CREATERUNOUTPUT
DESCRIPTOR.message_types_by_name['DescribeRunInput'] = _DESCRIBERUNINPUT
DESCRIPTOR.message_types_by_name['DescribeRunOutput'] = _DESCRIBERUNOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateRunInput = _reflection.GeneratedProtocolMessageType('CreateRunInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNINPUT,
  '__module__' : 'eolymp.playground.playground_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.playground.CreateRunInput)
  })
_sym_db.RegisterMessage(CreateRunInput)

CreateRunOutput = _reflection.GeneratedProtocolMessageType('CreateRunOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNOUTPUT,
  '__module__' : 'eolymp.playground.playground_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.playground.CreateRunOutput)
  })
_sym_db.RegisterMessage(CreateRunOutput)

DescribeRunInput = _reflection.GeneratedProtocolMessageType('DescribeRunInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERUNINPUT,
  '__module__' : 'eolymp.playground.playground_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.playground.DescribeRunInput)
  })
_sym_db.RegisterMessage(DescribeRunInput)

DescribeRunOutput = _reflection.GeneratedProtocolMessageType('DescribeRunOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERUNOUTPUT,
  '__module__' : 'eolymp.playground.playground_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.playground.DescribeRunOutput)
  })
_sym_db.RegisterMessage(DescribeRunOutput)


DESCRIPTOR._options = None

_PLAYGROUND = _descriptor.ServiceDescriptor(
  name='Playground',
  full_name='eolymp.playground.Playground',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=378,
  serialized_end=717,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateRun',
    full_name='eolymp.playground.Playground.CreateRun',
    index=0,
    containing_service=None,
    input_type=_CREATERUNINPUT,
    output_type=_CREATERUNOUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024playground:run:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\022\"\020/playground/runs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeRun',
    full_name='eolymp.playground.Playground.DescribeRun',
    index=1,
    containing_service=None,
    input_type=_DESCRIBERUNINPUT,
    output_type=_DESCRIBERUNOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023playground:run:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002 \022\031/playground/runs/{run_id}b\003run',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PLAYGROUND)

DESCRIPTOR.services_by_name['Playground'] = _PLAYGROUND

# @@protoc_insertion_point(module_scope)
