# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/judge.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.judge import activity_pb2 as eolymp_dot_judge_dot_activity__pb2
from eolymp.judge import announcement_pb2 as eolymp_dot_judge_dot_announcement__pb2
from eolymp.judge import contest_pb2 as eolymp_dot_judge_dot_contest__pb2
from eolymp.judge import entitlement_pb2 as eolymp_dot_judge_dot_entitlement__pb2
from eolymp.judge import form_pb2 as eolymp_dot_judge_dot_form__pb2
from eolymp.judge import participant_pb2 as eolymp_dot_judge_dot_participant__pb2
from eolymp.judge import problem_pb2 as eolymp_dot_judge_dot_problem__pb2
from eolymp.judge import reply_pb2 as eolymp_dot_judge_dot_reply__pb2
from eolymp.judge import scoreboard_pb2 as eolymp_dot_judge_dot_scoreboard__pb2
from eolymp.judge import submission_pb2 as eolymp_dot_judge_dot_submission__pb2
from eolymp.judge import ticket_pb2 as eolymp_dot_judge_dot_ticket__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/judge.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x65olymp/judge/judge.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\x1a eolymp/wellknown/direction.proto\x1a\x1b\x65olymp/judge/activity.proto\x1a\x1f\x65olymp/judge/announcement.proto\x1a\x1a\x65olymp/judge/contest.proto\x1a\x1e\x65olymp/judge/entitlement.proto\x1a\x17\x65olymp/judge/form.proto\x1a\x1e\x65olymp/judge/participant.proto\x1a\x1a\x65olymp/judge/problem.proto\x1a\x18\x65olymp/judge/reply.proto\x1a\x1d\x65olymp/judge/scoreboard.proto\x1a\x1d\x65olymp/judge/submission.proto\x1a\x19\x65olymp/judge/ticket.proto\"i\n\x12\x43reateContestInput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x1d.eolymp.judge.Scoreboard.Type\")\n\x13\x43reateContestOutput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"(\n\x12\x44\x65leteContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteContestOutput\"P\n\x12UpdateContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12&\n\x07\x63ontest\x18\x02 \x01(\x0b\x32\x15.eolymp.judge.Contest\"\x15\n\x13UpdateContestOutput\"*\n\x14\x44\x65scribeContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"?\n\x15\x44\x65scribeContestOutput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\"!\n\x12LookupContestInput\x12\x0b\n\x03key\x18\x01 \x01(\t\"s\n\x13LookupContestOutput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\x12\x34\n\nappearance\x18\x02 \x01(\x0b\x32 .eolymp.judge.Contest.Appearance\"\xdc\x03\n\x11ListContestsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.judge.ListContestsInput.Filter\x1a\xef\x02\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12-\n\x03own\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x38\n\tstarts_at\x18\x04 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x36\n\x07\x65nds_at\x18\x05 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x30\n\x06public\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x34\n\nvisibility\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"I\n\x12ListContestsOutput\x12$\n\x05items\x18\x01 \x03(\x0b\x32\x15.eolymp.judge.Contest\x12\r\n\x05total\x18\x02 \x01(\x05\"&\n\x10OpenContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x13\n\x11OpenContestOutput\"\'\n\x11\x43loseContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12\x43loseContestOutput\"&\n\x10JoinContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x13\n\x11JoinContestOutput\"\'\n\x11StartContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12StartContestOutput\"`\n\x12ImportProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\timport_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x14\n\x0csubmit_limit\x18\x0b \x01(\r\")\n\x13ImportProblemOutput\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"&\n\x10SyncProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x13\n\x11SyncProblemOutput\"M\n\x12UpdateProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x14\n\x0csubmit_limit\x18\x0b \x01(\r\"\x15\n\x13UpdateProblemOutput\"(\n\x12\x44\x65leteProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteProblemOutput\"(\n\x12RetestProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x15\n\x13RetestProblemOutput\"E\n\x11ListProblemsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"I\n\x12ListProblemsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.judge.Problem\"*\n\x14\x44\x65scribeProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"?\n\x15\x44\x65scribeProblemOutput\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Problem\")\n\x13ListStatementsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"U\n\x14ListStatementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.eolymp.judge.Problem.Statement\"\'\n\x11ListExamplesInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"N\n\x12ListExamplesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.judge.Problem.Test\"x\n\x13\x41\x64\x64ParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12-\n\x05users\x18\x03 \x03(\x0b\x32\x1e.eolymp.judge.Participant.User\x12\x10\n\x07user_id\x18\xe7\x07 \x01(\t\".\n\x14\x41\x64\x64ParticipantOutput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"0\n\x16\x45nableParticipantInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"\x19\n\x17\x45nableParticipantOutput\"1\n\x17\x44isableParticipantInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"\x1a\n\x18\x44isableParticipantOutput\"0\n\x16RemoveParticipantInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"\x19\n\x17RemoveParticipantOutput\")\n\x13VerifyPasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"7\n\x14VerifyPasscodeOutput\x12\x10\n\x08required\x18\x01 \x01(\x08\x12\r\n\x05valid\x18\x02 \x01(\x08\":\n\x12\x45nterPasscodeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x10\n\x08passcode\x18\x02 \x01(\t\"\x15\n\x13\x45nterPasscodeOutput\",\n\x12ResetPasscodeInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"\'\n\x13ResetPasscodeOutput\x12\x10\n\x08passcode\x18\x01 \x01(\t\"-\n\x13RemovePasscodeInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"\x16\n\x14RemovePasscodeOutput\"\xe6\x05\n\x15ListParticipantsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.judge.ListParticipantsInput.Filter\x12:\n\x04sort\x18\x32 \x01(\x0e\x32,.eolymp.judge.ListParticipantsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xa6\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x08 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x04 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x32\n\x07penalty\x18\x05 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x39\n\nstarted_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12:\n\x0b\x63omplete_at\x18\x07 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\"M\n\x08Sortable\x12\x08\n\x04RANK\x10\x00\x12\t\n\x05SCORE\x10\x01\x12\x0b\n\x07PENALTY\x10\x02\x12\x0e\n\nSTARTED_AT\x10\x03\x12\x0f\n\x0b\x43OMPLETE_AT\x10\x04\"Q\n\x16ListParticipantsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.judge.Participant\"0\n\x1aIntrospectParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"M\n\x1bIntrospectParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"2\n\x18\x44\x65scribeParticipantInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"K\n\x19\x44\x65scribeParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"I\n\x15\x43reateSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"/\n\x16\x43reateSubmissionOutput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"\xe4\x04\n\x14ListSubmissionsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.judge.ListSubmissionsInput.Filter\x1a\xdd\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\nproblem_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12.\n\x04lang\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x06 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x35\n\npercentage\x18\x07 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12;\n\x0csubmitted_at\x18\x08 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x33\n\tsignature\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"O\n\x15ListSubmissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.judge.Submission\"0\n\x17\x44\x65scribeSubmissionInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"H\n\x18\x44\x65scribeSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Submission\".\n\x15RetestSubmissionInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"\x18\n\x16RetestSubmissionOutput\"I\n\x11\x43reateTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"\'\n\x12\x43reateTicketOutput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"%\n\x10\x43loseTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x13\n\x11\x43loseTicketOutput\"$\n\x0fOpenTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x12\n\x10OpenTicketOutput\"$\n\x0fReadTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x12\n\x10ReadTicketOutput\"&\n\x11\x44\x65leteTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteTicketOutput\"(\n\x13\x44\x65scribeTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"<\n\x14\x44\x65scribeTicketOutput\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"\xeb\x03\n\x10ListTicketsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.judge.ListTicketsInput.Filter\x1a\x80\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\ncontest_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12@\n\x16is_read_by_participant\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12:\n\x10is_read_by_owner\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x31\n\x07is_open\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12-\n\x03own\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"G\n\x11ListTicketsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.judge.Ticket\"E\n\x10ReplyTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x15 \x01(\x08\"%\n\x11ReplyTicketOutput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"C\n\x10ListRepliesInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"F\n\x11ListRepliesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\"\n\x05items\x18\x02 \x03(\x0b\x32\x13.eolymp.judge.Reply\"$\n\x10\x44\x65leteReplyInput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteReplyOutput\"5\n\x10UpdateReplyInput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x13\n\x11UpdateReplyOutput\"V\n\x1e\x43onfigureRegistrationFormInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12 \n\x04\x66orm\x18\n \x01(\x0b\x32\x12.eolymp.judge.Form\"!\n\x1f\x43onfigureRegistrationFormOutput\"3\n\x1d\x44\x65scribeRegistrationFormInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"B\n\x1e\x44\x65scribeRegistrationFormOutput\x12 \n\x04\x66orm\x18\x01 \x01(\x0b\x32\x12.eolymp.judge.Form\"<\n\x15\x43onfigureRuntimeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\x02 \x03(\t\"\x18\n\x16\x43onfigureRuntimeOutput\"*\n\x14\x44\x65scribeRuntimeInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"(\n\x15\x44\x65scribeRuntimeOutput\x12\x0f\n\x07runtime\x18\x01 \x03(\t\"c\n\x17SubmitRegistrationInput\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12\x30\n\x0cregistration\x18\n \x01(\x0b\x32\x1a.eolymp.judge.Registration\"\x1a\n\x18SubmitRegistrationOutput\"3\n\x19\x44\x65scribeRegistrationInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"N\n\x1a\x44\x65scribeRegistrationOutput\x12\x30\n\x0cregistration\x18\x01 \x01(\x0b\x32\x1a.eolymp.judge.Registration\"_\n\x17\x43reateAnnouncementInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x30\n\x0c\x61nnouncement\x18\x02 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\"&\n\x18\x43reateAnnouncementOutput\x12\n\n\x02id\x18\x01 \x01(\t\"d\n\x17UpdateAnnouncementInput\x12\x17\n\x0f\x61nnouncement_id\x18\x01 \x01(\t\x12\x30\n\x0c\x61nnouncement\x18\x02 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\"\x1a\n\x18UpdateAnnouncementOutput\"2\n\x17\x44\x65leteAnnouncementInput\x12\x17\n\x0f\x61nnouncement_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteAnnouncementOutput\"0\n\x15ReadAnnouncementInput\x12\x17\n\x0f\x61nnouncement_id\x18\x01 \x01(\t\"\x18\n\x16ReadAnnouncementOutput\"4\n\x19\x44\x65scribeAnnouncementInput\x12\x17\n\x0f\x61nnouncement_id\x18\x01 \x01(\t\"N\n\x1a\x44\x65scribeAnnouncementOutput\x12\x30\n\x0c\x61nnouncement\x18\x01 \x01(\x0b\x32\x1a.eolymp.judge.Announcement\":\n\x1f\x44\x65scribeAnnouncementStatusInput\x12\x17\n\x0f\x61nnouncement_id\x18\x01 \x01(\t\"3\n DescribeAnnouncementStatusOutput\x12\x0f\n\x07is_read\x18\x01 \x01(\x08\"\xf1\x01\n\x16ListAnnouncementsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12<\n\x07\x66ilters\x18( \x01(\x0b\x32+.eolymp.judge.ListAnnouncementsInput.Filter\x1ag\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\x07is_read\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"S\n\x17ListAnnouncementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.judge.Announcement\"C\n\x19\x44\x65scribeCodeTemplateInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x12\n\nruntime_id\x18\x02 \x01(\t\".\n\x1a\x44\x65scribeCodeTemplateOutput\x12\x10\n\x08template\x18\x01 \x01(\t\"Y\n\x15\x43reateScoreboardInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12,\n\nscoreboard\x18\x02 \x01(\x0b\x32\x18.eolymp.judge.Scoreboard\"/\n\x16\x43reateScoreboardOutput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\\\n\x15UpdateScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12,\n\nscoreboard\x18\x02 \x01(\x0b\x32\x18.eolymp.judge.Scoreboard\"\x18\n\x16UpdateScoreboardOutput\"/\n\x16RebuildScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x19\n\x17RebuildScoreboardOutput\".\n\x15\x44\x65leteScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteScoreboardOutput\"0\n\x17\x44\x65scribeScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"H\n\x18\x44\x65scribeScoreboardOutput\x12,\n\nscoreboard\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Scoreboard\"4\n\x1e\x44\x65scribeDefaultScoreboardInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"O\n\x1f\x44\x65scribeDefaultScoreboardOutput\x12,\n\nscoreboard\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Scoreboard\"\xd1\x02\n\x14ListScoreboardsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.judge.ListScoreboardsInput.Filter\x1a\xca\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\x07visible\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x31\n\x07\x64\x65\x66\x61ult\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04type\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"O\n\x15ListScoreboardsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.judge.Scoreboard\"K\n\x1a\x44\x65scribeScoreboardRowInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"H\n\x1b\x44\x65scribeScoreboardRowOutput\x12)\n\x03row\x18\x01 \x01(\x0b\x32\x1c.eolymp.judge.Scoreboard.Row\"O\n!DescribeDefaultScoreboardRowInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"O\n\"DescribeDefaultScoreboardRowOutput\x12)\n\x03row\x18\x01 \x01(\x0b\x32\x1c.eolymp.judge.Scoreboard.Row\"\xc6\x04\n\x17ListScoreboardRowsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.judge.ListScoreboardRowsInput.Filter\x1a\xb6\x03\n\x06\x46ilter\x12\x36\n\x0eparticipant_id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x34\n\x08username\x18\x08 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x04 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x32\n\x07penalty\x18\x05 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x39\n\nstarted_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12:\n\x0b\x63omplete_at\x18\x07 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\"V\n\x18ListScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.eolymp.judge.Scoreboard.Row\"\x91\x01\n\x1eListDefaultScoreboardRowsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.judge.ListScoreboardRowsInput.Filter\"]\n\x1fListDefaultScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.eolymp.judge.Scoreboard.Row\"\x80\x01\n\x15ListEntitlementsInput\x12\x14\n\ncontest_id\x18\x01 \x01(\tH\x00\x12\x17\n\rsubmission_id\x18\x02 \x01(\tH\x00\x12\x13\n\tticket_id\x18\x03 \x01(\tH\x00\x12\x18\n\x0eparticipant_id\x18\x04 \x01(\tH\x00\x42\t\n\x07\x63ontext\"I\n\x16ListEntitlementsOutput\x12/\n\x0c\x65ntitlements\x18\x01 \x03(\x0e\x32\x19.eolymp.judge.Entitlement\"G\n\x13ListActivitiesInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"L\n\x14ListActivitiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.judge.Activity\"d\n\x18\x43onfigureAppearanceInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x34\n\nappearance\x18\x02 \x01(\x0b\x32 .eolymp.judge.Contest.Appearance\"\x1b\n\x19\x43onfigureAppearanceOutput\"-\n\x17\x44\x65scribeAppearanceInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"P\n\x18\x44\x65scribeAppearanceOutput\x12\x34\n\nappearance\x18\x01 \x01(\x0b\x32 .eolymp.judge.Contest.Appearance2\xa5k\n\x05Judge\x12\xa0\x01\n\rCreateContest\x12 .eolymp.judge.CreateContestInput\x1a!.eolymp.judge.CreateContestOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7\xa3=\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a\"\x0f/judge/contests:\x07\x63ontest\x12\xa4\x01\n\rDeleteContest\x12 .eolymp.judge.DeleteContestInput\x1a!.eolymp.judge.DeleteContestOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/judge/contests/{contest_id}\x12\xad\x01\n\rUpdateContest\x12 .eolymp.judge.UpdateContestInput\x1a!.eolymp.judge.UpdateContestOutput\"W\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\'\x1a\x1c/judge/contests/{contest_id}:\x07\x63ontest\x12\x8c\x01\n\rLookupContest\x12 .eolymp.judge.LookupContestInput\x1a!.eolymp.judge.LookupContestOutput\"6\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02 \x12\x1b/judge/contest-lookup/{key}b\x01*\x12\x98\x01\n\x0f\x44\x65scribeContest\x12\".eolymp.judge.DescribeContestInput\x1a#.eolymp.judge.DescribeContestOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\'\x12\x1c/judge/contests/{contest_id}b\x07\x63ontest\x12y\n\x0cListContests\x12\x1f.eolymp.judge.ListContestsInput\x1a .eolymp.judge.ListContestsOutput\"&\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x11\x12\x0f/judge/contests\x12\xa3\x01\n\x0bOpenContest\x12\x1e.eolymp.judge.OpenContestInput\x1a\x1f.eolymp.judge.OpenContestOutput\"S\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02#\"!/judge/contests/{contest_id}/open\x12\xa7\x01\n\x0c\x43loseContest\x12\x1f.eolymp.judge.CloseContestInput\x1a .eolymp.judge.CloseContestOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02$\"\"/judge/contests/{contest_id}/close\x12\xda\x01\n\x19\x43onfigureRegistrationForm\x12,.eolymp.judge.ConfigureRegistrationFormInput\x1a-.eolymp.judge.ConfigureRegistrationFormOutput\"`\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x30\"./judge/contests/{contest_id}/registration-form\x12\xdc\x01\n\x18\x44\x65scribeRegistrationForm\x12+.eolymp.judge.DescribeRegistrationFormInput\x1a,.eolymp.judge.DescribeRegistrationFormOutput\"e\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x36\x12./judge/contests/{contest_id}/registration-formb\x04\x66orm\x12\xb5\x01\n\x10\x43onfigureRuntime\x12#.eolymp.judge.ConfigureRuntimeInput\x1a$.eolymp.judge.ConfigureRuntimeOutput\"V\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&\"$/judge/contests/{contest_id}/runtime\x12\xb1\x01\n\x0f\x44\x65scribeRuntime\x12\".eolymp.judge.DescribeRuntimeInput\x1a#.eolymp.judge.DescribeRuntimeOutput\"U\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02&\x12$/judge/contests/{contest_id}/runtime\x12\xc1\x01\n\x13\x43onfigureAppearance\x12&.eolymp.judge.ConfigureAppearanceInput\x1a\'.eolymp.judge.ConfigureAppearanceOutput\"Y\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02)\"\'/judge/contests/{contest_id}/appearance\x12\xbd\x01\n\x12\x44\x65scribeAppearance\x12%.eolymp.judge.DescribeAppearanceInput\x1a&.eolymp.judge.DescribeAppearanceOutput\"X\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02)\x12\'/judge/contests/{contest_id}/appearance\x12\xc2\x01\n\x12SubmitRegistration\x12%.eolymp.judge.SubmitRegistrationInput\x1a&.eolymp.judge.SubmitRegistrationOutput\"]\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\'\"%/judge/contests/{contest_id}/register\x12\xcd\x01\n\x14\x44\x65scribeRegistration\x12\'.eolymp.judge.DescribeRegistrationInput\x1a(.eolymp.judge.DescribeRegistrationOutput\"b\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x33\x12\x31/judge/participants/{participant_id}/registration\x12\xb3\x01\n\rImportProblem\x12 .eolymp.judge.ImportProblemInput\x1a!.eolymp.judge.ImportProblemOutput\"]\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02-\"+/judge/contests/{contest_id}/import/problem\x12\xa3\x01\n\x0bSyncProblem\x12\x1e.eolymp.judge.SyncProblemInput\x1a\x1f.eolymp.judge.SyncProblemOutput\"S\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02#\"!/judge/problems/{problem_id}/sync\x12\xa4\x01\n\rUpdateProblem\x12 .eolymp.judge.UpdateProblemInput\x1a!.eolymp.judge.UpdateProblemOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\"\x1c/judge/problems/{problem_id}\x12\xa9\x01\n\x0cListProblems\x12\x1f.eolymp.judge.ListProblemsInput\x1a .eolymp.judge.ListProblemsOutput\"V\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00@@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\'\x12%/judge/contests/{contest_id}/problems\x12\xa9\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.judge.DescribeProblemInput\x1a#.eolymp.judge.DescribeProblemOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1e\x12\x1c/judge/problems/{problem_id}\x12\xd2\x01\n\x14\x44\x65scribeCodeTemplate\x12\'.eolymp.judge.DescribeCodeTemplateInput\x1a(.eolymp.judge.DescribeCodeTemplateOutput\"g\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x38\x12\x33/judge/problems/{problem_id}/templates/{runtime_id}b\x01*\x12\xb1\x01\n\x0eListStatements\x12!.eolymp.judge.ListStatementsInput\x1a\".eolymp.judge.ListStatementsOutput\"X\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02)\x12\'/judge/problems/{problem_id}/statements\x12\xaa\x01\n\x0cListExamples\x12\x1f.eolymp.judge.ListExamplesInput\x1a .eolymp.judge.ListExamplesOutput\"W\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02(\x12&/judge/problems/{problem_id}/examples/\x12\xa4\x01\n\rDeleteProblem\x12 .eolymp.judge.DeleteProblemInput\x1a!.eolymp.judge.DeleteProblemOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/judge/problems/{problem_id}\x12\xae\x01\n\rRetestProblem\x12 .eolymp.judge.RetestProblemInput\x1a!.eolymp.judge.RetestProblemOutput\"X\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02(\x12#/judge/problems/{problem_id}/retestb\x01*\x12\xb7\x01\n\x0e\x41\x64\x64Participant\x12!.eolymp.judge.AddParticipantInput\x1a\".eolymp.judge.AddParticipantOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02.\")/judge/contests/{contest_id}/participants:\x01*\x12\xbf\x01\n\x11\x45nableParticipant\x12$.eolymp.judge.EnableParticipantInput\x1a%.eolymp.judge.EnableParticipantOutput\"]\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02-\"+/judge/participants/{participant_id}/enable\x12\xc3\x01\n\x12\x44isableParticipant\x12%.eolymp.judge.DisableParticipantInput\x1a&.eolymp.judge.DisableParticipantOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02.\",/judge/participants/{participant_id}/disable\x12\xb8\x01\n\x11RemoveParticipant\x12$.eolymp.judge.RemoveParticipantInput\x1a%.eolymp.judge.RemoveParticipantOutput\"V\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&*$/judge/participants/{participant_id}\x12\xb9\x01\n\x10ListParticipants\x12#.eolymp.judge.ListParticipantsInput\x1a$.eolymp.judge.ListParticipantsOutput\"Z\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02+\x12)/judge/contests/{contest_id}/participants\x12\xcb\x01\n\x13\x44\x65scribeParticipant\x12&.eolymp.judge.DescribeParticipantInput\x1a\'.eolymp.judge.DescribeParticipantOutput\"c\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x33\x12$/judge/participants/{participant_id}b\x0bparticipant\x12\xd3\x01\n\x15IntrospectParticipant\x12(.eolymp.judge.IntrospectParticipantInput\x1a).eolymp.judge.IntrospectParticipantOutput\"e\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x36\x12\'/judge/contests/{contest_id}/introspectb\x0bparticipant\x12\x88\x01\n\x0bJoinContest\x12\x1e.eolymp.judge.JoinContestInput\x1a\x1f.eolymp.judge.JoinContestOutput\"8\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xd3\xe4\x93\x02#\"!/judge/contests/{contest_id}/join\x12\xad\x01\n\x0cStartContest\x12\x1f.eolymp.judge.StartContestInput\x1a .eolymp.judge.StartContestOutput\"Z\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xd3\xe4\x93\x02$\"\"/judge/contests/{contest_id}/start\x12\xaf\x01\n\x0eVerifyPasscode\x12!.eolymp.judge.VerifyPasscodeInput\x1a\".eolymp.judge.VerifyPasscodeOutput\"V\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\'\x12%/judge/contests/{contest_id}/passcode\x12\xac\x01\n\rEnterPasscode\x12 .eolymp.judge.EnterPasscodeInput\x1a!.eolymp.judge.EnterPasscodeOutput\"V\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\'\"%/judge/contests/{contest_id}/passcode\x12\xb5\x01\n\rResetPasscode\x12 .eolymp.judge.ResetPasscodeInput\x1a!.eolymp.judge.ResetPasscodeOutput\"_\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02/\"-/judge/participants/{participant_id}/passcode\x12\xb8\x01\n\x0eRemovePasscode\x12!.eolymp.judge.RemovePasscodeInput\x1a\".eolymp.judge.RemovePasscodeOutput\"_\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02/*-/judge/participants/{participant_id}/passcode\x12\xc2\x01\n\x10\x43reateSubmission\x12#.eolymp.judge.CreateSubmissionInput\x1a$.eolymp.judge.CreateSubmissionOutput\"c\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xd3\xe4\x93\x02-\"(/judge/problems/{problem_id}/submissions:\x01*\x12\x97\x02\n\x0fListSubmissions\x12\".eolymp.judge.ListSubmissionsInput\x1a#.eolymp.judge.ListSubmissionsOutput\"\xba\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x8a\x01\x12(/judge/contests/{contest_id}/submissionsZ*\x12(/judge/problems/{problem_id}/submissionsZ2\x12\x30/judge/participants/{participant_id}/submissions\x12\xc4\x01\n\x12\x44\x65scribeSubmission\x12%.eolymp.judge.DescribeSubmissionInput\x1a&.eolymp.judge.DescribeSubmissionOutput\"_\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x30\x12\"/judge/submissions/{submission_id}b\nsubmission\x12\xbd\x01\n\x10RetestSubmission\x12#.eolymp.judge.RetestSubmissionInput\x1a$.eolymp.judge.RetestSubmissionOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02.\x12)/judge/submissions/{submission_id}/retestb\x01*\x12\xb2\x01\n\x0c\x43reateTicket\x12\x1f.eolymp.judge.CreateTicketInput\x1a .eolymp.judge.CreateTicketOutput\"_\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02)\"$/judge/contests/{contest_id}/ticketsb\x01*\x12\xa5\x01\n\x0b\x43loseTicket\x12\x1e.eolymp.judge.CloseTicketInput\x1a\x1f.eolymp.judge.CloseTicketOutput\"U\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02%\" /judge/tickets/{ticket_id}/closeb\x01*\x12\xa1\x01\n\nOpenTicket\x12\x1d.eolymp.judge.OpenTicketInput\x1a\x1e.eolymp.judge.OpenTicketOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02$\"\x1f/judge/tickets/{ticket_id}/openb\x01*\x12\xa0\x01\n\nReadTicket\x12\x1d.eolymp.judge.ReadTicketInput\x1a\x1e.eolymp.judge.ReadTicketOutput\"S\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02$\"\x1f/judge/tickets/{ticket_id}/readb\x01*\x12\xa2\x01\n\x0c\x44\x65leteTicket\x12\x1f.eolymp.judge.DeleteTicketInput\x1a .eolymp.judge.DeleteTicketOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1f*\x1a/judge/tickets/{ticket_id}b\x01*\x12\xac\x01\n\x0e\x44\x65scribeTicket\x12!.eolymp.judge.DescribeTicketInput\x1a\".eolymp.judge.DescribeTicketOutput\"S\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02$\x12\x1a/judge/tickets/{ticket_id}b\x06ticket\x12\x92\x01\n\x0bListTickets\x12\x1e.eolymp.judge.ListTicketsInput\x1a\x1f.eolymp.judge.ListTicketsOutput\"B\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x13\x12\x0e/judge/ticketsb\x01*\x12\xad\x01\n\x0bReplyTicket\x12\x1e.eolymp.judge.ReplyTicketInput\x1a\x1f.eolymp.judge.ReplyTicketOutput\"]\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\'\"\"/judge/tickets/{ticket_id}/repliesb\x01*\x12\xa6\x01\n\x0bListReplies\x12\x1e.eolymp.judge.ListRepliesInput\x1a\x1f.eolymp.judge.ListRepliesOutput\"V\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\'\x12\"/judge/tickets/{ticket_id}/repliesb\x01*\x12\x9e\x01\n\x0b\x44\x65leteReply\x12\x1e.eolymp.judge.DeleteReplyInput\x1a\x1f.eolymp.judge.DeleteReplyOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x19/judge/replies/{reply_id}b\x01*\x12\x9e\x01\n\x0bUpdateReply\x12\x1e.eolymp.judge.UpdateReplyInput\x1a\x1f.eolymp.judge.UpdateReplyOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\"\x19/judge/replies/{reply_id}b\x01*\x12\xc4\x01\n\x12\x43reateAnnouncement\x12%.eolymp.judge.CreateAnnouncementInput\x1a&.eolymp.judge.CreateAnnouncementOutput\"_\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02/\"*/judge/contests/{contest_id}/announcementsb\x01*\x12\xbd\x01\n\x12UpdateAnnouncement\x12%.eolymp.judge.UpdateAnnouncementInput\x1a&.eolymp.judge.UpdateAnnouncementOutput\"X\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02(\"&/judge/announcements/{announcement_id}\x12\xbd\x01\n\x12\x44\x65leteAnnouncement\x12%.eolymp.judge.DeleteAnnouncementInput\x1a&.eolymp.judge.DeleteAnnouncementOutput\"X\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02(*&/judge/announcements/{announcement_id}\x12\xbe\x01\n\x10ReadAnnouncement\x12#.eolymp.judge.ReadAnnouncementInput\x1a$.eolymp.judge.ReadAnnouncementOutput\"_\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x30\"+/judge/announcements/{announcement_id}/readb\x01*\x12\xd0\x01\n\x14\x44\x65scribeAnnouncement\x12\'.eolymp.judge.DescribeAnnouncementInput\x1a(.eolymp.judge.DescribeAnnouncementOutput\"e\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x36\x12&/judge/announcements/{announcement_id}b\x0c\x61nnouncement\x12\xde\x01\n\x1a\x44\x65scribeAnnouncementStatus\x12-.eolymp.judge.DescribeAnnouncementStatusInput\x1a..eolymp.judge.DescribeAnnouncementStatusOutput\"a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x32\x12-/judge/announcements/{announcement_id}/statusb\x01*\x12\xc0\x01\n\x11ListAnnouncements\x12$.eolymp.judge.ListAnnouncementsInput\x1a%.eolymp.judge.ListAnnouncementsOutput\"^\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02/\x12*/judge/contests/{contest_id}/announcementsb\x01*\x12\xbc\x01\n\x10\x43reateScoreboard\x12#.eolymp.judge.CreateScoreboardInput\x1a$.eolymp.judge.CreateScoreboardOutput\"]\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02-\"(/judge/contests/{contest_id}/scoreboardsb\x01*\x12\xb3\x01\n\x10UpdateScoreboard\x12#.eolymp.judge.UpdateScoreboardInput\x1a$.eolymp.judge.UpdateScoreboardOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02$\"\"/judge/scoreboards/{scoreboard_id}\x12\xbe\x01\n\x11RebuildScoreboard\x12$.eolymp.judge.RebuildScoreboardInput\x1a%.eolymp.judge.RebuildScoreboardOutput\"\\\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02,\"*/judge/scoreboards/{scoreboard_id}/rebuild\x12\xb3\x01\n\x10\x44\x65leteScoreboard\x12#.eolymp.judge.DeleteScoreboardInput\x1a$.eolymp.judge.DeleteScoreboardOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02$*\"/judge/scoreboards/{scoreboard_id}\x12\xc4\x01\n\x12\x44\x65scribeScoreboard\x12%.eolymp.judge.DescribeScoreboardInput\x1a&.eolymp.judge.DescribeScoreboardOutput\"_\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x30\x12\"/judge/scoreboards/{scoreboard_id}b\nscoreboard\x12\xde\x01\n\x19\x44\x65scribeDefaultScoreboard\x12,.eolymp.judge.DescribeDefaultScoreboardInput\x1a-.eolymp.judge.DescribeDefaultScoreboardOutput\"d\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x35\x12\'/judge/contests/{contest_id}/scoreboardb\nscoreboard\x12\xb8\x01\n\x0fListScoreboards\x12\".eolymp.judge.ListScoreboardsInput\x1a#.eolymp.judge.ListScoreboardsOutput\"\\\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02-\x12(/judge/contests/{contest_id}/scoreboardsb\x01*\x12\xdd\x01\n\x15\x44\x65scribeScoreboardRow\x12(.eolymp.judge.DescribeScoreboardRowInput\x1a).eolymp.judge.DescribeScoreboardRowOutput\"o\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02?\x12\x38/judge/scoreboards/{scoreboard_id}/rows/{participant_id}b\x03row\x12\xf7\x01\n\x1c\x44\x65scribeDefaultScoreboardRow\x12/.eolymp.judge.DescribeDefaultScoreboardRowInput\x1a\x30.eolymp.judge.DescribeDefaultScoreboardRowOutput\"t\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x44\x12=/judge/contests/{contest_id}/scoreboard/rows/{participant_id}b\x03row\x12\xc0\x01\n\x12ListScoreboardRows\x12%.eolymp.judge.ListScoreboardRowsInput\x1a&.eolymp.judge.ListScoreboardRowsOutput\"[\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02,\x12\'/judge/scoreboards/{scoreboard_id}/rowsb\x01*\x12\xda\x01\n\x19ListDefaultScoreboardRows\x12,.eolymp.judge.ListDefaultScoreboardRowsInput\x1a-.eolymp.judge.ListDefaultScoreboardRowsOutput\"`\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x31\x12,/judge/contests/{contest_id}/scoreboard/rowsb\x01*\x12\x89\x01\n\x10ListEntitlements\x12#.eolymp.judge.ListEntitlementsInput\x1a$.eolymp.judge.ListEntitlementsOutput\"*\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x15\x12\x13/judge/entitlements\x12\xb4\x01\n\x0eListActivities\x12!.eolymp.judge.ListActivitiesInput\x1a\".eolymp.judge.ListActivitiesOutput\"[\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02,\x12\'/judge/contests/{contest_id}/activitiesb\x01*B3Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_direction__pb2.DESCRIPTOR,eolymp_dot_judge_dot_activity__pb2.DESCRIPTOR,eolymp_dot_judge_dot_announcement__pb2.DESCRIPTOR,eolymp_dot_judge_dot_contest__pb2.DESCRIPTOR,eolymp_dot_judge_dot_entitlement__pb2.DESCRIPTOR,eolymp_dot_judge_dot_form__pb2.DESCRIPTOR,eolymp_dot_judge_dot_participant__pb2.DESCRIPTOR,eolymp_dot_judge_dot_problem__pb2.DESCRIPTOR,eolymp_dot_judge_dot_reply__pb2.DESCRIPTOR,eolymp_dot_judge_dot_scoreboard__pb2.DESCRIPTOR,eolymp_dot_judge_dot_submission__pb2.DESCRIPTOR,eolymp_dot_judge_dot_ticket__pb2.DESCRIPTOR,])



_LISTPARTICIPANTSINPUT_SORTABLE = _descriptor.EnumDescriptor(
  name='Sortable',
  full_name='eolymp.judge.ListParticipantsInput.Sortable',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RANK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCORE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENALTY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTED_AT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETE_AT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4265,
  serialized_end=4342,
)
_sym_db.RegisterEnumDescriptor(_LISTPARTICIPANTSINPUT_SORTABLE)


_CREATECONTESTINPUT = _descriptor.Descriptor(
  name='CreateContestInput',
  full_name='eolymp.judge.CreateContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest', full_name='eolymp.judge.CreateContestInput.contest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.judge.CreateContestInput.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=637,
)


_CREATECONTESTOUTPUT = _descriptor.Descriptor(
  name='CreateContestOutput',
  full_name='eolymp.judge.CreateContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.CreateContestOutput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=639,
  serialized_end=680,
)


_DELETECONTESTINPUT = _descriptor.Descriptor(
  name='DeleteContestInput',
  full_name='eolymp.judge.DeleteContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.DeleteContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=722,
)


_DELETECONTESTOUTPUT = _descriptor.Descriptor(
  name='DeleteContestOutput',
  full_name='eolymp.judge.DeleteContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=724,
  serialized_end=745,
)


_UPDATECONTESTINPUT = _descriptor.Descriptor(
  name='UpdateContestInput',
  full_name='eolymp.judge.UpdateContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.UpdateContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest', full_name='eolymp.judge.UpdateContestInput.contest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=827,
)


_UPDATECONTESTOUTPUT = _descriptor.Descriptor(
  name='UpdateContestOutput',
  full_name='eolymp.judge.UpdateContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=850,
)


_DESCRIBECONTESTINPUT = _descriptor.Descriptor(
  name='DescribeContestInput',
  full_name='eolymp.judge.DescribeContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.DescribeContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=894,
)


_DESCRIBECONTESTOUTPUT = _descriptor.Descriptor(
  name='DescribeContestOutput',
  full_name='eolymp.judge.DescribeContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest', full_name='eolymp.judge.DescribeContestOutput.contest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=959,
)


_LOOKUPCONTESTINPUT = _descriptor.Descriptor(
  name='LookupContestInput',
  full_name='eolymp.judge.LookupContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.judge.LookupContestInput.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=961,
  serialized_end=994,
)


_LOOKUPCONTESTOUTPUT = _descriptor.Descriptor(
  name='LookupContestOutput',
  full_name='eolymp.judge.LookupContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest', full_name='eolymp.judge.LookupContestOutput.contest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appearance', full_name='eolymp.judge.LookupContestOutput.appearance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=996,
  serialized_end=1111,
)


_LISTCONTESTSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.judge.ListContestsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.ListContestsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='own', full_name='eolymp.judge.ListContestsInput.Filter.own', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.judge.ListContestsInput.Filter.name', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='starts_at', full_name='eolymp.judge.ListContestsInput.Filter.starts_at', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ends_at', full_name='eolymp.judge.ListContestsInput.Filter.ends_at', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public', full_name='eolymp.judge.ListContestsInput.Filter.public', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='eolymp.judge.ListContestsInput.Filter.visibility', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1223,
  serialized_end=1590,
)

_LISTCONTESTSINPUT = _descriptor.Descriptor(
  name='ListContestsInput',
  full_name='eolymp.judge.ListContestsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListContestsInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListContestsInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.judge.ListContestsInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTCONTESTSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1114,
  serialized_end=1590,
)


_LISTCONTESTSOUTPUT = _descriptor.Descriptor(
  name='ListContestsOutput',
  full_name='eolymp.judge.ListContestsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListContestsOutput.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListContestsOutput.total', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1592,
  serialized_end=1665,
)


_OPENCONTESTINPUT = _descriptor.Descriptor(
  name='OpenContestInput',
  full_name='eolymp.judge.OpenContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.OpenContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1667,
  serialized_end=1705,
)


_OPENCONTESTOUTPUT = _descriptor.Descriptor(
  name='OpenContestOutput',
  full_name='eolymp.judge.OpenContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1707,
  serialized_end=1726,
)


_CLOSECONTESTINPUT = _descriptor.Descriptor(
  name='CloseContestInput',
  full_name='eolymp.judge.CloseContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.CloseContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1728,
  serialized_end=1767,
)


_CLOSECONTESTOUTPUT = _descriptor.Descriptor(
  name='CloseContestOutput',
  full_name='eolymp.judge.CloseContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1769,
  serialized_end=1789,
)


_JOINCONTESTINPUT = _descriptor.Descriptor(
  name='JoinContestInput',
  full_name='eolymp.judge.JoinContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.JoinContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1791,
  serialized_end=1829,
)


_JOINCONTESTOUTPUT = _descriptor.Descriptor(
  name='JoinContestOutput',
  full_name='eolymp.judge.JoinContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1831,
  serialized_end=1850,
)


_STARTCONTESTINPUT = _descriptor.Descriptor(
  name='StartContestInput',
  full_name='eolymp.judge.StartContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.StartContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1852,
  serialized_end=1891,
)


_STARTCONTESTOUTPUT = _descriptor.Descriptor(
  name='StartContestOutput',
  full_name='eolymp.judge.StartContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1893,
  serialized_end=1913,
)


_IMPORTPROBLEMINPUT = _descriptor.Descriptor(
  name='ImportProblemInput',
  full_name='eolymp.judge.ImportProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ImportProblemInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='import_id', full_name='eolymp.judge.ImportProblemInput.import_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.judge.ImportProblemInput.index', index=2,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submit_limit', full_name='eolymp.judge.ImportProblemInput.submit_limit', index=3,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1915,
  serialized_end=2011,
)


_IMPORTPROBLEMOUTPUT = _descriptor.Descriptor(
  name='ImportProblemOutput',
  full_name='eolymp.judge.ImportProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.ImportProblemOutput.problem_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2013,
  serialized_end=2054,
)


_SYNCPROBLEMINPUT = _descriptor.Descriptor(
  name='SyncProblemInput',
  full_name='eolymp.judge.SyncProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.SyncProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2056,
  serialized_end=2094,
)


_SYNCPROBLEMOUTPUT = _descriptor.Descriptor(
  name='SyncProblemOutput',
  full_name='eolymp.judge.SyncProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2096,
  serialized_end=2115,
)


_UPDATEPROBLEMINPUT = _descriptor.Descriptor(
  name='UpdateProblemInput',
  full_name='eolymp.judge.UpdateProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.UpdateProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.judge.UpdateProblemInput.index', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submit_limit', full_name='eolymp.judge.UpdateProblemInput.submit_limit', index=2,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2117,
  serialized_end=2194,
)


_UPDATEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='UpdateProblemOutput',
  full_name='eolymp.judge.UpdateProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2196,
  serialized_end=2217,
)


_DELETEPROBLEMINPUT = _descriptor.Descriptor(
  name='DeleteProblemInput',
  full_name='eolymp.judge.DeleteProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.DeleteProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2219,
  serialized_end=2259,
)


_DELETEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='DeleteProblemOutput',
  full_name='eolymp.judge.DeleteProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2261,
  serialized_end=2282,
)


_RETESTPROBLEMINPUT = _descriptor.Descriptor(
  name='RetestProblemInput',
  full_name='eolymp.judge.RetestProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.RetestProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2284,
  serialized_end=2324,
)


_RETESTPROBLEMOUTPUT = _descriptor.Descriptor(
  name='RetestProblemOutput',
  full_name='eolymp.judge.RetestProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2326,
  serialized_end=2347,
)


_LISTPROBLEMSINPUT = _descriptor.Descriptor(
  name='ListProblemsInput',
  full_name='eolymp.judge.ListProblemsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListProblemsInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListProblemsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListProblemsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2349,
  serialized_end=2418,
)


_LISTPROBLEMSOUTPUT = _descriptor.Descriptor(
  name='ListProblemsOutput',
  full_name='eolymp.judge.ListProblemsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListProblemsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListProblemsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2420,
  serialized_end=2493,
)


_DESCRIBEPROBLEMINPUT = _descriptor.Descriptor(
  name='DescribeProblemInput',
  full_name='eolymp.judge.DescribeProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.DescribeProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2495,
  serialized_end=2537,
)


_DESCRIBEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='DescribeProblemOutput',
  full_name='eolymp.judge.DescribeProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem', full_name='eolymp.judge.DescribeProblemOutput.problem', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2539,
  serialized_end=2602,
)


_LISTSTATEMENTSINPUT = _descriptor.Descriptor(
  name='ListStatementsInput',
  full_name='eolymp.judge.ListStatementsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.ListStatementsInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2604,
  serialized_end=2645,
)


_LISTSTATEMENTSOUTPUT = _descriptor.Descriptor(
  name='ListStatementsOutput',
  full_name='eolymp.judge.ListStatementsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListStatementsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListStatementsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2647,
  serialized_end=2732,
)


_LISTEXAMPLESINPUT = _descriptor.Descriptor(
  name='ListExamplesInput',
  full_name='eolymp.judge.ListExamplesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.ListExamplesInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2734,
  serialized_end=2773,
)


_LISTEXAMPLESOUTPUT = _descriptor.Descriptor(
  name='ListExamplesOutput',
  full_name='eolymp.judge.ListExamplesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListExamplesOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListExamplesOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2775,
  serialized_end=2853,
)


_ADDPARTICIPANTINPUT = _descriptor.Descriptor(
  name='AddParticipantInput',
  full_name='eolymp.judge.AddParticipantInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.AddParticipantInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.judge.AddParticipantInput.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='eolymp.judge.AddParticipantInput.users', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.judge.AddParticipantInput.user_id', index=3,
      number=999, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2855,
  serialized_end=2975,
)


_ADDPARTICIPANTOUTPUT = _descriptor.Descriptor(
  name='AddParticipantOutput',
  full_name='eolymp.judge.AddParticipantOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.AddParticipantOutput.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2977,
  serialized_end=3023,
)


_ENABLEPARTICIPANTINPUT = _descriptor.Descriptor(
  name='EnableParticipantInput',
  full_name='eolymp.judge.EnableParticipantInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.EnableParticipantInput.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3025,
  serialized_end=3073,
)


_ENABLEPARTICIPANTOUTPUT = _descriptor.Descriptor(
  name='EnableParticipantOutput',
  full_name='eolymp.judge.EnableParticipantOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3075,
  serialized_end=3100,
)


_DISABLEPARTICIPANTINPUT = _descriptor.Descriptor(
  name='DisableParticipantInput',
  full_name='eolymp.judge.DisableParticipantInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.DisableParticipantInput.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3102,
  serialized_end=3151,
)


_DISABLEPARTICIPANTOUTPUT = _descriptor.Descriptor(
  name='DisableParticipantOutput',
  full_name='eolymp.judge.DisableParticipantOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3153,
  serialized_end=3179,
)


_REMOVEPARTICIPANTINPUT = _descriptor.Descriptor(
  name='RemoveParticipantInput',
  full_name='eolymp.judge.RemoveParticipantInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.RemoveParticipantInput.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3181,
  serialized_end=3229,
)


_REMOVEPARTICIPANTOUTPUT = _descriptor.Descriptor(
  name='RemoveParticipantOutput',
  full_name='eolymp.judge.RemoveParticipantOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3231,
  serialized_end=3256,
)


_VERIFYPASSCODEINPUT = _descriptor.Descriptor(
  name='VerifyPasscodeInput',
  full_name='eolymp.judge.VerifyPasscodeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.VerifyPasscodeInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3258,
  serialized_end=3299,
)


_VERIFYPASSCODEOUTPUT = _descriptor.Descriptor(
  name='VerifyPasscodeOutput',
  full_name='eolymp.judge.VerifyPasscodeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='required', full_name='eolymp.judge.VerifyPasscodeOutput.required', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid', full_name='eolymp.judge.VerifyPasscodeOutput.valid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3301,
  serialized_end=3356,
)


_ENTERPASSCODEINPUT = _descriptor.Descriptor(
  name='EnterPasscodeInput',
  full_name='eolymp.judge.EnterPasscodeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.EnterPasscodeInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passcode', full_name='eolymp.judge.EnterPasscodeInput.passcode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3358,
  serialized_end=3416,
)


_ENTERPASSCODEOUTPUT = _descriptor.Descriptor(
  name='EnterPasscodeOutput',
  full_name='eolymp.judge.EnterPasscodeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3418,
  serialized_end=3439,
)


_RESETPASSCODEINPUT = _descriptor.Descriptor(
  name='ResetPasscodeInput',
  full_name='eolymp.judge.ResetPasscodeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.ResetPasscodeInput.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3441,
  serialized_end=3485,
)


_RESETPASSCODEOUTPUT = _descriptor.Descriptor(
  name='ResetPasscodeOutput',
  full_name='eolymp.judge.ResetPasscodeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='passcode', full_name='eolymp.judge.ResetPasscodeOutput.passcode', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3487,
  serialized_end=3526,
)


_REMOVEPASSCODEINPUT = _descriptor.Descriptor(
  name='RemovePasscodeInput',
  full_name='eolymp.judge.RemovePasscodeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.RemovePasscodeInput.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3528,
  serialized_end=3573,
)


_REMOVEPASSCODEOUTPUT = _descriptor.Descriptor(
  name='RemovePasscodeOutput',
  full_name='eolymp.judge.RemovePasscodeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3575,
  serialized_end=3597,
)


_LISTPARTICIPANTSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.judge.ListParticipantsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.ListParticipantsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.judge.ListParticipantsInput.Filter.user_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.judge.ListParticipantsInput.Filter.name', index=2,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.ListParticipantsInput.Filter.status', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.ListParticipantsInput.Filter.score', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty', full_name='eolymp.judge.ListParticipantsInput.Filter.penalty', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='eolymp.judge.ListParticipantsInput.Filter.started_at', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='complete_at', full_name='eolymp.judge.ListParticipantsInput.Filter.complete_at', index=7,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3841,
  serialized_end=4263,
)

_LISTPARTICIPANTSINPUT = _descriptor.Descriptor(
  name='ListParticipantsInput',
  full_name='eolymp.judge.ListParticipantsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListParticipantsInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListParticipantsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListParticipantsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.judge.ListParticipantsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort', full_name='eolymp.judge.ListParticipantsInput.sort', index=4,
      number=50, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='eolymp.judge.ListParticipantsInput.order', index=5,
      number=51, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPARTICIPANTSINPUT_FILTER, ],
  enum_types=[
    _LISTPARTICIPANTSINPUT_SORTABLE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3600,
  serialized_end=4342,
)


_LISTPARTICIPANTSOUTPUT = _descriptor.Descriptor(
  name='ListParticipantsOutput',
  full_name='eolymp.judge.ListParticipantsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListParticipantsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListParticipantsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4344,
  serialized_end=4425,
)


_INTROSPECTPARTICIPANTINPUT = _descriptor.Descriptor(
  name='IntrospectParticipantInput',
  full_name='eolymp.judge.IntrospectParticipantInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.IntrospectParticipantInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4427,
  serialized_end=4475,
)


_INTROSPECTPARTICIPANTOUTPUT = _descriptor.Descriptor(
  name='IntrospectParticipantOutput',
  full_name='eolymp.judge.IntrospectParticipantOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant', full_name='eolymp.judge.IntrospectParticipantOutput.participant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4477,
  serialized_end=4554,
)


_DESCRIBEPARTICIPANTINPUT = _descriptor.Descriptor(
  name='DescribeParticipantInput',
  full_name='eolymp.judge.DescribeParticipantInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.DescribeParticipantInput.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4556,
  serialized_end=4606,
)


_DESCRIBEPARTICIPANTOUTPUT = _descriptor.Descriptor(
  name='DescribeParticipantOutput',
  full_name='eolymp.judge.DescribeParticipantOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant', full_name='eolymp.judge.DescribeParticipantOutput.participant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4608,
  serialized_end=4683,
)


_CREATESUBMISSIONINPUT = _descriptor.Descriptor(
  name='CreateSubmissionInput',
  full_name='eolymp.judge.CreateSubmissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.CreateSubmissionInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.judge.CreateSubmissionInput.lang', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.judge.CreateSubmissionInput.source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4685,
  serialized_end=4758,
)


_CREATESUBMISSIONOUTPUT = _descriptor.Descriptor(
  name='CreateSubmissionOutput',
  full_name='eolymp.judge.CreateSubmissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='eolymp.judge.CreateSubmissionOutput.submission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4760,
  serialized_end=4807,
)


_LISTSUBMISSIONSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.judge.ListSubmissionsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.ListSubmissionsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.ListSubmissionsInput.Filter.participant_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.ListSubmissionsInput.Filter.problem_id', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.ListSubmissionsInput.Filter.status', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.judge.ListSubmissionsInput.Filter.lang', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.ListSubmissionsInput.Filter.score', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='eolymp.judge.ListSubmissionsInput.Filter.percentage', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submitted_at', full_name='eolymp.judge.ListSubmissionsInput.Filter.submitted_at', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='eolymp.judge.ListSubmissionsInput.Filter.signature', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4945,
  serialized_end=5422,
)

_LISTSUBMISSIONSINPUT = _descriptor.Descriptor(
  name='ListSubmissionsInput',
  full_name='eolymp.judge.ListSubmissionsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListSubmissionsInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListSubmissionsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListSubmissionsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.judge.ListSubmissionsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSUBMISSIONSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4810,
  serialized_end=5422,
)


_LISTSUBMISSIONSOUTPUT = _descriptor.Descriptor(
  name='ListSubmissionsOutput',
  full_name='eolymp.judge.ListSubmissionsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListSubmissionsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListSubmissionsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5424,
  serialized_end=5503,
)


_DESCRIBESUBMISSIONINPUT = _descriptor.Descriptor(
  name='DescribeSubmissionInput',
  full_name='eolymp.judge.DescribeSubmissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='eolymp.judge.DescribeSubmissionInput.submission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5505,
  serialized_end=5553,
)


_DESCRIBESUBMISSIONOUTPUT = _descriptor.Descriptor(
  name='DescribeSubmissionOutput',
  full_name='eolymp.judge.DescribeSubmissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission', full_name='eolymp.judge.DescribeSubmissionOutput.submission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5555,
  serialized_end=5627,
)


_RETESTSUBMISSIONINPUT = _descriptor.Descriptor(
  name='RetestSubmissionInput',
  full_name='eolymp.judge.RetestSubmissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='eolymp.judge.RetestSubmissionInput.submission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5629,
  serialized_end=5675,
)


_RETESTSUBMISSIONOUTPUT = _descriptor.Descriptor(
  name='RetestSubmissionOutput',
  full_name='eolymp.judge.RetestSubmissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5677,
  serialized_end=5701,
)


_CREATETICKETINPUT = _descriptor.Descriptor(
  name='CreateTicketInput',
  full_name='eolymp.judge.CreateTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.CreateTicketInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject', full_name='eolymp.judge.CreateTicketInput.subject', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='eolymp.judge.CreateTicketInput.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5703,
  serialized_end=5776,
)


_CREATETICKETOUTPUT = _descriptor.Descriptor(
  name='CreateTicketOutput',
  full_name='eolymp.judge.CreateTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.CreateTicketOutput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5778,
  serialized_end=5817,
)


_CLOSETICKETINPUT = _descriptor.Descriptor(
  name='CloseTicketInput',
  full_name='eolymp.judge.CloseTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.CloseTicketInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5819,
  serialized_end=5856,
)


_CLOSETICKETOUTPUT = _descriptor.Descriptor(
  name='CloseTicketOutput',
  full_name='eolymp.judge.CloseTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5858,
  serialized_end=5877,
)


_OPENTICKETINPUT = _descriptor.Descriptor(
  name='OpenTicketInput',
  full_name='eolymp.judge.OpenTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.OpenTicketInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5879,
  serialized_end=5915,
)


_OPENTICKETOUTPUT = _descriptor.Descriptor(
  name='OpenTicketOutput',
  full_name='eolymp.judge.OpenTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5917,
  serialized_end=5935,
)


_READTICKETINPUT = _descriptor.Descriptor(
  name='ReadTicketInput',
  full_name='eolymp.judge.ReadTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.ReadTicketInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5937,
  serialized_end=5973,
)


_READTICKETOUTPUT = _descriptor.Descriptor(
  name='ReadTicketOutput',
  full_name='eolymp.judge.ReadTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5975,
  serialized_end=5993,
)


_DELETETICKETINPUT = _descriptor.Descriptor(
  name='DeleteTicketInput',
  full_name='eolymp.judge.DeleteTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.DeleteTicketInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5995,
  serialized_end=6033,
)


_DELETETICKETOUTPUT = _descriptor.Descriptor(
  name='DeleteTicketOutput',
  full_name='eolymp.judge.DeleteTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6035,
  serialized_end=6055,
)


_DESCRIBETICKETINPUT = _descriptor.Descriptor(
  name='DescribeTicketInput',
  full_name='eolymp.judge.DescribeTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.DescribeTicketInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6057,
  serialized_end=6097,
)


_DESCRIBETICKETOUTPUT = _descriptor.Descriptor(
  name='DescribeTicketOutput',
  full_name='eolymp.judge.DescribeTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket', full_name='eolymp.judge.DescribeTicketOutput.ticket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6099,
  serialized_end=6159,
)


_LISTTICKETSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.judge.ListTicketsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.ListTicketsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListTicketsInput.Filter.contest_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.ListTicketsInput.Filter.participant_id', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_read_by_participant', full_name='eolymp.judge.ListTicketsInput.Filter.is_read_by_participant', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_read_by_owner', full_name='eolymp.judge.ListTicketsInput.Filter.is_read_by_owner', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_open', full_name='eolymp.judge.ListTicketsInput.Filter.is_open', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='own', full_name='eolymp.judge.ListTicketsInput.Filter.own', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6269,
  serialized_end=6653,
)

_LISTTICKETSINPUT = _descriptor.Descriptor(
  name='ListTicketsInput',
  full_name='eolymp.judge.ListTicketsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListTicketsInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListTicketsInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.judge.ListTicketsInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTTICKETSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6162,
  serialized_end=6653,
)


_LISTTICKETSOUTPUT = _descriptor.Descriptor(
  name='ListTicketsOutput',
  full_name='eolymp.judge.ListTicketsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListTicketsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListTicketsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6655,
  serialized_end=6726,
)


_REPLYTICKETINPUT = _descriptor.Descriptor(
  name='ReplyTicketInput',
  full_name='eolymp.judge.ReplyTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.ReplyTicketInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='eolymp.judge.ReplyTicketInput.message', index=1,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='eolymp.judge.ReplyTicketInput.close', index=2,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6728,
  serialized_end=6797,
)


_REPLYTICKETOUTPUT = _descriptor.Descriptor(
  name='ReplyTicketOutput',
  full_name='eolymp.judge.ReplyTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reply_id', full_name='eolymp.judge.ReplyTicketOutput.reply_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6799,
  serialized_end=6836,
)


_LISTREPLIESINPUT = _descriptor.Descriptor(
  name='ListRepliesInput',
  full_name='eolymp.judge.ListRepliesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.ListRepliesInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListRepliesInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListRepliesInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6838,
  serialized_end=6905,
)


_LISTREPLIESOUTPUT = _descriptor.Descriptor(
  name='ListRepliesOutput',
  full_name='eolymp.judge.ListRepliesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListRepliesOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListRepliesOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6907,
  serialized_end=6977,
)


_DELETEREPLYINPUT = _descriptor.Descriptor(
  name='DeleteReplyInput',
  full_name='eolymp.judge.DeleteReplyInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reply_id', full_name='eolymp.judge.DeleteReplyInput.reply_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6979,
  serialized_end=7015,
)


_DELETEREPLYOUTPUT = _descriptor.Descriptor(
  name='DeleteReplyOutput',
  full_name='eolymp.judge.DeleteReplyOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7017,
  serialized_end=7036,
)


_UPDATEREPLYINPUT = _descriptor.Descriptor(
  name='UpdateReplyInput',
  full_name='eolymp.judge.UpdateReplyInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reply_id', full_name='eolymp.judge.UpdateReplyInput.reply_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='eolymp.judge.UpdateReplyInput.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7038,
  serialized_end=7091,
)


_UPDATEREPLYOUTPUT = _descriptor.Descriptor(
  name='UpdateReplyOutput',
  full_name='eolymp.judge.UpdateReplyOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7093,
  serialized_end=7112,
)


_CONFIGUREREGISTRATIONFORMINPUT = _descriptor.Descriptor(
  name='ConfigureRegistrationFormInput',
  full_name='eolymp.judge.ConfigureRegistrationFormInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ConfigureRegistrationFormInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='form', full_name='eolymp.judge.ConfigureRegistrationFormInput.form', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7114,
  serialized_end=7200,
)


_CONFIGUREREGISTRATIONFORMOUTPUT = _descriptor.Descriptor(
  name='ConfigureRegistrationFormOutput',
  full_name='eolymp.judge.ConfigureRegistrationFormOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7202,
  serialized_end=7235,
)


_DESCRIBEREGISTRATIONFORMINPUT = _descriptor.Descriptor(
  name='DescribeRegistrationFormInput',
  full_name='eolymp.judge.DescribeRegistrationFormInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.DescribeRegistrationFormInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7237,
  serialized_end=7288,
)


_DESCRIBEREGISTRATIONFORMOUTPUT = _descriptor.Descriptor(
  name='DescribeRegistrationFormOutput',
  full_name='eolymp.judge.DescribeRegistrationFormOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='form', full_name='eolymp.judge.DescribeRegistrationFormOutput.form', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7290,
  serialized_end=7356,
)


_CONFIGURERUNTIMEINPUT = _descriptor.Descriptor(
  name='ConfigureRuntimeInput',
  full_name='eolymp.judge.ConfigureRuntimeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ConfigureRuntimeInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime', full_name='eolymp.judge.ConfigureRuntimeInput.runtime', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7358,
  serialized_end=7418,
)


_CONFIGURERUNTIMEOUTPUT = _descriptor.Descriptor(
  name='ConfigureRuntimeOutput',
  full_name='eolymp.judge.ConfigureRuntimeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7420,
  serialized_end=7444,
)


_DESCRIBERUNTIMEINPUT = _descriptor.Descriptor(
  name='DescribeRuntimeInput',
  full_name='eolymp.judge.DescribeRuntimeInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.DescribeRuntimeInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7446,
  serialized_end=7488,
)


_DESCRIBERUNTIMEOUTPUT = _descriptor.Descriptor(
  name='DescribeRuntimeOutput',
  full_name='eolymp.judge.DescribeRuntimeOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='runtime', full_name='eolymp.judge.DescribeRuntimeOutput.runtime', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7490,
  serialized_end=7530,
)


_SUBMITREGISTRATIONINPUT = _descriptor.Descriptor(
  name='SubmitRegistrationInput',
  full_name='eolymp.judge.SubmitRegistrationInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.SubmitRegistrationInput.participant_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registration', full_name='eolymp.judge.SubmitRegistrationInput.registration', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7532,
  serialized_end=7631,
)


_SUBMITREGISTRATIONOUTPUT = _descriptor.Descriptor(
  name='SubmitRegistrationOutput',
  full_name='eolymp.judge.SubmitRegistrationOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7633,
  serialized_end=7659,
)


_DESCRIBEREGISTRATIONINPUT = _descriptor.Descriptor(
  name='DescribeRegistrationInput',
  full_name='eolymp.judge.DescribeRegistrationInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.DescribeRegistrationInput.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7661,
  serialized_end=7712,
)


_DESCRIBEREGISTRATIONOUTPUT = _descriptor.Descriptor(
  name='DescribeRegistrationOutput',
  full_name='eolymp.judge.DescribeRegistrationOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='registration', full_name='eolymp.judge.DescribeRegistrationOutput.registration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7714,
  serialized_end=7792,
)


_CREATEANNOUNCEMENTINPUT = _descriptor.Descriptor(
  name='CreateAnnouncementInput',
  full_name='eolymp.judge.CreateAnnouncementInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.CreateAnnouncementInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='announcement', full_name='eolymp.judge.CreateAnnouncementInput.announcement', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7794,
  serialized_end=7889,
)


_CREATEANNOUNCEMENTOUTPUT = _descriptor.Descriptor(
  name='CreateAnnouncementOutput',
  full_name='eolymp.judge.CreateAnnouncementOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.CreateAnnouncementOutput.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7891,
  serialized_end=7929,
)


_UPDATEANNOUNCEMENTINPUT = _descriptor.Descriptor(
  name='UpdateAnnouncementInput',
  full_name='eolymp.judge.UpdateAnnouncementInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcement_id', full_name='eolymp.judge.UpdateAnnouncementInput.announcement_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='announcement', full_name='eolymp.judge.UpdateAnnouncementInput.announcement', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7931,
  serialized_end=8031,
)


_UPDATEANNOUNCEMENTOUTPUT = _descriptor.Descriptor(
  name='UpdateAnnouncementOutput',
  full_name='eolymp.judge.UpdateAnnouncementOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8033,
  serialized_end=8059,
)


_DELETEANNOUNCEMENTINPUT = _descriptor.Descriptor(
  name='DeleteAnnouncementInput',
  full_name='eolymp.judge.DeleteAnnouncementInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcement_id', full_name='eolymp.judge.DeleteAnnouncementInput.announcement_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8061,
  serialized_end=8111,
)


_DELETEANNOUNCEMENTOUTPUT = _descriptor.Descriptor(
  name='DeleteAnnouncementOutput',
  full_name='eolymp.judge.DeleteAnnouncementOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8113,
  serialized_end=8139,
)


_READANNOUNCEMENTINPUT = _descriptor.Descriptor(
  name='ReadAnnouncementInput',
  full_name='eolymp.judge.ReadAnnouncementInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcement_id', full_name='eolymp.judge.ReadAnnouncementInput.announcement_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8141,
  serialized_end=8189,
)


_READANNOUNCEMENTOUTPUT = _descriptor.Descriptor(
  name='ReadAnnouncementOutput',
  full_name='eolymp.judge.ReadAnnouncementOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8191,
  serialized_end=8215,
)


_DESCRIBEANNOUNCEMENTINPUT = _descriptor.Descriptor(
  name='DescribeAnnouncementInput',
  full_name='eolymp.judge.DescribeAnnouncementInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcement_id', full_name='eolymp.judge.DescribeAnnouncementInput.announcement_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8217,
  serialized_end=8269,
)


_DESCRIBEANNOUNCEMENTOUTPUT = _descriptor.Descriptor(
  name='DescribeAnnouncementOutput',
  full_name='eolymp.judge.DescribeAnnouncementOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcement', full_name='eolymp.judge.DescribeAnnouncementOutput.announcement', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8271,
  serialized_end=8349,
)


_DESCRIBEANNOUNCEMENTSTATUSINPUT = _descriptor.Descriptor(
  name='DescribeAnnouncementStatusInput',
  full_name='eolymp.judge.DescribeAnnouncementStatusInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcement_id', full_name='eolymp.judge.DescribeAnnouncementStatusInput.announcement_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8351,
  serialized_end=8409,
)


_DESCRIBEANNOUNCEMENTSTATUSOUTPUT = _descriptor.Descriptor(
  name='DescribeAnnouncementStatusOutput',
  full_name='eolymp.judge.DescribeAnnouncementStatusOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_read', full_name='eolymp.judge.DescribeAnnouncementStatusOutput.is_read', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8411,
  serialized_end=8462,
)


_LISTANNOUNCEMENTSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.judge.ListAnnouncementsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.ListAnnouncementsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_read', full_name='eolymp.judge.ListAnnouncementsInput.Filter.is_read', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8603,
  serialized_end=8706,
)

_LISTANNOUNCEMENTSINPUT = _descriptor.Descriptor(
  name='ListAnnouncementsInput',
  full_name='eolymp.judge.ListAnnouncementsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListAnnouncementsInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListAnnouncementsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListAnnouncementsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.judge.ListAnnouncementsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTANNOUNCEMENTSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8465,
  serialized_end=8706,
)


_LISTANNOUNCEMENTSOUTPUT = _descriptor.Descriptor(
  name='ListAnnouncementsOutput',
  full_name='eolymp.judge.ListAnnouncementsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListAnnouncementsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListAnnouncementsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8708,
  serialized_end=8791,
)


_DESCRIBECODETEMPLATEINPUT = _descriptor.Descriptor(
  name='DescribeCodeTemplateInput',
  full_name='eolymp.judge.DescribeCodeTemplateInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.DescribeCodeTemplateInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_id', full_name='eolymp.judge.DescribeCodeTemplateInput.runtime_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8793,
  serialized_end=8860,
)


_DESCRIBECODETEMPLATEOUTPUT = _descriptor.Descriptor(
  name='DescribeCodeTemplateOutput',
  full_name='eolymp.judge.DescribeCodeTemplateOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='eolymp.judge.DescribeCodeTemplateOutput.template', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8862,
  serialized_end=8908,
)


_CREATESCOREBOARDINPUT = _descriptor.Descriptor(
  name='CreateScoreboardInput',
  full_name='eolymp.judge.CreateScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.CreateScoreboardInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.judge.CreateScoreboardInput.scoreboard', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8910,
  serialized_end=8999,
)


_CREATESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='CreateScoreboardOutput',
  full_name='eolymp.judge.CreateScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.judge.CreateScoreboardOutput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9001,
  serialized_end=9048,
)


_UPDATESCOREBOARDINPUT = _descriptor.Descriptor(
  name='UpdateScoreboardInput',
  full_name='eolymp.judge.UpdateScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.judge.UpdateScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.judge.UpdateScoreboardInput.scoreboard', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9050,
  serialized_end=9142,
)


_UPDATESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='UpdateScoreboardOutput',
  full_name='eolymp.judge.UpdateScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9144,
  serialized_end=9168,
)


_REBUILDSCOREBOARDINPUT = _descriptor.Descriptor(
  name='RebuildScoreboardInput',
  full_name='eolymp.judge.RebuildScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.judge.RebuildScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9170,
  serialized_end=9217,
)


_REBUILDSCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='RebuildScoreboardOutput',
  full_name='eolymp.judge.RebuildScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9219,
  serialized_end=9244,
)


_DELETESCOREBOARDINPUT = _descriptor.Descriptor(
  name='DeleteScoreboardInput',
  full_name='eolymp.judge.DeleteScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.judge.DeleteScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9246,
  serialized_end=9292,
)


_DELETESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='DeleteScoreboardOutput',
  full_name='eolymp.judge.DeleteScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9294,
  serialized_end=9318,
)


_DESCRIBESCOREBOARDINPUT = _descriptor.Descriptor(
  name='DescribeScoreboardInput',
  full_name='eolymp.judge.DescribeScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.judge.DescribeScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9320,
  serialized_end=9368,
)


_DESCRIBESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='DescribeScoreboardOutput',
  full_name='eolymp.judge.DescribeScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.judge.DescribeScoreboardOutput.scoreboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9370,
  serialized_end=9442,
)


_DESCRIBEDEFAULTSCOREBOARDINPUT = _descriptor.Descriptor(
  name='DescribeDefaultScoreboardInput',
  full_name='eolymp.judge.DescribeDefaultScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.DescribeDefaultScoreboardInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9444,
  serialized_end=9496,
)


_DESCRIBEDEFAULTSCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='DescribeDefaultScoreboardOutput',
  full_name='eolymp.judge.DescribeDefaultScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.judge.DescribeDefaultScoreboardOutput.scoreboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9498,
  serialized_end=9577,
)


_LISTSCOREBOARDSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.judge.ListScoreboardsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.ListScoreboardsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visible', full_name='eolymp.judge.ListScoreboardsInput.Filter.visible', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default', full_name='eolymp.judge.ListScoreboardsInput.Filter.default', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.judge.ListScoreboardsInput.Filter.type', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9715,
  serialized_end=9917,
)

_LISTSCOREBOARDSINPUT = _descriptor.Descriptor(
  name='ListScoreboardsInput',
  full_name='eolymp.judge.ListScoreboardsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListScoreboardsInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListScoreboardsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListScoreboardsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.judge.ListScoreboardsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSCOREBOARDSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9580,
  serialized_end=9917,
)


_LISTSCOREBOARDSOUTPUT = _descriptor.Descriptor(
  name='ListScoreboardsOutput',
  full_name='eolymp.judge.ListScoreboardsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListScoreboardsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListScoreboardsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9919,
  serialized_end=9998,
)


_DESCRIBESCOREBOARDROWINPUT = _descriptor.Descriptor(
  name='DescribeScoreboardRowInput',
  full_name='eolymp.judge.DescribeScoreboardRowInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.judge.DescribeScoreboardRowInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.DescribeScoreboardRowInput.participant_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10000,
  serialized_end=10075,
)


_DESCRIBESCOREBOARDROWOUTPUT = _descriptor.Descriptor(
  name='DescribeScoreboardRowOutput',
  full_name='eolymp.judge.DescribeScoreboardRowOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='row', full_name='eolymp.judge.DescribeScoreboardRowOutput.row', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10077,
  serialized_end=10149,
)


_DESCRIBEDEFAULTSCOREBOARDROWINPUT = _descriptor.Descriptor(
  name='DescribeDefaultScoreboardRowInput',
  full_name='eolymp.judge.DescribeDefaultScoreboardRowInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.DescribeDefaultScoreboardRowInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.DescribeDefaultScoreboardRowInput.participant_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10151,
  serialized_end=10230,
)


_DESCRIBEDEFAULTSCOREBOARDROWOUTPUT = _descriptor.Descriptor(
  name='DescribeDefaultScoreboardRowOutput',
  full_name='eolymp.judge.DescribeDefaultScoreboardRowOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='row', full_name='eolymp.judge.DescribeDefaultScoreboardRowOutput.row', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10232,
  serialized_end=10311,
)


_LISTSCOREBOARDROWSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.judge.ListScoreboardRowsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.ListScoreboardRowsInput.Filter.participant_id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.judge.ListScoreboardRowsInput.Filter.user_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='eolymp.judge.ListScoreboardRowsInput.Filter.username', index=2,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.ListScoreboardRowsInput.Filter.status', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.ListScoreboardRowsInput.Filter.score', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty', full_name='eolymp.judge.ListScoreboardRowsInput.Filter.penalty', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='eolymp.judge.ListScoreboardRowsInput.Filter.started_at', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='complete_at', full_name='eolymp.judge.ListScoreboardRowsInput.Filter.complete_at', index=7,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10458,
  serialized_end=10896,
)

_LISTSCOREBOARDROWSINPUT = _descriptor.Descriptor(
  name='ListScoreboardRowsInput',
  full_name='eolymp.judge.ListScoreboardRowsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.judge.ListScoreboardRowsInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListScoreboardRowsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListScoreboardRowsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.judge.ListScoreboardRowsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSCOREBOARDROWSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10314,
  serialized_end=10896,
)


_LISTSCOREBOARDROWSOUTPUT = _descriptor.Descriptor(
  name='ListScoreboardRowsOutput',
  full_name='eolymp.judge.ListScoreboardRowsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListScoreboardRowsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListScoreboardRowsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10898,
  serialized_end=10984,
)


_LISTDEFAULTSCOREBOARDROWSINPUT = _descriptor.Descriptor(
  name='ListDefaultScoreboardRowsInput',
  full_name='eolymp.judge.ListDefaultScoreboardRowsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListDefaultScoreboardRowsInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListDefaultScoreboardRowsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListDefaultScoreboardRowsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.judge.ListDefaultScoreboardRowsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10987,
  serialized_end=11132,
)


_LISTDEFAULTSCOREBOARDROWSOUTPUT = _descriptor.Descriptor(
  name='ListDefaultScoreboardRowsOutput',
  full_name='eolymp.judge.ListDefaultScoreboardRowsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListDefaultScoreboardRowsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListDefaultScoreboardRowsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11134,
  serialized_end=11227,
)


_LISTENTITLEMENTSINPUT = _descriptor.Descriptor(
  name='ListEntitlementsInput',
  full_name='eolymp.judge.ListEntitlementsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListEntitlementsInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='eolymp.judge.ListEntitlementsInput.submission_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.ListEntitlementsInput.ticket_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.ListEntitlementsInput.participant_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='context', full_name='eolymp.judge.ListEntitlementsInput.context',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=11230,
  serialized_end=11358,
)


_LISTENTITLEMENTSOUTPUT = _descriptor.Descriptor(
  name='ListEntitlementsOutput',
  full_name='eolymp.judge.ListEntitlementsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entitlements', full_name='eolymp.judge.ListEntitlementsOutput.entitlements', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11360,
  serialized_end=11433,
)


_LISTACTIVITIESINPUT = _descriptor.Descriptor(
  name='ListActivitiesInput',
  full_name='eolymp.judge.ListActivitiesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListActivitiesInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListActivitiesInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListActivitiesInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11435,
  serialized_end=11506,
)


_LISTACTIVITIESOUTPUT = _descriptor.Descriptor(
  name='ListActivitiesOutput',
  full_name='eolymp.judge.ListActivitiesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListActivitiesOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListActivitiesOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11508,
  serialized_end=11584,
)


_CONFIGUREAPPEARANCEINPUT = _descriptor.Descriptor(
  name='ConfigureAppearanceInput',
  full_name='eolymp.judge.ConfigureAppearanceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ConfigureAppearanceInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appearance', full_name='eolymp.judge.ConfigureAppearanceInput.appearance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11586,
  serialized_end=11686,
)


_CONFIGUREAPPEARANCEOUTPUT = _descriptor.Descriptor(
  name='ConfigureAppearanceOutput',
  full_name='eolymp.judge.ConfigureAppearanceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11688,
  serialized_end=11715,
)


_DESCRIBEAPPEARANCEINPUT = _descriptor.Descriptor(
  name='DescribeAppearanceInput',
  full_name='eolymp.judge.DescribeAppearanceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.DescribeAppearanceInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11717,
  serialized_end=11762,
)


_DESCRIBEAPPEARANCEOUTPUT = _descriptor.Descriptor(
  name='DescribeAppearanceOutput',
  full_name='eolymp.judge.DescribeAppearanceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appearance', full_name='eolymp.judge.DescribeAppearanceOutput.appearance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11764,
  serialized_end=11844,
)

_CREATECONTESTINPUT.fields_by_name['contest'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST
_CREATECONTESTINPUT.fields_by_name['type'].enum_type = eolymp_dot_judge_dot_scoreboard__pb2._SCOREBOARD_TYPE
_UPDATECONTESTINPUT.fields_by_name['contest'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST
_DESCRIBECONTESTOUTPUT.fields_by_name['contest'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST
_LOOKUPCONTESTOUTPUT.fields_by_name['contest'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST
_LOOKUPCONTESTOUTPUT.fields_by_name['appearance'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST_APPEARANCE
_LISTCONTESTSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTCONTESTSINPUT_FILTER.fields_by_name['own'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTCONTESTSINPUT_FILTER.fields_by_name['name'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTCONTESTSINPUT_FILTER.fields_by_name['starts_at'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONTIMESTAMP
_LISTCONTESTSINPUT_FILTER.fields_by_name['ends_at'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONTIMESTAMP
_LISTCONTESTSINPUT_FILTER.fields_by_name['public'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTCONTESTSINPUT_FILTER.fields_by_name['visibility'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTCONTESTSINPUT_FILTER.containing_type = _LISTCONTESTSINPUT
_LISTCONTESTSINPUT.fields_by_name['filters'].message_type = _LISTCONTESTSINPUT_FILTER
_LISTCONTESTSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST
_LISTPROBLEMSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_problem__pb2._PROBLEM
_DESCRIBEPROBLEMOUTPUT.fields_by_name['problem'].message_type = eolymp_dot_judge_dot_problem__pb2._PROBLEM
_LISTSTATEMENTSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_problem__pb2._PROBLEM_STATEMENT
_LISTEXAMPLESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_problem__pb2._PROBLEM_TEST
_ADDPARTICIPANTINPUT.fields_by_name['users'].message_type = eolymp_dot_judge_dot_participant__pb2._PARTICIPANT_USER
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['user_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['name'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['status'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['score'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONFLOAT
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['penalty'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONFLOAT
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['started_at'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONTIMESTAMP
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['complete_at'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONTIMESTAMP
_LISTPARTICIPANTSINPUT_FILTER.containing_type = _LISTPARTICIPANTSINPUT
_LISTPARTICIPANTSINPUT.fields_by_name['filters'].message_type = _LISTPARTICIPANTSINPUT_FILTER
_LISTPARTICIPANTSINPUT.fields_by_name['sort'].enum_type = _LISTPARTICIPANTSINPUT_SORTABLE
_LISTPARTICIPANTSINPUT.fields_by_name['order'].enum_type = eolymp_dot_wellknown_dot_direction__pb2._DIRECTION
_LISTPARTICIPANTSINPUT_SORTABLE.containing_type = _LISTPARTICIPANTSINPUT
_LISTPARTICIPANTSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_participant__pb2._PARTICIPANT
_INTROSPECTPARTICIPANTOUTPUT.fields_by_name['participant'].message_type = eolymp_dot_judge_dot_participant__pb2._PARTICIPANT
_DESCRIBEPARTICIPANTOUTPUT.fields_by_name['participant'].message_type = eolymp_dot_judge_dot_participant__pb2._PARTICIPANT
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['participant_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['problem_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['status'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['lang'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['score'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONFLOAT
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['percentage'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONFLOAT
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['submitted_at'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONTIMESTAMP
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['signature'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTSUBMISSIONSINPUT_FILTER.containing_type = _LISTSUBMISSIONSINPUT
_LISTSUBMISSIONSINPUT.fields_by_name['filters'].message_type = _LISTSUBMISSIONSINPUT_FILTER
_LISTSUBMISSIONSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_submission__pb2._SUBMISSION
_DESCRIBESUBMISSIONOUTPUT.fields_by_name['submission'].message_type = eolymp_dot_judge_dot_submission__pb2._SUBMISSION
_DESCRIBETICKETOUTPUT.fields_by_name['ticket'].message_type = eolymp_dot_judge_dot_ticket__pb2._TICKET
_LISTTICKETSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTTICKETSINPUT_FILTER.fields_by_name['contest_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTTICKETSINPUT_FILTER.fields_by_name['participant_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTTICKETSINPUT_FILTER.fields_by_name['is_read_by_participant'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTTICKETSINPUT_FILTER.fields_by_name['is_read_by_owner'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTTICKETSINPUT_FILTER.fields_by_name['is_open'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTTICKETSINPUT_FILTER.fields_by_name['own'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTTICKETSINPUT_FILTER.containing_type = _LISTTICKETSINPUT
_LISTTICKETSINPUT.fields_by_name['filters'].message_type = _LISTTICKETSINPUT_FILTER
_LISTTICKETSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_ticket__pb2._TICKET
_LISTREPLIESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_reply__pb2._REPLY
_CONFIGUREREGISTRATIONFORMINPUT.fields_by_name['form'].message_type = eolymp_dot_judge_dot_form__pb2._FORM
_DESCRIBEREGISTRATIONFORMOUTPUT.fields_by_name['form'].message_type = eolymp_dot_judge_dot_form__pb2._FORM
_SUBMITREGISTRATIONINPUT.fields_by_name['registration'].message_type = eolymp_dot_judge_dot_form__pb2._REGISTRATION
_DESCRIBEREGISTRATIONOUTPUT.fields_by_name['registration'].message_type = eolymp_dot_judge_dot_form__pb2._REGISTRATION
_CREATEANNOUNCEMENTINPUT.fields_by_name['announcement'].message_type = eolymp_dot_judge_dot_announcement__pb2._ANNOUNCEMENT
_UPDATEANNOUNCEMENTINPUT.fields_by_name['announcement'].message_type = eolymp_dot_judge_dot_announcement__pb2._ANNOUNCEMENT
_DESCRIBEANNOUNCEMENTOUTPUT.fields_by_name['announcement'].message_type = eolymp_dot_judge_dot_announcement__pb2._ANNOUNCEMENT
_LISTANNOUNCEMENTSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTANNOUNCEMENTSINPUT_FILTER.fields_by_name['is_read'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTANNOUNCEMENTSINPUT_FILTER.containing_type = _LISTANNOUNCEMENTSINPUT
_LISTANNOUNCEMENTSINPUT.fields_by_name['filters'].message_type = _LISTANNOUNCEMENTSINPUT_FILTER
_LISTANNOUNCEMENTSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_announcement__pb2._ANNOUNCEMENT
_CREATESCOREBOARDINPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_judge_dot_scoreboard__pb2._SCOREBOARD
_UPDATESCOREBOARDINPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_judge_dot_scoreboard__pb2._SCOREBOARD
_DESCRIBESCOREBOARDOUTPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_judge_dot_scoreboard__pb2._SCOREBOARD
_DESCRIBEDEFAULTSCOREBOARDOUTPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_judge_dot_scoreboard__pb2._SCOREBOARD
_LISTSCOREBOARDSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSCOREBOARDSINPUT_FILTER.fields_by_name['visible'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTSCOREBOARDSINPUT_FILTER.fields_by_name['default'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTSCOREBOARDSINPUT_FILTER.fields_by_name['type'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTSCOREBOARDSINPUT_FILTER.containing_type = _LISTSCOREBOARDSINPUT
_LISTSCOREBOARDSINPUT.fields_by_name['filters'].message_type = _LISTSCOREBOARDSINPUT_FILTER
_LISTSCOREBOARDSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_scoreboard__pb2._SCOREBOARD
_DESCRIBESCOREBOARDROWOUTPUT.fields_by_name['row'].message_type = eolymp_dot_judge_dot_scoreboard__pb2._SCOREBOARD_ROW
_DESCRIBEDEFAULTSCOREBOARDROWOUTPUT.fields_by_name['row'].message_type = eolymp_dot_judge_dot_scoreboard__pb2._SCOREBOARD_ROW
_LISTSCOREBOARDROWSINPUT_FILTER.fields_by_name['participant_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSCOREBOARDROWSINPUT_FILTER.fields_by_name['user_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSCOREBOARDROWSINPUT_FILTER.fields_by_name['username'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTSCOREBOARDROWSINPUT_FILTER.fields_by_name['status'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTSCOREBOARDROWSINPUT_FILTER.fields_by_name['score'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONFLOAT
_LISTSCOREBOARDROWSINPUT_FILTER.fields_by_name['penalty'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONFLOAT
_LISTSCOREBOARDROWSINPUT_FILTER.fields_by_name['started_at'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONTIMESTAMP
_LISTSCOREBOARDROWSINPUT_FILTER.fields_by_name['complete_at'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONTIMESTAMP
_LISTSCOREBOARDROWSINPUT_FILTER.containing_type = _LISTSCOREBOARDROWSINPUT
_LISTSCOREBOARDROWSINPUT.fields_by_name['filters'].message_type = _LISTSCOREBOARDROWSINPUT_FILTER
_LISTSCOREBOARDROWSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_scoreboard__pb2._SCOREBOARD_ROW
_LISTDEFAULTSCOREBOARDROWSINPUT.fields_by_name['filters'].message_type = _LISTSCOREBOARDROWSINPUT_FILTER
_LISTDEFAULTSCOREBOARDROWSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_scoreboard__pb2._SCOREBOARD_ROW
_LISTENTITLEMENTSINPUT.oneofs_by_name['context'].fields.append(
  _LISTENTITLEMENTSINPUT.fields_by_name['contest_id'])
_LISTENTITLEMENTSINPUT.fields_by_name['contest_id'].containing_oneof = _LISTENTITLEMENTSINPUT.oneofs_by_name['context']
_LISTENTITLEMENTSINPUT.oneofs_by_name['context'].fields.append(
  _LISTENTITLEMENTSINPUT.fields_by_name['submission_id'])
_LISTENTITLEMENTSINPUT.fields_by_name['submission_id'].containing_oneof = _LISTENTITLEMENTSINPUT.oneofs_by_name['context']
_LISTENTITLEMENTSINPUT.oneofs_by_name['context'].fields.append(
  _LISTENTITLEMENTSINPUT.fields_by_name['ticket_id'])
_LISTENTITLEMENTSINPUT.fields_by_name['ticket_id'].containing_oneof = _LISTENTITLEMENTSINPUT.oneofs_by_name['context']
_LISTENTITLEMENTSINPUT.oneofs_by_name['context'].fields.append(
  _LISTENTITLEMENTSINPUT.fields_by_name['participant_id'])
_LISTENTITLEMENTSINPUT.fields_by_name['participant_id'].containing_oneof = _LISTENTITLEMENTSINPUT.oneofs_by_name['context']
_LISTENTITLEMENTSOUTPUT.fields_by_name['entitlements'].enum_type = eolymp_dot_judge_dot_entitlement__pb2._ENTITLEMENT
_LISTACTIVITIESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_activity__pb2._ACTIVITY
_CONFIGUREAPPEARANCEINPUT.fields_by_name['appearance'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST_APPEARANCE
_DESCRIBEAPPEARANCEOUTPUT.fields_by_name['appearance'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST_APPEARANCE
DESCRIPTOR.message_types_by_name['CreateContestInput'] = _CREATECONTESTINPUT
DESCRIPTOR.message_types_by_name['CreateContestOutput'] = _CREATECONTESTOUTPUT
DESCRIPTOR.message_types_by_name['DeleteContestInput'] = _DELETECONTESTINPUT
DESCRIPTOR.message_types_by_name['DeleteContestOutput'] = _DELETECONTESTOUTPUT
DESCRIPTOR.message_types_by_name['UpdateContestInput'] = _UPDATECONTESTINPUT
DESCRIPTOR.message_types_by_name['UpdateContestOutput'] = _UPDATECONTESTOUTPUT
DESCRIPTOR.message_types_by_name['DescribeContestInput'] = _DESCRIBECONTESTINPUT
DESCRIPTOR.message_types_by_name['DescribeContestOutput'] = _DESCRIBECONTESTOUTPUT
DESCRIPTOR.message_types_by_name['LookupContestInput'] = _LOOKUPCONTESTINPUT
DESCRIPTOR.message_types_by_name['LookupContestOutput'] = _LOOKUPCONTESTOUTPUT
DESCRIPTOR.message_types_by_name['ListContestsInput'] = _LISTCONTESTSINPUT
DESCRIPTOR.message_types_by_name['ListContestsOutput'] = _LISTCONTESTSOUTPUT
DESCRIPTOR.message_types_by_name['OpenContestInput'] = _OPENCONTESTINPUT
DESCRIPTOR.message_types_by_name['OpenContestOutput'] = _OPENCONTESTOUTPUT
DESCRIPTOR.message_types_by_name['CloseContestInput'] = _CLOSECONTESTINPUT
DESCRIPTOR.message_types_by_name['CloseContestOutput'] = _CLOSECONTESTOUTPUT
DESCRIPTOR.message_types_by_name['JoinContestInput'] = _JOINCONTESTINPUT
DESCRIPTOR.message_types_by_name['JoinContestOutput'] = _JOINCONTESTOUTPUT
DESCRIPTOR.message_types_by_name['StartContestInput'] = _STARTCONTESTINPUT
DESCRIPTOR.message_types_by_name['StartContestOutput'] = _STARTCONTESTOUTPUT
DESCRIPTOR.message_types_by_name['ImportProblemInput'] = _IMPORTPROBLEMINPUT
DESCRIPTOR.message_types_by_name['ImportProblemOutput'] = _IMPORTPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['SyncProblemInput'] = _SYNCPROBLEMINPUT
DESCRIPTOR.message_types_by_name['SyncProblemOutput'] = _SYNCPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['UpdateProblemInput'] = _UPDATEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['UpdateProblemOutput'] = _UPDATEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['DeleteProblemInput'] = _DELETEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['DeleteProblemOutput'] = _DELETEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['RetestProblemInput'] = _RETESTPROBLEMINPUT
DESCRIPTOR.message_types_by_name['RetestProblemOutput'] = _RETESTPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['ListProblemsInput'] = _LISTPROBLEMSINPUT
DESCRIPTOR.message_types_by_name['ListProblemsOutput'] = _LISTPROBLEMSOUTPUT
DESCRIPTOR.message_types_by_name['DescribeProblemInput'] = _DESCRIBEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['DescribeProblemOutput'] = _DESCRIBEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['ListStatementsInput'] = _LISTSTATEMENTSINPUT
DESCRIPTOR.message_types_by_name['ListStatementsOutput'] = _LISTSTATEMENTSOUTPUT
DESCRIPTOR.message_types_by_name['ListExamplesInput'] = _LISTEXAMPLESINPUT
DESCRIPTOR.message_types_by_name['ListExamplesOutput'] = _LISTEXAMPLESOUTPUT
DESCRIPTOR.message_types_by_name['AddParticipantInput'] = _ADDPARTICIPANTINPUT
DESCRIPTOR.message_types_by_name['AddParticipantOutput'] = _ADDPARTICIPANTOUTPUT
DESCRIPTOR.message_types_by_name['EnableParticipantInput'] = _ENABLEPARTICIPANTINPUT
DESCRIPTOR.message_types_by_name['EnableParticipantOutput'] = _ENABLEPARTICIPANTOUTPUT
DESCRIPTOR.message_types_by_name['DisableParticipantInput'] = _DISABLEPARTICIPANTINPUT
DESCRIPTOR.message_types_by_name['DisableParticipantOutput'] = _DISABLEPARTICIPANTOUTPUT
DESCRIPTOR.message_types_by_name['RemoveParticipantInput'] = _REMOVEPARTICIPANTINPUT
DESCRIPTOR.message_types_by_name['RemoveParticipantOutput'] = _REMOVEPARTICIPANTOUTPUT
DESCRIPTOR.message_types_by_name['VerifyPasscodeInput'] = _VERIFYPASSCODEINPUT
DESCRIPTOR.message_types_by_name['VerifyPasscodeOutput'] = _VERIFYPASSCODEOUTPUT
DESCRIPTOR.message_types_by_name['EnterPasscodeInput'] = _ENTERPASSCODEINPUT
DESCRIPTOR.message_types_by_name['EnterPasscodeOutput'] = _ENTERPASSCODEOUTPUT
DESCRIPTOR.message_types_by_name['ResetPasscodeInput'] = _RESETPASSCODEINPUT
DESCRIPTOR.message_types_by_name['ResetPasscodeOutput'] = _RESETPASSCODEOUTPUT
DESCRIPTOR.message_types_by_name['RemovePasscodeInput'] = _REMOVEPASSCODEINPUT
DESCRIPTOR.message_types_by_name['RemovePasscodeOutput'] = _REMOVEPASSCODEOUTPUT
DESCRIPTOR.message_types_by_name['ListParticipantsInput'] = _LISTPARTICIPANTSINPUT
DESCRIPTOR.message_types_by_name['ListParticipantsOutput'] = _LISTPARTICIPANTSOUTPUT
DESCRIPTOR.message_types_by_name['IntrospectParticipantInput'] = _INTROSPECTPARTICIPANTINPUT
DESCRIPTOR.message_types_by_name['IntrospectParticipantOutput'] = _INTROSPECTPARTICIPANTOUTPUT
DESCRIPTOR.message_types_by_name['DescribeParticipantInput'] = _DESCRIBEPARTICIPANTINPUT
DESCRIPTOR.message_types_by_name['DescribeParticipantOutput'] = _DESCRIBEPARTICIPANTOUTPUT
DESCRIPTOR.message_types_by_name['CreateSubmissionInput'] = _CREATESUBMISSIONINPUT
DESCRIPTOR.message_types_by_name['CreateSubmissionOutput'] = _CREATESUBMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['ListSubmissionsInput'] = _LISTSUBMISSIONSINPUT
DESCRIPTOR.message_types_by_name['ListSubmissionsOutput'] = _LISTSUBMISSIONSOUTPUT
DESCRIPTOR.message_types_by_name['DescribeSubmissionInput'] = _DESCRIBESUBMISSIONINPUT
DESCRIPTOR.message_types_by_name['DescribeSubmissionOutput'] = _DESCRIBESUBMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['RetestSubmissionInput'] = _RETESTSUBMISSIONINPUT
DESCRIPTOR.message_types_by_name['RetestSubmissionOutput'] = _RETESTSUBMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['CreateTicketInput'] = _CREATETICKETINPUT
DESCRIPTOR.message_types_by_name['CreateTicketOutput'] = _CREATETICKETOUTPUT
DESCRIPTOR.message_types_by_name['CloseTicketInput'] = _CLOSETICKETINPUT
DESCRIPTOR.message_types_by_name['CloseTicketOutput'] = _CLOSETICKETOUTPUT
DESCRIPTOR.message_types_by_name['OpenTicketInput'] = _OPENTICKETINPUT
DESCRIPTOR.message_types_by_name['OpenTicketOutput'] = _OPENTICKETOUTPUT
DESCRIPTOR.message_types_by_name['ReadTicketInput'] = _READTICKETINPUT
DESCRIPTOR.message_types_by_name['ReadTicketOutput'] = _READTICKETOUTPUT
DESCRIPTOR.message_types_by_name['DeleteTicketInput'] = _DELETETICKETINPUT
DESCRIPTOR.message_types_by_name['DeleteTicketOutput'] = _DELETETICKETOUTPUT
DESCRIPTOR.message_types_by_name['DescribeTicketInput'] = _DESCRIBETICKETINPUT
DESCRIPTOR.message_types_by_name['DescribeTicketOutput'] = _DESCRIBETICKETOUTPUT
DESCRIPTOR.message_types_by_name['ListTicketsInput'] = _LISTTICKETSINPUT
DESCRIPTOR.message_types_by_name['ListTicketsOutput'] = _LISTTICKETSOUTPUT
DESCRIPTOR.message_types_by_name['ReplyTicketInput'] = _REPLYTICKETINPUT
DESCRIPTOR.message_types_by_name['ReplyTicketOutput'] = _REPLYTICKETOUTPUT
DESCRIPTOR.message_types_by_name['ListRepliesInput'] = _LISTREPLIESINPUT
DESCRIPTOR.message_types_by_name['ListRepliesOutput'] = _LISTREPLIESOUTPUT
DESCRIPTOR.message_types_by_name['DeleteReplyInput'] = _DELETEREPLYINPUT
DESCRIPTOR.message_types_by_name['DeleteReplyOutput'] = _DELETEREPLYOUTPUT
DESCRIPTOR.message_types_by_name['UpdateReplyInput'] = _UPDATEREPLYINPUT
DESCRIPTOR.message_types_by_name['UpdateReplyOutput'] = _UPDATEREPLYOUTPUT
DESCRIPTOR.message_types_by_name['ConfigureRegistrationFormInput'] = _CONFIGUREREGISTRATIONFORMINPUT
DESCRIPTOR.message_types_by_name['ConfigureRegistrationFormOutput'] = _CONFIGUREREGISTRATIONFORMOUTPUT
DESCRIPTOR.message_types_by_name['DescribeRegistrationFormInput'] = _DESCRIBEREGISTRATIONFORMINPUT
DESCRIPTOR.message_types_by_name['DescribeRegistrationFormOutput'] = _DESCRIBEREGISTRATIONFORMOUTPUT
DESCRIPTOR.message_types_by_name['ConfigureRuntimeInput'] = _CONFIGURERUNTIMEINPUT
DESCRIPTOR.message_types_by_name['ConfigureRuntimeOutput'] = _CONFIGURERUNTIMEOUTPUT
DESCRIPTOR.message_types_by_name['DescribeRuntimeInput'] = _DESCRIBERUNTIMEINPUT
DESCRIPTOR.message_types_by_name['DescribeRuntimeOutput'] = _DESCRIBERUNTIMEOUTPUT
DESCRIPTOR.message_types_by_name['SubmitRegistrationInput'] = _SUBMITREGISTRATIONINPUT
DESCRIPTOR.message_types_by_name['SubmitRegistrationOutput'] = _SUBMITREGISTRATIONOUTPUT
DESCRIPTOR.message_types_by_name['DescribeRegistrationInput'] = _DESCRIBEREGISTRATIONINPUT
DESCRIPTOR.message_types_by_name['DescribeRegistrationOutput'] = _DESCRIBEREGISTRATIONOUTPUT
DESCRIPTOR.message_types_by_name['CreateAnnouncementInput'] = _CREATEANNOUNCEMENTINPUT
DESCRIPTOR.message_types_by_name['CreateAnnouncementOutput'] = _CREATEANNOUNCEMENTOUTPUT
DESCRIPTOR.message_types_by_name['UpdateAnnouncementInput'] = _UPDATEANNOUNCEMENTINPUT
DESCRIPTOR.message_types_by_name['UpdateAnnouncementOutput'] = _UPDATEANNOUNCEMENTOUTPUT
DESCRIPTOR.message_types_by_name['DeleteAnnouncementInput'] = _DELETEANNOUNCEMENTINPUT
DESCRIPTOR.message_types_by_name['DeleteAnnouncementOutput'] = _DELETEANNOUNCEMENTOUTPUT
DESCRIPTOR.message_types_by_name['ReadAnnouncementInput'] = _READANNOUNCEMENTINPUT
DESCRIPTOR.message_types_by_name['ReadAnnouncementOutput'] = _READANNOUNCEMENTOUTPUT
DESCRIPTOR.message_types_by_name['DescribeAnnouncementInput'] = _DESCRIBEANNOUNCEMENTINPUT
DESCRIPTOR.message_types_by_name['DescribeAnnouncementOutput'] = _DESCRIBEANNOUNCEMENTOUTPUT
DESCRIPTOR.message_types_by_name['DescribeAnnouncementStatusInput'] = _DESCRIBEANNOUNCEMENTSTATUSINPUT
DESCRIPTOR.message_types_by_name['DescribeAnnouncementStatusOutput'] = _DESCRIBEANNOUNCEMENTSTATUSOUTPUT
DESCRIPTOR.message_types_by_name['ListAnnouncementsInput'] = _LISTANNOUNCEMENTSINPUT
DESCRIPTOR.message_types_by_name['ListAnnouncementsOutput'] = _LISTANNOUNCEMENTSOUTPUT
DESCRIPTOR.message_types_by_name['DescribeCodeTemplateInput'] = _DESCRIBECODETEMPLATEINPUT
DESCRIPTOR.message_types_by_name['DescribeCodeTemplateOutput'] = _DESCRIBECODETEMPLATEOUTPUT
DESCRIPTOR.message_types_by_name['CreateScoreboardInput'] = _CREATESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['CreateScoreboardOutput'] = _CREATESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['UpdateScoreboardInput'] = _UPDATESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['UpdateScoreboardOutput'] = _UPDATESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['RebuildScoreboardInput'] = _REBUILDSCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['RebuildScoreboardOutput'] = _REBUILDSCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['DeleteScoreboardInput'] = _DELETESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['DeleteScoreboardOutput'] = _DELETESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardInput'] = _DESCRIBESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardOutput'] = _DESCRIBESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['DescribeDefaultScoreboardInput'] = _DESCRIBEDEFAULTSCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['DescribeDefaultScoreboardOutput'] = _DESCRIBEDEFAULTSCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['ListScoreboardsInput'] = _LISTSCOREBOARDSINPUT
DESCRIPTOR.message_types_by_name['ListScoreboardsOutput'] = _LISTSCOREBOARDSOUTPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardRowInput'] = _DESCRIBESCOREBOARDROWINPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardRowOutput'] = _DESCRIBESCOREBOARDROWOUTPUT
DESCRIPTOR.message_types_by_name['DescribeDefaultScoreboardRowInput'] = _DESCRIBEDEFAULTSCOREBOARDROWINPUT
DESCRIPTOR.message_types_by_name['DescribeDefaultScoreboardRowOutput'] = _DESCRIBEDEFAULTSCOREBOARDROWOUTPUT
DESCRIPTOR.message_types_by_name['ListScoreboardRowsInput'] = _LISTSCOREBOARDROWSINPUT
DESCRIPTOR.message_types_by_name['ListScoreboardRowsOutput'] = _LISTSCOREBOARDROWSOUTPUT
DESCRIPTOR.message_types_by_name['ListDefaultScoreboardRowsInput'] = _LISTDEFAULTSCOREBOARDROWSINPUT
DESCRIPTOR.message_types_by_name['ListDefaultScoreboardRowsOutput'] = _LISTDEFAULTSCOREBOARDROWSOUTPUT
DESCRIPTOR.message_types_by_name['ListEntitlementsInput'] = _LISTENTITLEMENTSINPUT
DESCRIPTOR.message_types_by_name['ListEntitlementsOutput'] = _LISTENTITLEMENTSOUTPUT
DESCRIPTOR.message_types_by_name['ListActivitiesInput'] = _LISTACTIVITIESINPUT
DESCRIPTOR.message_types_by_name['ListActivitiesOutput'] = _LISTACTIVITIESOUTPUT
DESCRIPTOR.message_types_by_name['ConfigureAppearanceInput'] = _CONFIGUREAPPEARANCEINPUT
DESCRIPTOR.message_types_by_name['ConfigureAppearanceOutput'] = _CONFIGUREAPPEARANCEOUTPUT
DESCRIPTOR.message_types_by_name['DescribeAppearanceInput'] = _DESCRIBEAPPEARANCEINPUT
DESCRIPTOR.message_types_by_name['DescribeAppearanceOutput'] = _DESCRIBEAPPEARANCEOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateContestInput = _reflection.GeneratedProtocolMessageType('CreateContestInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateContestInput)
  })
_sym_db.RegisterMessage(CreateContestInput)

CreateContestOutput = _reflection.GeneratedProtocolMessageType('CreateContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateContestOutput)
  })
_sym_db.RegisterMessage(CreateContestOutput)

DeleteContestInput = _reflection.GeneratedProtocolMessageType('DeleteContestInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteContestInput)
  })
_sym_db.RegisterMessage(DeleteContestInput)

DeleteContestOutput = _reflection.GeneratedProtocolMessageType('DeleteContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteContestOutput)
  })
_sym_db.RegisterMessage(DeleteContestOutput)

UpdateContestInput = _reflection.GeneratedProtocolMessageType('UpdateContestInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateContestInput)
  })
_sym_db.RegisterMessage(UpdateContestInput)

UpdateContestOutput = _reflection.GeneratedProtocolMessageType('UpdateContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateContestOutput)
  })
_sym_db.RegisterMessage(UpdateContestOutput)

DescribeContestInput = _reflection.GeneratedProtocolMessageType('DescribeContestInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeContestInput)
  })
_sym_db.RegisterMessage(DescribeContestInput)

DescribeContestOutput = _reflection.GeneratedProtocolMessageType('DescribeContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeContestOutput)
  })
_sym_db.RegisterMessage(DescribeContestOutput)

LookupContestInput = _reflection.GeneratedProtocolMessageType('LookupContestInput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPCONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.LookupContestInput)
  })
_sym_db.RegisterMessage(LookupContestInput)

LookupContestOutput = _reflection.GeneratedProtocolMessageType('LookupContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPCONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.LookupContestOutput)
  })
_sym_db.RegisterMessage(LookupContestOutput)

ListContestsInput = _reflection.GeneratedProtocolMessageType('ListContestsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTCONTESTSINPUT_FILTER,
    '__module__' : 'eolymp.judge.judge_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.ListContestsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTCONTESTSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListContestsInput)
  })
_sym_db.RegisterMessage(ListContestsInput)
_sym_db.RegisterMessage(ListContestsInput.Filter)

ListContestsOutput = _reflection.GeneratedProtocolMessageType('ListContestsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTESTSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListContestsOutput)
  })
_sym_db.RegisterMessage(ListContestsOutput)

OpenContestInput = _reflection.GeneratedProtocolMessageType('OpenContestInput', (_message.Message,), {
  'DESCRIPTOR' : _OPENCONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.OpenContestInput)
  })
_sym_db.RegisterMessage(OpenContestInput)

OpenContestOutput = _reflection.GeneratedProtocolMessageType('OpenContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _OPENCONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.OpenContestOutput)
  })
_sym_db.RegisterMessage(OpenContestOutput)

CloseContestInput = _reflection.GeneratedProtocolMessageType('CloseContestInput', (_message.Message,), {
  'DESCRIPTOR' : _CLOSECONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CloseContestInput)
  })
_sym_db.RegisterMessage(CloseContestInput)

CloseContestOutput = _reflection.GeneratedProtocolMessageType('CloseContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _CLOSECONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CloseContestOutput)
  })
_sym_db.RegisterMessage(CloseContestOutput)

JoinContestInput = _reflection.GeneratedProtocolMessageType('JoinContestInput', (_message.Message,), {
  'DESCRIPTOR' : _JOINCONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.JoinContestInput)
  })
_sym_db.RegisterMessage(JoinContestInput)

JoinContestOutput = _reflection.GeneratedProtocolMessageType('JoinContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _JOINCONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.JoinContestOutput)
  })
_sym_db.RegisterMessage(JoinContestOutput)

StartContestInput = _reflection.GeneratedProtocolMessageType('StartContestInput', (_message.Message,), {
  'DESCRIPTOR' : _STARTCONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.StartContestInput)
  })
_sym_db.RegisterMessage(StartContestInput)

StartContestOutput = _reflection.GeneratedProtocolMessageType('StartContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _STARTCONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.StartContestOutput)
  })
_sym_db.RegisterMessage(StartContestOutput)

ImportProblemInput = _reflection.GeneratedProtocolMessageType('ImportProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTPROBLEMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ImportProblemInput)
  })
_sym_db.RegisterMessage(ImportProblemInput)

ImportProblemOutput = _reflection.GeneratedProtocolMessageType('ImportProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTPROBLEMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ImportProblemOutput)
  })
_sym_db.RegisterMessage(ImportProblemOutput)

SyncProblemInput = _reflection.GeneratedProtocolMessageType('SyncProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _SYNCPROBLEMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.SyncProblemInput)
  })
_sym_db.RegisterMessage(SyncProblemInput)

SyncProblemOutput = _reflection.GeneratedProtocolMessageType('SyncProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _SYNCPROBLEMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.SyncProblemOutput)
  })
_sym_db.RegisterMessage(SyncProblemOutput)

UpdateProblemInput = _reflection.GeneratedProtocolMessageType('UpdateProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROBLEMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateProblemInput)
  })
_sym_db.RegisterMessage(UpdateProblemInput)

UpdateProblemOutput = _reflection.GeneratedProtocolMessageType('UpdateProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROBLEMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateProblemOutput)
  })
_sym_db.RegisterMessage(UpdateProblemOutput)

DeleteProblemInput = _reflection.GeneratedProtocolMessageType('DeleteProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROBLEMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteProblemInput)
  })
_sym_db.RegisterMessage(DeleteProblemInput)

DeleteProblemOutput = _reflection.GeneratedProtocolMessageType('DeleteProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROBLEMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteProblemOutput)
  })
_sym_db.RegisterMessage(DeleteProblemOutput)

RetestProblemInput = _reflection.GeneratedProtocolMessageType('RetestProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _RETESTPROBLEMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RetestProblemInput)
  })
_sym_db.RegisterMessage(RetestProblemInput)

RetestProblemOutput = _reflection.GeneratedProtocolMessageType('RetestProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _RETESTPROBLEMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RetestProblemOutput)
  })
_sym_db.RegisterMessage(RetestProblemOutput)

ListProblemsInput = _reflection.GeneratedProtocolMessageType('ListProblemsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROBLEMSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListProblemsInput)
  })
_sym_db.RegisterMessage(ListProblemsInput)

ListProblemsOutput = _reflection.GeneratedProtocolMessageType('ListProblemsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROBLEMSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListProblemsOutput)
  })
_sym_db.RegisterMessage(ListProblemsOutput)

DescribeProblemInput = _reflection.GeneratedProtocolMessageType('DescribeProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPROBLEMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeProblemInput)
  })
_sym_db.RegisterMessage(DescribeProblemInput)

DescribeProblemOutput = _reflection.GeneratedProtocolMessageType('DescribeProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPROBLEMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeProblemOutput)
  })
_sym_db.RegisterMessage(DescribeProblemOutput)

ListStatementsInput = _reflection.GeneratedProtocolMessageType('ListStatementsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTATEMENTSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListStatementsInput)
  })
_sym_db.RegisterMessage(ListStatementsInput)

ListStatementsOutput = _reflection.GeneratedProtocolMessageType('ListStatementsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTATEMENTSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListStatementsOutput)
  })
_sym_db.RegisterMessage(ListStatementsOutput)

ListExamplesInput = _reflection.GeneratedProtocolMessageType('ListExamplesInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXAMPLESINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListExamplesInput)
  })
_sym_db.RegisterMessage(ListExamplesInput)

ListExamplesOutput = _reflection.GeneratedProtocolMessageType('ListExamplesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXAMPLESOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListExamplesOutput)
  })
_sym_db.RegisterMessage(ListExamplesOutput)

AddParticipantInput = _reflection.GeneratedProtocolMessageType('AddParticipantInput', (_message.Message,), {
  'DESCRIPTOR' : _ADDPARTICIPANTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.AddParticipantInput)
  })
_sym_db.RegisterMessage(AddParticipantInput)

AddParticipantOutput = _reflection.GeneratedProtocolMessageType('AddParticipantOutput', (_message.Message,), {
  'DESCRIPTOR' : _ADDPARTICIPANTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.AddParticipantOutput)
  })
_sym_db.RegisterMessage(AddParticipantOutput)

EnableParticipantInput = _reflection.GeneratedProtocolMessageType('EnableParticipantInput', (_message.Message,), {
  'DESCRIPTOR' : _ENABLEPARTICIPANTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.EnableParticipantInput)
  })
_sym_db.RegisterMessage(EnableParticipantInput)

EnableParticipantOutput = _reflection.GeneratedProtocolMessageType('EnableParticipantOutput', (_message.Message,), {
  'DESCRIPTOR' : _ENABLEPARTICIPANTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.EnableParticipantOutput)
  })
_sym_db.RegisterMessage(EnableParticipantOutput)

DisableParticipantInput = _reflection.GeneratedProtocolMessageType('DisableParticipantInput', (_message.Message,), {
  'DESCRIPTOR' : _DISABLEPARTICIPANTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DisableParticipantInput)
  })
_sym_db.RegisterMessage(DisableParticipantInput)

DisableParticipantOutput = _reflection.GeneratedProtocolMessageType('DisableParticipantOutput', (_message.Message,), {
  'DESCRIPTOR' : _DISABLEPARTICIPANTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DisableParticipantOutput)
  })
_sym_db.RegisterMessage(DisableParticipantOutput)

RemoveParticipantInput = _reflection.GeneratedProtocolMessageType('RemoveParticipantInput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPARTICIPANTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RemoveParticipantInput)
  })
_sym_db.RegisterMessage(RemoveParticipantInput)

RemoveParticipantOutput = _reflection.GeneratedProtocolMessageType('RemoveParticipantOutput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPARTICIPANTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RemoveParticipantOutput)
  })
_sym_db.RegisterMessage(RemoveParticipantOutput)

VerifyPasscodeInput = _reflection.GeneratedProtocolMessageType('VerifyPasscodeInput', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYPASSCODEINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.VerifyPasscodeInput)
  })
_sym_db.RegisterMessage(VerifyPasscodeInput)

VerifyPasscodeOutput = _reflection.GeneratedProtocolMessageType('VerifyPasscodeOutput', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYPASSCODEOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.VerifyPasscodeOutput)
  })
_sym_db.RegisterMessage(VerifyPasscodeOutput)

EnterPasscodeInput = _reflection.GeneratedProtocolMessageType('EnterPasscodeInput', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPASSCODEINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.EnterPasscodeInput)
  })
_sym_db.RegisterMessage(EnterPasscodeInput)

EnterPasscodeOutput = _reflection.GeneratedProtocolMessageType('EnterPasscodeOutput', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPASSCODEOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.EnterPasscodeOutput)
  })
_sym_db.RegisterMessage(EnterPasscodeOutput)

ResetPasscodeInput = _reflection.GeneratedProtocolMessageType('ResetPasscodeInput', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSCODEINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ResetPasscodeInput)
  })
_sym_db.RegisterMessage(ResetPasscodeInput)

ResetPasscodeOutput = _reflection.GeneratedProtocolMessageType('ResetPasscodeOutput', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSCODEOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ResetPasscodeOutput)
  })
_sym_db.RegisterMessage(ResetPasscodeOutput)

RemovePasscodeInput = _reflection.GeneratedProtocolMessageType('RemovePasscodeInput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPASSCODEINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RemovePasscodeInput)
  })
_sym_db.RegisterMessage(RemovePasscodeInput)

RemovePasscodeOutput = _reflection.GeneratedProtocolMessageType('RemovePasscodeOutput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPASSCODEOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RemovePasscodeOutput)
  })
_sym_db.RegisterMessage(RemovePasscodeOutput)

ListParticipantsInput = _reflection.GeneratedProtocolMessageType('ListParticipantsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTPARTICIPANTSINPUT_FILTER,
    '__module__' : 'eolymp.judge.judge_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.ListParticipantsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTPARTICIPANTSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListParticipantsInput)
  })
_sym_db.RegisterMessage(ListParticipantsInput)
_sym_db.RegisterMessage(ListParticipantsInput.Filter)

ListParticipantsOutput = _reflection.GeneratedProtocolMessageType('ListParticipantsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARTICIPANTSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListParticipantsOutput)
  })
_sym_db.RegisterMessage(ListParticipantsOutput)

IntrospectParticipantInput = _reflection.GeneratedProtocolMessageType('IntrospectParticipantInput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTPARTICIPANTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.IntrospectParticipantInput)
  })
_sym_db.RegisterMessage(IntrospectParticipantInput)

IntrospectParticipantOutput = _reflection.GeneratedProtocolMessageType('IntrospectParticipantOutput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTPARTICIPANTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.IntrospectParticipantOutput)
  })
_sym_db.RegisterMessage(IntrospectParticipantOutput)

DescribeParticipantInput = _reflection.GeneratedProtocolMessageType('DescribeParticipantInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPARTICIPANTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeParticipantInput)
  })
_sym_db.RegisterMessage(DescribeParticipantInput)

DescribeParticipantOutput = _reflection.GeneratedProtocolMessageType('DescribeParticipantOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPARTICIPANTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeParticipantOutput)
  })
_sym_db.RegisterMessage(DescribeParticipantOutput)

CreateSubmissionInput = _reflection.GeneratedProtocolMessageType('CreateSubmissionInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBMISSIONINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateSubmissionInput)
  })
_sym_db.RegisterMessage(CreateSubmissionInput)

CreateSubmissionOutput = _reflection.GeneratedProtocolMessageType('CreateSubmissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBMISSIONOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateSubmissionOutput)
  })
_sym_db.RegisterMessage(CreateSubmissionOutput)

ListSubmissionsInput = _reflection.GeneratedProtocolMessageType('ListSubmissionsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTSUBMISSIONSINPUT_FILTER,
    '__module__' : 'eolymp.judge.judge_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.ListSubmissionsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTSUBMISSIONSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListSubmissionsInput)
  })
_sym_db.RegisterMessage(ListSubmissionsInput)
_sym_db.RegisterMessage(ListSubmissionsInput.Filter)

ListSubmissionsOutput = _reflection.GeneratedProtocolMessageType('ListSubmissionsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSUBMISSIONSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListSubmissionsOutput)
  })
_sym_db.RegisterMessage(ListSubmissionsOutput)

DescribeSubmissionInput = _reflection.GeneratedProtocolMessageType('DescribeSubmissionInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESUBMISSIONINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeSubmissionInput)
  })
_sym_db.RegisterMessage(DescribeSubmissionInput)

DescribeSubmissionOutput = _reflection.GeneratedProtocolMessageType('DescribeSubmissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESUBMISSIONOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeSubmissionOutput)
  })
_sym_db.RegisterMessage(DescribeSubmissionOutput)

RetestSubmissionInput = _reflection.GeneratedProtocolMessageType('RetestSubmissionInput', (_message.Message,), {
  'DESCRIPTOR' : _RETESTSUBMISSIONINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RetestSubmissionInput)
  })
_sym_db.RegisterMessage(RetestSubmissionInput)

RetestSubmissionOutput = _reflection.GeneratedProtocolMessageType('RetestSubmissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _RETESTSUBMISSIONOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RetestSubmissionOutput)
  })
_sym_db.RegisterMessage(RetestSubmissionOutput)

CreateTicketInput = _reflection.GeneratedProtocolMessageType('CreateTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateTicketInput)
  })
_sym_db.RegisterMessage(CreateTicketInput)

CreateTicketOutput = _reflection.GeneratedProtocolMessageType('CreateTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateTicketOutput)
  })
_sym_db.RegisterMessage(CreateTicketOutput)

CloseTicketInput = _reflection.GeneratedProtocolMessageType('CloseTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _CLOSETICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CloseTicketInput)
  })
_sym_db.RegisterMessage(CloseTicketInput)

CloseTicketOutput = _reflection.GeneratedProtocolMessageType('CloseTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _CLOSETICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CloseTicketOutput)
  })
_sym_db.RegisterMessage(CloseTicketOutput)

OpenTicketInput = _reflection.GeneratedProtocolMessageType('OpenTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _OPENTICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.OpenTicketInput)
  })
_sym_db.RegisterMessage(OpenTicketInput)

OpenTicketOutput = _reflection.GeneratedProtocolMessageType('OpenTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _OPENTICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.OpenTicketOutput)
  })
_sym_db.RegisterMessage(OpenTicketOutput)

ReadTicketInput = _reflection.GeneratedProtocolMessageType('ReadTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _READTICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ReadTicketInput)
  })
_sym_db.RegisterMessage(ReadTicketInput)

ReadTicketOutput = _reflection.GeneratedProtocolMessageType('ReadTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _READTICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ReadTicketOutput)
  })
_sym_db.RegisterMessage(ReadTicketOutput)

DeleteTicketInput = _reflection.GeneratedProtocolMessageType('DeleteTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETETICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteTicketInput)
  })
_sym_db.RegisterMessage(DeleteTicketInput)

DeleteTicketOutput = _reflection.GeneratedProtocolMessageType('DeleteTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETETICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteTicketOutput)
  })
_sym_db.RegisterMessage(DeleteTicketOutput)

DescribeTicketInput = _reflection.GeneratedProtocolMessageType('DescribeTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeTicketInput)
  })
_sym_db.RegisterMessage(DescribeTicketInput)

DescribeTicketOutput = _reflection.GeneratedProtocolMessageType('DescribeTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeTicketOutput)
  })
_sym_db.RegisterMessage(DescribeTicketOutput)

ListTicketsInput = _reflection.GeneratedProtocolMessageType('ListTicketsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTTICKETSINPUT_FILTER,
    '__module__' : 'eolymp.judge.judge_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.ListTicketsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTTICKETSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListTicketsInput)
  })
_sym_db.RegisterMessage(ListTicketsInput)
_sym_db.RegisterMessage(ListTicketsInput.Filter)

ListTicketsOutput = _reflection.GeneratedProtocolMessageType('ListTicketsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTTICKETSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListTicketsOutput)
  })
_sym_db.RegisterMessage(ListTicketsOutput)

ReplyTicketInput = _reflection.GeneratedProtocolMessageType('ReplyTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _REPLYTICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ReplyTicketInput)
  })
_sym_db.RegisterMessage(ReplyTicketInput)

ReplyTicketOutput = _reflection.GeneratedProtocolMessageType('ReplyTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _REPLYTICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ReplyTicketOutput)
  })
_sym_db.RegisterMessage(ReplyTicketOutput)

ListRepliesInput = _reflection.GeneratedProtocolMessageType('ListRepliesInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPLIESINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListRepliesInput)
  })
_sym_db.RegisterMessage(ListRepliesInput)

ListRepliesOutput = _reflection.GeneratedProtocolMessageType('ListRepliesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPLIESOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListRepliesOutput)
  })
_sym_db.RegisterMessage(ListRepliesOutput)

DeleteReplyInput = _reflection.GeneratedProtocolMessageType('DeleteReplyInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPLYINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteReplyInput)
  })
_sym_db.RegisterMessage(DeleteReplyInput)

DeleteReplyOutput = _reflection.GeneratedProtocolMessageType('DeleteReplyOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPLYOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteReplyOutput)
  })
_sym_db.RegisterMessage(DeleteReplyOutput)

UpdateReplyInput = _reflection.GeneratedProtocolMessageType('UpdateReplyInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPLYINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateReplyInput)
  })
_sym_db.RegisterMessage(UpdateReplyInput)

UpdateReplyOutput = _reflection.GeneratedProtocolMessageType('UpdateReplyOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPLYOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateReplyOutput)
  })
_sym_db.RegisterMessage(UpdateReplyOutput)

ConfigureRegistrationFormInput = _reflection.GeneratedProtocolMessageType('ConfigureRegistrationFormInput', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGUREREGISTRATIONFORMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ConfigureRegistrationFormInput)
  })
_sym_db.RegisterMessage(ConfigureRegistrationFormInput)

ConfigureRegistrationFormOutput = _reflection.GeneratedProtocolMessageType('ConfigureRegistrationFormOutput', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGUREREGISTRATIONFORMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ConfigureRegistrationFormOutput)
  })
_sym_db.RegisterMessage(ConfigureRegistrationFormOutput)

DescribeRegistrationFormInput = _reflection.GeneratedProtocolMessageType('DescribeRegistrationFormInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEREGISTRATIONFORMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeRegistrationFormInput)
  })
_sym_db.RegisterMessage(DescribeRegistrationFormInput)

DescribeRegistrationFormOutput = _reflection.GeneratedProtocolMessageType('DescribeRegistrationFormOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEREGISTRATIONFORMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeRegistrationFormOutput)
  })
_sym_db.RegisterMessage(DescribeRegistrationFormOutput)

ConfigureRuntimeInput = _reflection.GeneratedProtocolMessageType('ConfigureRuntimeInput', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURERUNTIMEINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ConfigureRuntimeInput)
  })
_sym_db.RegisterMessage(ConfigureRuntimeInput)

ConfigureRuntimeOutput = _reflection.GeneratedProtocolMessageType('ConfigureRuntimeOutput', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURERUNTIMEOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ConfigureRuntimeOutput)
  })
_sym_db.RegisterMessage(ConfigureRuntimeOutput)

DescribeRuntimeInput = _reflection.GeneratedProtocolMessageType('DescribeRuntimeInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERUNTIMEINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeRuntimeInput)
  })
_sym_db.RegisterMessage(DescribeRuntimeInput)

DescribeRuntimeOutput = _reflection.GeneratedProtocolMessageType('DescribeRuntimeOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBERUNTIMEOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeRuntimeOutput)
  })
_sym_db.RegisterMessage(DescribeRuntimeOutput)

SubmitRegistrationInput = _reflection.GeneratedProtocolMessageType('SubmitRegistrationInput', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITREGISTRATIONINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.SubmitRegistrationInput)
  })
_sym_db.RegisterMessage(SubmitRegistrationInput)

SubmitRegistrationOutput = _reflection.GeneratedProtocolMessageType('SubmitRegistrationOutput', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITREGISTRATIONOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.SubmitRegistrationOutput)
  })
_sym_db.RegisterMessage(SubmitRegistrationOutput)

DescribeRegistrationInput = _reflection.GeneratedProtocolMessageType('DescribeRegistrationInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEREGISTRATIONINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeRegistrationInput)
  })
_sym_db.RegisterMessage(DescribeRegistrationInput)

DescribeRegistrationOutput = _reflection.GeneratedProtocolMessageType('DescribeRegistrationOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEREGISTRATIONOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeRegistrationOutput)
  })
_sym_db.RegisterMessage(DescribeRegistrationOutput)

CreateAnnouncementInput = _reflection.GeneratedProtocolMessageType('CreateAnnouncementInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEANNOUNCEMENTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateAnnouncementInput)
  })
_sym_db.RegisterMessage(CreateAnnouncementInput)

CreateAnnouncementOutput = _reflection.GeneratedProtocolMessageType('CreateAnnouncementOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEANNOUNCEMENTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateAnnouncementOutput)
  })
_sym_db.RegisterMessage(CreateAnnouncementOutput)

UpdateAnnouncementInput = _reflection.GeneratedProtocolMessageType('UpdateAnnouncementInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEANNOUNCEMENTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateAnnouncementInput)
  })
_sym_db.RegisterMessage(UpdateAnnouncementInput)

UpdateAnnouncementOutput = _reflection.GeneratedProtocolMessageType('UpdateAnnouncementOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEANNOUNCEMENTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateAnnouncementOutput)
  })
_sym_db.RegisterMessage(UpdateAnnouncementOutput)

DeleteAnnouncementInput = _reflection.GeneratedProtocolMessageType('DeleteAnnouncementInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEANNOUNCEMENTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteAnnouncementInput)
  })
_sym_db.RegisterMessage(DeleteAnnouncementInput)

DeleteAnnouncementOutput = _reflection.GeneratedProtocolMessageType('DeleteAnnouncementOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEANNOUNCEMENTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteAnnouncementOutput)
  })
_sym_db.RegisterMessage(DeleteAnnouncementOutput)

ReadAnnouncementInput = _reflection.GeneratedProtocolMessageType('ReadAnnouncementInput', (_message.Message,), {
  'DESCRIPTOR' : _READANNOUNCEMENTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ReadAnnouncementInput)
  })
_sym_db.RegisterMessage(ReadAnnouncementInput)

ReadAnnouncementOutput = _reflection.GeneratedProtocolMessageType('ReadAnnouncementOutput', (_message.Message,), {
  'DESCRIPTOR' : _READANNOUNCEMENTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ReadAnnouncementOutput)
  })
_sym_db.RegisterMessage(ReadAnnouncementOutput)

DescribeAnnouncementInput = _reflection.GeneratedProtocolMessageType('DescribeAnnouncementInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEANNOUNCEMENTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeAnnouncementInput)
  })
_sym_db.RegisterMessage(DescribeAnnouncementInput)

DescribeAnnouncementOutput = _reflection.GeneratedProtocolMessageType('DescribeAnnouncementOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEANNOUNCEMENTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeAnnouncementOutput)
  })
_sym_db.RegisterMessage(DescribeAnnouncementOutput)

DescribeAnnouncementStatusInput = _reflection.GeneratedProtocolMessageType('DescribeAnnouncementStatusInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEANNOUNCEMENTSTATUSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeAnnouncementStatusInput)
  })
_sym_db.RegisterMessage(DescribeAnnouncementStatusInput)

DescribeAnnouncementStatusOutput = _reflection.GeneratedProtocolMessageType('DescribeAnnouncementStatusOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEANNOUNCEMENTSTATUSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeAnnouncementStatusOutput)
  })
_sym_db.RegisterMessage(DescribeAnnouncementStatusOutput)

ListAnnouncementsInput = _reflection.GeneratedProtocolMessageType('ListAnnouncementsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTANNOUNCEMENTSINPUT_FILTER,
    '__module__' : 'eolymp.judge.judge_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.ListAnnouncementsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTANNOUNCEMENTSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListAnnouncementsInput)
  })
_sym_db.RegisterMessage(ListAnnouncementsInput)
_sym_db.RegisterMessage(ListAnnouncementsInput.Filter)

ListAnnouncementsOutput = _reflection.GeneratedProtocolMessageType('ListAnnouncementsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTANNOUNCEMENTSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListAnnouncementsOutput)
  })
_sym_db.RegisterMessage(ListAnnouncementsOutput)

DescribeCodeTemplateInput = _reflection.GeneratedProtocolMessageType('DescribeCodeTemplateInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECODETEMPLATEINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeCodeTemplateInput)
  })
_sym_db.RegisterMessage(DescribeCodeTemplateInput)

DescribeCodeTemplateOutput = _reflection.GeneratedProtocolMessageType('DescribeCodeTemplateOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECODETEMPLATEOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeCodeTemplateOutput)
  })
_sym_db.RegisterMessage(DescribeCodeTemplateOutput)

CreateScoreboardInput = _reflection.GeneratedProtocolMessageType('CreateScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCOREBOARDINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateScoreboardInput)
  })
_sym_db.RegisterMessage(CreateScoreboardInput)

CreateScoreboardOutput = _reflection.GeneratedProtocolMessageType('CreateScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateScoreboardOutput)
  })
_sym_db.RegisterMessage(CreateScoreboardOutput)

UpdateScoreboardInput = _reflection.GeneratedProtocolMessageType('UpdateScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCOREBOARDINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateScoreboardInput)
  })
_sym_db.RegisterMessage(UpdateScoreboardInput)

UpdateScoreboardOutput = _reflection.GeneratedProtocolMessageType('UpdateScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateScoreboardOutput)
  })
_sym_db.RegisterMessage(UpdateScoreboardOutput)

RebuildScoreboardInput = _reflection.GeneratedProtocolMessageType('RebuildScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDSCOREBOARDINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RebuildScoreboardInput)
  })
_sym_db.RegisterMessage(RebuildScoreboardInput)

RebuildScoreboardOutput = _reflection.GeneratedProtocolMessageType('RebuildScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDSCOREBOARDOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RebuildScoreboardOutput)
  })
_sym_db.RegisterMessage(RebuildScoreboardOutput)

DeleteScoreboardInput = _reflection.GeneratedProtocolMessageType('DeleteScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCOREBOARDINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteScoreboardInput)
  })
_sym_db.RegisterMessage(DeleteScoreboardInput)

DeleteScoreboardOutput = _reflection.GeneratedProtocolMessageType('DeleteScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteScoreboardOutput)
  })
_sym_db.RegisterMessage(DeleteScoreboardOutput)

DescribeScoreboardInput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeScoreboardInput)
  })
_sym_db.RegisterMessage(DescribeScoreboardInput)

DescribeScoreboardOutput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeScoreboardOutput)
  })
_sym_db.RegisterMessage(DescribeScoreboardOutput)

DescribeDefaultScoreboardInput = _reflection.GeneratedProtocolMessageType('DescribeDefaultScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDEFAULTSCOREBOARDINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeDefaultScoreboardInput)
  })
_sym_db.RegisterMessage(DescribeDefaultScoreboardInput)

DescribeDefaultScoreboardOutput = _reflection.GeneratedProtocolMessageType('DescribeDefaultScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDEFAULTSCOREBOARDOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeDefaultScoreboardOutput)
  })
_sym_db.RegisterMessage(DescribeDefaultScoreboardOutput)

ListScoreboardsInput = _reflection.GeneratedProtocolMessageType('ListScoreboardsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTSCOREBOARDSINPUT_FILTER,
    '__module__' : 'eolymp.judge.judge_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.ListScoreboardsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTSCOREBOARDSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListScoreboardsInput)
  })
_sym_db.RegisterMessage(ListScoreboardsInput)
_sym_db.RegisterMessage(ListScoreboardsInput.Filter)

ListScoreboardsOutput = _reflection.GeneratedProtocolMessageType('ListScoreboardsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCOREBOARDSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListScoreboardsOutput)
  })
_sym_db.RegisterMessage(ListScoreboardsOutput)

DescribeScoreboardRowInput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardRowInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDROWINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeScoreboardRowInput)
  })
_sym_db.RegisterMessage(DescribeScoreboardRowInput)

DescribeScoreboardRowOutput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardRowOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDROWOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeScoreboardRowOutput)
  })
_sym_db.RegisterMessage(DescribeScoreboardRowOutput)

DescribeDefaultScoreboardRowInput = _reflection.GeneratedProtocolMessageType('DescribeDefaultScoreboardRowInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDEFAULTSCOREBOARDROWINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeDefaultScoreboardRowInput)
  })
_sym_db.RegisterMessage(DescribeDefaultScoreboardRowInput)

DescribeDefaultScoreboardRowOutput = _reflection.GeneratedProtocolMessageType('DescribeDefaultScoreboardRowOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDEFAULTSCOREBOARDROWOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeDefaultScoreboardRowOutput)
  })
_sym_db.RegisterMessage(DescribeDefaultScoreboardRowOutput)

ListScoreboardRowsInput = _reflection.GeneratedProtocolMessageType('ListScoreboardRowsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTSCOREBOARDROWSINPUT_FILTER,
    '__module__' : 'eolymp.judge.judge_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.ListScoreboardRowsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTSCOREBOARDROWSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListScoreboardRowsInput)
  })
_sym_db.RegisterMessage(ListScoreboardRowsInput)
_sym_db.RegisterMessage(ListScoreboardRowsInput.Filter)

ListScoreboardRowsOutput = _reflection.GeneratedProtocolMessageType('ListScoreboardRowsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCOREBOARDROWSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListScoreboardRowsOutput)
  })
_sym_db.RegisterMessage(ListScoreboardRowsOutput)

ListDefaultScoreboardRowsInput = _reflection.GeneratedProtocolMessageType('ListDefaultScoreboardRowsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEFAULTSCOREBOARDROWSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListDefaultScoreboardRowsInput)
  })
_sym_db.RegisterMessage(ListDefaultScoreboardRowsInput)

ListDefaultScoreboardRowsOutput = _reflection.GeneratedProtocolMessageType('ListDefaultScoreboardRowsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEFAULTSCOREBOARDROWSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListDefaultScoreboardRowsOutput)
  })
_sym_db.RegisterMessage(ListDefaultScoreboardRowsOutput)

ListEntitlementsInput = _reflection.GeneratedProtocolMessageType('ListEntitlementsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITLEMENTSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListEntitlementsInput)
  })
_sym_db.RegisterMessage(ListEntitlementsInput)

ListEntitlementsOutput = _reflection.GeneratedProtocolMessageType('ListEntitlementsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITLEMENTSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListEntitlementsOutput)
  })
_sym_db.RegisterMessage(ListEntitlementsOutput)

ListActivitiesInput = _reflection.GeneratedProtocolMessageType('ListActivitiesInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTACTIVITIESINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListActivitiesInput)
  })
_sym_db.RegisterMessage(ListActivitiesInput)

ListActivitiesOutput = _reflection.GeneratedProtocolMessageType('ListActivitiesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTACTIVITIESOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListActivitiesOutput)
  })
_sym_db.RegisterMessage(ListActivitiesOutput)

ConfigureAppearanceInput = _reflection.GeneratedProtocolMessageType('ConfigureAppearanceInput', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGUREAPPEARANCEINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ConfigureAppearanceInput)
  })
_sym_db.RegisterMessage(ConfigureAppearanceInput)

ConfigureAppearanceOutput = _reflection.GeneratedProtocolMessageType('ConfigureAppearanceOutput', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGUREAPPEARANCEOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ConfigureAppearanceOutput)
  })
_sym_db.RegisterMessage(ConfigureAppearanceOutput)

DescribeAppearanceInput = _reflection.GeneratedProtocolMessageType('DescribeAppearanceInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEAPPEARANCEINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeAppearanceInput)
  })
_sym_db.RegisterMessage(DescribeAppearanceInput)

DescribeAppearanceOutput = _reflection.GeneratedProtocolMessageType('DescribeAppearanceOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEAPPEARANCEOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeAppearanceOutput)
  })
_sym_db.RegisterMessage(DescribeAppearanceOutput)


DESCRIPTOR._options = None

_JUDGE = _descriptor.ServiceDescriptor(
  name='Judge',
  full_name='eolymp.judge.Judge',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=11847,
  serialized_end=25580,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateContest',
    full_name='eolymp.judge.Judge.CreateContest',
    index=0,
    containing_service=None,
    input_type=_CREATECONTESTINPUT,
    output_type=_CREATECONTESTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327\243=\370\342\n\005\202\323\344\223\002\032\"\017/judge/contests:\007contest',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteContest',
    full_name='eolymp.judge.Judge.DeleteContest',
    index=1,
    containing_service=None,
    input_type=_DELETECONTESTINPUT,
    output_type=_DELETECONTESTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036*\034/judge/contests/{contest_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateContest',
    full_name='eolymp.judge.Judge.UpdateContest',
    index=2,
    containing_service=None,
    input_type=_UPDATECONTESTINPUT,
    output_type=_UPDATECONTESTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\'\032\034/judge/contests/{contest_id}:\007contest',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LookupContest',
    full_name='eolymp.judge.Judge.LookupContest',
    index=3,
    containing_service=None,
    input_type=_LOOKUPCONTESTINPUT,
    output_type=_LOOKUPCONTESTOUTPUT,
    serialized_options=b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002 \022\033/judge/contest-lookup/{key}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeContest',
    full_name='eolymp.judge.Judge.DescribeContest',
    index=4,
    containing_service=None,
    input_type=_DESCRIBECONTESTINPUT,
    output_type=_DESCRIBECONTESTOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\'\022\034/judge/contests/{contest_id}b\007contest',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListContests',
    full_name='eolymp.judge.Judge.ListContests',
    index=5,
    containing_service=None,
    input_type=_LISTCONTESTSINPUT,
    output_type=_LISTCONTESTSOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\021\022\017/judge/contests',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OpenContest',
    full_name='eolymp.judge.Judge.OpenContest',
    index=6,
    containing_service=None,
    input_type=_OPENCONTESTINPUT,
    output_type=_OPENCONTESTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002#\"!/judge/contests/{contest_id}/open',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CloseContest',
    full_name='eolymp.judge.Judge.CloseContest',
    index=7,
    containing_service=None,
    input_type=_CLOSECONTESTINPUT,
    output_type=_CLOSECONTESTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002$\"\"/judge/contests/{contest_id}/close',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConfigureRegistrationForm',
    full_name='eolymp.judge.Judge.ConfigureRegistrationForm',
    index=8,
    containing_service=None,
    input_type=_CONFIGUREREGISTRATIONFORMINPUT,
    output_type=_CONFIGUREREGISTRATIONFORMOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\0020\"./judge/contests/{contest_id}/registration-form',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeRegistrationForm',
    full_name='eolymp.judge.Judge.DescribeRegistrationForm',
    index=9,
    containing_service=None,
    input_type=_DESCRIBEREGISTRATIONFORMINPUT,
    output_type=_DESCRIBEREGISTRATIONFORMOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\0026\022./judge/contests/{contest_id}/registration-formb\004form',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConfigureRuntime',
    full_name='eolymp.judge.Judge.ConfigureRuntime',
    index=10,
    containing_service=None,
    input_type=_CONFIGURERUNTIMEINPUT,
    output_type=_CONFIGURERUNTIMEOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&\"$/judge/contests/{contest_id}/runtime',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeRuntime',
    full_name='eolymp.judge.Judge.DescribeRuntime',
    index=11,
    containing_service=None,
    input_type=_DESCRIBERUNTIMEINPUT,
    output_type=_DESCRIBERUNTIMEOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002&\022$/judge/contests/{contest_id}/runtime',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConfigureAppearance',
    full_name='eolymp.judge.Judge.ConfigureAppearance',
    index=12,
    containing_service=None,
    input_type=_CONFIGUREAPPEARANCEINPUT,
    output_type=_CONFIGUREAPPEARANCEOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002)\"\'/judge/contests/{contest_id}/appearance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeAppearance',
    full_name='eolymp.judge.Judge.DescribeAppearance',
    index=13,
    containing_service=None,
    input_type=_DESCRIBEAPPEARANCEINPUT,
    output_type=_DESCRIBEAPPEARANCEOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002)\022\'/judge/contests/{contest_id}/appearance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubmitRegistration',
    full_name='eolymp.judge.Judge.SubmitRegistration',
    index=14,
    containing_service=None,
    input_type=_SUBMITREGISTRATIONINPUT,
    output_type=_SUBMITREGISTRATIONOUTPUT,
    serialized_options=b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\'\"%/judge/contests/{contest_id}/register',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeRegistration',
    full_name='eolymp.judge.Judge.DescribeRegistration',
    index=15,
    containing_service=None,
    input_type=_DESCRIBEREGISTRATIONINPUT,
    output_type=_DESCRIBEREGISTRATIONOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\0023\0221/judge/participants/{participant_id}/registration',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ImportProblem',
    full_name='eolymp.judge.Judge.ImportProblem',
    index=16,
    containing_service=None,
    input_type=_IMPORTPROBLEMINPUT,
    output_type=_IMPORTPROBLEMOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002-\"+/judge/contests/{contest_id}/import/problem',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SyncProblem',
    full_name='eolymp.judge.Judge.SyncProblem',
    index=17,
    containing_service=None,
    input_type=_SYNCPROBLEMINPUT,
    output_type=_SYNCPROBLEMOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002#\"!/judge/problems/{problem_id}/sync',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateProblem',
    full_name='eolymp.judge.Judge.UpdateProblem',
    index=18,
    containing_service=None,
    input_type=_UPDATEPROBLEMINPUT,
    output_type=_UPDATEPROBLEMOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\"\034/judge/problems/{problem_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListProblems',
    full_name='eolymp.judge.Judge.ListProblems',
    index=19,
    containing_service=None,
    input_type=_LISTPROBLEMSINPUT,
    output_type=_LISTPROBLEMSOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000@@\370\342\n\n\202\323\344\223\002\'\022%/judge/contests/{contest_id}/problems',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeProblem',
    full_name='eolymp.judge.Judge.DescribeProblem',
    index=20,
    containing_service=None,
    input_type=_DESCRIBEPROBLEMINPUT,
    output_type=_DESCRIBEPROBLEMOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\036\022\034/judge/problems/{problem_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeCodeTemplate',
    full_name='eolymp.judge.Judge.DescribeCodeTemplate',
    index=21,
    containing_service=None,
    input_type=_DESCRIBECODETEMPLATEINPUT,
    output_type=_DESCRIBECODETEMPLATEOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0028\0223/judge/problems/{problem_id}/templates/{runtime_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListStatements',
    full_name='eolymp.judge.Judge.ListStatements',
    index=22,
    containing_service=None,
    input_type=_LISTSTATEMENTSINPUT,
    output_type=_LISTSTATEMENTSOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002)\022\'/judge/problems/{problem_id}/statements',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListExamples',
    full_name='eolymp.judge.Judge.ListExamples',
    index=23,
    containing_service=None,
    input_type=_LISTEXAMPLESINPUT,
    output_type=_LISTEXAMPLESOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002(\022&/judge/problems/{problem_id}/examples/',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProblem',
    full_name='eolymp.judge.Judge.DeleteProblem',
    index=24,
    containing_service=None,
    input_type=_DELETEPROBLEMINPUT,
    output_type=_DELETEPROBLEMOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036*\034/judge/problems/{problem_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetestProblem',
    full_name='eolymp.judge.Judge.RetestProblem',
    index=25,
    containing_service=None,
    input_type=_RETESTPROBLEMINPUT,
    output_type=_RETESTPROBLEMOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002(\022#/judge/problems/{problem_id}/retestb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddParticipant',
    full_name='eolymp.judge.Judge.AddParticipant',
    index=26,
    containing_service=None,
    input_type=_ADDPARTICIPANTINPUT,
    output_type=_ADDPARTICIPANTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002.\")/judge/contests/{contest_id}/participants:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnableParticipant',
    full_name='eolymp.judge.Judge.EnableParticipant',
    index=27,
    containing_service=None,
    input_type=_ENABLEPARTICIPANTINPUT,
    output_type=_ENABLEPARTICIPANTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002-\"+/judge/participants/{participant_id}/enable',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisableParticipant',
    full_name='eolymp.judge.Judge.DisableParticipant',
    index=28,
    containing_service=None,
    input_type=_DISABLEPARTICIPANTINPUT,
    output_type=_DISABLEPARTICIPANTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002.\",/judge/participants/{participant_id}/disable',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveParticipant',
    full_name='eolymp.judge.Judge.RemoveParticipant',
    index=29,
    containing_service=None,
    input_type=_REMOVEPARTICIPANTINPUT,
    output_type=_REMOVEPARTICIPANTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&*$/judge/participants/{participant_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListParticipants',
    full_name='eolymp.judge.Judge.ListParticipants',
    index=30,
    containing_service=None,
    input_type=_LISTPARTICIPANTSINPUT,
    output_type=_LISTPARTICIPANTSOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002+\022)/judge/contests/{contest_id}/participants',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeParticipant',
    full_name='eolymp.judge.Judge.DescribeParticipant',
    index=31,
    containing_service=None,
    input_type=_DESCRIBEPARTICIPANTINPUT,
    output_type=_DESCRIBEPARTICIPANTOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\0023\022$/judge/participants/{participant_id}b\013participant',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IntrospectParticipant',
    full_name='eolymp.judge.Judge.IntrospectParticipant',
    index=32,
    containing_service=None,
    input_type=_INTROSPECTPARTICIPANTINPUT,
    output_type=_INTROSPECTPARTICIPANTOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0026\022\'/judge/contests/{contest_id}/introspectb\013participant',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='JoinContest',
    full_name='eolymp.judge.Judge.JoinContest',
    index=33,
    containing_service=None,
    input_type=_JOINCONTESTINPUT,
    output_type=_JOINCONTESTOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\323\344\223\002#\"!/judge/contests/{contest_id}/join',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartContest',
    full_name='eolymp.judge.Judge.StartContest',
    index=34,
    containing_service=None,
    input_type=_STARTCONTESTINPUT,
    output_type=_STARTCONTESTOUTPUT,
    serialized_options=b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\323\344\223\002$\"\"/judge/contests/{contest_id}/start',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='VerifyPasscode',
    full_name='eolymp.judge.Judge.VerifyPasscode',
    index=35,
    containing_service=None,
    input_type=_VERIFYPASSCODEINPUT,
    output_type=_VERIFYPASSCODEOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\'\022%/judge/contests/{contest_id}/passcode',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnterPasscode',
    full_name='eolymp.judge.Judge.EnterPasscode',
    index=36,
    containing_service=None,
    input_type=_ENTERPASSCODEINPUT,
    output_type=_ENTERPASSCODEOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\'\"%/judge/contests/{contest_id}/passcode',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetPasscode',
    full_name='eolymp.judge.Judge.ResetPasscode',
    index=37,
    containing_service=None,
    input_type=_RESETPASSCODEINPUT,
    output_type=_RESETPASSCODEOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002/\"-/judge/participants/{participant_id}/passcode',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemovePasscode',
    full_name='eolymp.judge.Judge.RemovePasscode',
    index=38,
    containing_service=None,
    input_type=_REMOVEPASSCODEINPUT,
    output_type=_REMOVEPASSCODEOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002/*-/judge/participants/{participant_id}/passcode',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateSubmission',
    full_name='eolymp.judge.Judge.CreateSubmission',
    index=39,
    containing_service=None,
    input_type=_CREATESUBMISSIONINPUT,
    output_type=_CREATESUBMISSIONOUTPUT,
    serialized_options=b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\323\344\223\002-\"(/judge/problems/{problem_id}/submissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListSubmissions',
    full_name='eolymp.judge.Judge.ListSubmissions',
    index=40,
    containing_service=None,
    input_type=_LISTSUBMISSIONSINPUT,
    output_type=_LISTSUBMISSIONSOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\212\001\022(/judge/contests/{contest_id}/submissionsZ*\022(/judge/problems/{problem_id}/submissionsZ2\0220/judge/participants/{participant_id}/submissions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeSubmission',
    full_name='eolymp.judge.Judge.DescribeSubmission',
    index=41,
    containing_service=None,
    input_type=_DESCRIBESUBMISSIONINPUT,
    output_type=_DESCRIBESUBMISSIONOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0020\022\"/judge/submissions/{submission_id}b\nsubmission',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetestSubmission',
    full_name='eolymp.judge.Judge.RetestSubmission',
    index=42,
    containing_service=None,
    input_type=_RETESTSUBMISSIONINPUT,
    output_type=_RETESTSUBMISSIONOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002.\022)/judge/submissions/{submission_id}/retestb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTicket',
    full_name='eolymp.judge.Judge.CreateTicket',
    index=43,
    containing_service=None,
    input_type=_CREATETICKETINPUT,
    output_type=_CREATETICKETOUTPUT,
    serialized_options=b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002)\"$/judge/contests/{contest_id}/ticketsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CloseTicket',
    full_name='eolymp.judge.Judge.CloseTicket',
    index=44,
    containing_service=None,
    input_type=_CLOSETICKETINPUT,
    output_type=_CLOSETICKETOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002%\" /judge/tickets/{ticket_id}/closeb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OpenTicket',
    full_name='eolymp.judge.Judge.OpenTicket',
    index=45,
    containing_service=None,
    input_type=_OPENTICKETINPUT,
    output_type=_OPENTICKETOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002$\"\037/judge/tickets/{ticket_id}/openb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadTicket',
    full_name='eolymp.judge.Judge.ReadTicket',
    index=46,
    containing_service=None,
    input_type=_READTICKETINPUT,
    output_type=_READTICKETOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002$\"\037/judge/tickets/{ticket_id}/readb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTicket',
    full_name='eolymp.judge.Judge.DeleteTicket',
    index=47,
    containing_service=None,
    input_type=_DELETETICKETINPUT,
    output_type=_DELETETICKETOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\037*\032/judge/tickets/{ticket_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeTicket',
    full_name='eolymp.judge.Judge.DescribeTicket',
    index=48,
    containing_service=None,
    input_type=_DESCRIBETICKETINPUT,
    output_type=_DESCRIBETICKETOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002$\022\032/judge/tickets/{ticket_id}b\006ticket',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListTickets',
    full_name='eolymp.judge.Judge.ListTickets',
    index=49,
    containing_service=None,
    input_type=_LISTTICKETSINPUT,
    output_type=_LISTTICKETSOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\023\022\016/judge/ticketsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReplyTicket',
    full_name='eolymp.judge.Judge.ReplyTicket',
    index=50,
    containing_service=None,
    input_type=_REPLYTICKETINPUT,
    output_type=_REPLYTICKETOUTPUT,
    serialized_options=b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\'\"\"/judge/tickets/{ticket_id}/repliesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListReplies',
    full_name='eolymp.judge.Judge.ListReplies',
    index=51,
    containing_service=None,
    input_type=_LISTREPLIESINPUT,
    output_type=_LISTREPLIESOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\'\022\"/judge/tickets/{ticket_id}/repliesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteReply',
    full_name='eolymp.judge.Judge.DeleteReply',
    index=52,
    containing_service=None,
    input_type=_DELETEREPLYINPUT,
    output_type=_DELETEREPLYOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\036*\031/judge/replies/{reply_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateReply',
    full_name='eolymp.judge.Judge.UpdateReply',
    index=53,
    containing_service=None,
    input_type=_UPDATEREPLYINPUT,
    output_type=_UPDATEREPLYOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\036\"\031/judge/replies/{reply_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateAnnouncement',
    full_name='eolymp.judge.Judge.CreateAnnouncement',
    index=54,
    containing_service=None,
    input_type=_CREATEANNOUNCEMENTINPUT,
    output_type=_CREATEANNOUNCEMENTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002/\"*/judge/contests/{contest_id}/announcementsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAnnouncement',
    full_name='eolymp.judge.Judge.UpdateAnnouncement',
    index=55,
    containing_service=None,
    input_type=_UPDATEANNOUNCEMENTINPUT,
    output_type=_UPDATEANNOUNCEMENTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002(\"&/judge/announcements/{announcement_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAnnouncement',
    full_name='eolymp.judge.Judge.DeleteAnnouncement',
    index=56,
    containing_service=None,
    input_type=_DELETEANNOUNCEMENTINPUT,
    output_type=_DELETEANNOUNCEMENTOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002(*&/judge/announcements/{announcement_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadAnnouncement',
    full_name='eolymp.judge.Judge.ReadAnnouncement',
    index=57,
    containing_service=None,
    input_type=_READANNOUNCEMENTINPUT,
    output_type=_READANNOUNCEMENTOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0020\"+/judge/announcements/{announcement_id}/readb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeAnnouncement',
    full_name='eolymp.judge.Judge.DescribeAnnouncement',
    index=58,
    containing_service=None,
    input_type=_DESCRIBEANNOUNCEMENTINPUT,
    output_type=_DESCRIBEANNOUNCEMENTOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0026\022&/judge/announcements/{announcement_id}b\014announcement',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeAnnouncementStatus',
    full_name='eolymp.judge.Judge.DescribeAnnouncementStatus',
    index=59,
    containing_service=None,
    input_type=_DESCRIBEANNOUNCEMENTSTATUSINPUT,
    output_type=_DESCRIBEANNOUNCEMENTSTATUSOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0022\022-/judge/announcements/{announcement_id}/statusb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAnnouncements',
    full_name='eolymp.judge.Judge.ListAnnouncements',
    index=60,
    containing_service=None,
    input_type=_LISTANNOUNCEMENTSINPUT,
    output_type=_LISTANNOUNCEMENTSOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002/\022*/judge/contests/{contest_id}/announcementsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateScoreboard',
    full_name='eolymp.judge.Judge.CreateScoreboard',
    index=61,
    containing_service=None,
    input_type=_CREATESCOREBOARDINPUT,
    output_type=_CREATESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002-\"(/judge/contests/{contest_id}/scoreboardsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateScoreboard',
    full_name='eolymp.judge.Judge.UpdateScoreboard',
    index=62,
    containing_service=None,
    input_type=_UPDATESCOREBOARDINPUT,
    output_type=_UPDATESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002$\"\"/judge/scoreboards/{scoreboard_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RebuildScoreboard',
    full_name='eolymp.judge.Judge.RebuildScoreboard',
    index=63,
    containing_service=None,
    input_type=_REBUILDSCOREBOARDINPUT,
    output_type=_REBUILDSCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002,\"*/judge/scoreboards/{scoreboard_id}/rebuild',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteScoreboard',
    full_name='eolymp.judge.Judge.DeleteScoreboard',
    index=64,
    containing_service=None,
    input_type=_DELETESCOREBOARDINPUT,
    output_type=_DELETESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002$*\"/judge/scoreboards/{scoreboard_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeScoreboard',
    full_name='eolymp.judge.Judge.DescribeScoreboard',
    index=65,
    containing_service=None,
    input_type=_DESCRIBESCOREBOARDINPUT,
    output_type=_DESCRIBESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0020\022\"/judge/scoreboards/{scoreboard_id}b\nscoreboard',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeDefaultScoreboard',
    full_name='eolymp.judge.Judge.DescribeDefaultScoreboard',
    index=66,
    containing_service=None,
    input_type=_DESCRIBEDEFAULTSCOREBOARDINPUT,
    output_type=_DESCRIBEDEFAULTSCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\0025\022\'/judge/contests/{contest_id}/scoreboardb\nscoreboard',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListScoreboards',
    full_name='eolymp.judge.Judge.ListScoreboards',
    index=67,
    containing_service=None,
    input_type=_LISTSCOREBOARDSINPUT,
    output_type=_LISTSCOREBOARDSOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002-\022(/judge/contests/{contest_id}/scoreboardsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeScoreboardRow',
    full_name='eolymp.judge.Judge.DescribeScoreboardRow',
    index=68,
    containing_service=None,
    input_type=_DESCRIBESCOREBOARDROWINPUT,
    output_type=_DESCRIBESCOREBOARDROWOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002?\0228/judge/scoreboards/{scoreboard_id}/rows/{participant_id}b\003row',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeDefaultScoreboardRow',
    full_name='eolymp.judge.Judge.DescribeDefaultScoreboardRow',
    index=69,
    containing_service=None,
    input_type=_DESCRIBEDEFAULTSCOREBOARDROWINPUT,
    output_type=_DESCRIBEDEFAULTSCOREBOARDROWOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002D\022=/judge/contests/{contest_id}/scoreboard/rows/{participant_id}b\003row',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListScoreboardRows',
    full_name='eolymp.judge.Judge.ListScoreboardRows',
    index=70,
    containing_service=None,
    input_type=_LISTSCOREBOARDROWSINPUT,
    output_type=_LISTSCOREBOARDROWSOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002,\022\'/judge/scoreboards/{scoreboard_id}/rowsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDefaultScoreboardRows',
    full_name='eolymp.judge.Judge.ListDefaultScoreboardRows',
    index=71,
    containing_service=None,
    input_type=_LISTDEFAULTSCOREBOARDROWSINPUT,
    output_type=_LISTDEFAULTSCOREBOARDROWSOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0021\022,/judge/contests/{contest_id}/scoreboard/rowsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListEntitlements',
    full_name='eolymp.judge.Judge.ListEntitlements',
    index=72,
    containing_service=None,
    input_type=_LISTENTITLEMENTSINPUT,
    output_type=_LISTENTITLEMENTSOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\025\022\023/judge/entitlements',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListActivities',
    full_name='eolymp.judge.Judge.ListActivities',
    index=73,
    containing_service=None,
    input_type=_LISTACTIVITIESINPUT,
    output_type=_LISTACTIVITIESOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002,\022\'/judge/contests/{contest_id}/activitiesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_JUDGE)

DESCRIPTOR.services_by_name['Judge'] = _JUDGE

# @@protoc_insertion_point(module_scope)
